@@ -1,39 +1,43 @@
-/*****
-*
-* TOra - An Oracle Toolkit for DBA's and developers
-* Copyright (C) 2003-2005 Quest Software, Inc
-* Portions Copyright (C) 2005 Other Contributors
-* 
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License
-* as published by the Free Software Foundation;  only version 2 of
-* the License is valid for this program.
-* 
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-* 
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*
-*      As a special exception, you have permission to link this program
-*      with the Oracle Client libraries and distribute executables, as long
-*      as you follow the requirements of the GNU GPL in regard to all of the
-*      software in the executable aside from Oracle client libraries.
-*
-*      Specifically you are not permitted to link this program with the
-*      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
-*      And you are not permitted to distribute binaries compiled against
-*      these libraries without written consent from Quest Software, Inc.
-*      Observe that this does not disallow linking to the Qt Free Edition.
-*
-*      You may link this product with any GPL'd Qt library such as Qt/Free
-*
-* All trademarks belong to their respective owners.
-*
-*****/
+
+/* BEGIN_COMMON_COPYRIGHT_HEADER
+ *
+ * TOra - An Oracle Toolkit for DBA's and developers
+ * 
+ * Shared/mixed copyright is held throughout files in this product
+ * 
+ * Portions Copyright (C) 2000-2001 Underscore AB
+ * Portions Copyright (C) 2003-2005 Quest Software, Inc.
+ * Portions Copyright (C) 2004-2008 Numerous Other Contributors
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation;  only version 2 of
+ * the License is valid for this program.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ *      As a special exception, you have permission to link this program
+ *      with the Oracle Client libraries and distribute executables, as long
+ *      as you follow the requirements of the GNU GPL in regard to all of the
+ *      software in the executable aside from Oracle client libraries.
+ * 
+ *      Specifically you are not permitted to link this program with the
+ *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
+ *      And you are not permitted to distribute binaries compiled against
+ *      these libraries. 
+ * 
+ *      You may link this product with any GPL'd Qt library.
+ * 
+ * All trademarks belong to their respective owners.
+ *
+ * END_COMMON_COPYRIGHT_HEADER */
 
 #include "utils.h"
 
@@ -43,30 +47,24 @@
 #include "tomain.h"
 #include "tomemoeditor.h"
 #include "toresultcombo.h"
-#include "toresultlong.h"
+#include "toresulttableview.h"
 #include "toresultplan.h"
-#include "toresultview.h"
 #include "tosql.h"
 #include "totool.h"
 #include "toworksheetstatistic.h"
 
-#ifdef TO_KDE
-#  include <kmenubar.h>
-#endif
-
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qmenubar.h>
-#include <qpopupmenu.h>
 #include <qspinbox.h>
 #include <qsplitter.h>
 #include <qtabwidget.h>
 #include <qtimer.h>
-#include <qtoolbar.h>
 #include <qtoolbutton.h>
-#include <qworkspace.h>
 
-#include "toanalyze.moc"
+#include <QMenu>
+#include <QPixmap>
+#include <QVBoxLayout>
 
 #include "icons/execute.xpm"
 #include "icons/refresh.xpm"
@@ -82,10 +80,9 @@ class toAnalyzeTool : public toTool
     }
 public:
     toAnalyzeTool()
-            : toTool(320, "Statistics Manager")
-    { }
+            : toTool(320, "Statistics Manager") { }
 
-    virtual void closeWindow(toConnection &connection){};
+    virtual void closeWindow(toConnection &connection) {};
 
     virtual const char *menuItem()
     {
@@ -97,14 +94,15 @@ public:
     }
     virtual bool canHandle(toConnection &conn)
     {
-        return toIsOracle(conn) || toIsMySQL(conn);
+        return toIsOracle(conn) || toIsMySQL(conn) || toIsPostgreSQL(conn);
     }
 };
 
+
 static toAnalyzeTool AnalyzeTool;
 
 static toSQL SQLListTablesMySQL("toAnalyze:ListTables",
-                                "toad 0,* show table status",
+                                "show table status",
                                 "Get table statistics, first three columns and binds must be same",
                                 "4.1",
                                 "MySQL");
@@ -142,6 +140,27 @@ static toSQL SQLListTables7("toAnalyze:ListTables",
                             "",
                             "0703");
 
+static toSQL SQLListTablesPg(
+    "toAnalyze:ListTables",
+    "SELECT 'TABLE' AS \"Type\",\n"
+    "       st.schemaname,\n"
+    "       st.relname AS \"table\",\n"
+    "       c.relfrozenxid AS \"Frozen XID\",\n"
+    "       c.relpages AS \"8KB Pages\",\n"
+    "       c.reltuples AS \"Tuples\",\n"
+    "       st.last_analyze AS \"Last Analyze\",\n"
+    "       st.last_autoanalyze AS \"Last Auto Analyze\",\n"
+    "       st.last_vacuum AS \"Last Vacuum\",\n"
+    "       st.last_autovacuum AS \"Last Auto Vacuum\"\n"
+    "  FROM pg_stat_all_tables st,\n"
+    "       pg_class c\n"
+    " WHERE st.relid = c.OID\n"
+    " ORDER BY 1,\n"
+    "          2",
+    "",
+    "7.2",
+    "PostgreSQL");
+
 static toSQL SQLListIndex("toAnalyze:ListIndex",
                           "SELECT 'INDEX' \"Type\",\n"
                           "       Owner,\n"
@@ -158,6 +177,26 @@ static toSQL SQLListIndex("toAnalyze:ListIndex",
                           " WHERE 1 = 1",
                           "List the available indexes, first three column and binds must be same");
 
+static toSQL SQLListIndexPg(
+    "toAnalyze:ListIndex",
+    "SELECT 'INDEX' AS \"Type\",\n"
+    "       st.schemaname,\n"
+    "       st.relname AS \"table\",\n"
+    "       st.indexrelname,\n"
+    "       c.relpages AS \"8KB Pages\",\n"
+    "       c.reltuples AS \"Tuples\",\n"
+    "       st.idx_scan,\n"
+    "       st.idx_tup_read,\n"
+    "       st.idx_tup_fetch\n"
+    "  FROM pg_stat_all_indexes st,\n"
+    "       pg_class c\n"
+    " WHERE st.indexrelid = c.OID\n"
+    " ORDER BY 1,\n"
+    "          2",
+    "",
+    "7.2",
+    "PostgreSQL");
+
 static toSQL SQLListPlans("toAnalyze:ListPlans",
                           "SELECT DISTINCT\n"
                           "       statement_id \"Statement\",\n"
@@ -167,116 +206,171 @@ static toSQL SQLListPlans("toAnalyze:ListPlans",
                           "Display available saved statements. Must have same first "
                           "column and %1");
 
+
 toAnalyze::toAnalyze(QWidget *main, toConnection &connection)
-        : toToolWidget(AnalyzeTool, "analyze.html", main, connection)
+        : toToolWidget(AnalyzeTool, "analyze.html", main, connection, "toAnalyze")
 {
+
     Tabs = new QTabWidget(this);
-    QVBox *box = new QVBox(Tabs);
-    Tabs->addTab(box, tr("Analyze"));
+    layout()->addWidget(Tabs);
 
-    QToolBar *toolbar = toAllocBar(box, tr("Statistics Manager"));
+    QWidget *container = new QWidget(Tabs);
+    QVBoxLayout *box = new QVBoxLayout;
+    Tabs->addTab(container, tr("Analyze"));
 
-    new QToolButton(QPixmap(const_cast<const char**>(refresh_xpm)),
-                    tr("Refresh"),
-                    tr("Refresh"),
-                    this, SLOT(refresh()),
-                    toolbar);
+    QToolBar *toolbar = toAllocBar(container, tr("Statistics Manager"));
+    box->addWidget(toolbar);
+
+    toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(refresh_xpm))),
+                       tr("Refresh"),
+                       this,
+                       SLOT(refresh()));
 
     toolbar->addSeparator();
+
+    Analyzed = NULL;
     if (toIsOracle(connection))
     {
-        Analyzed = new QComboBox(toolbar, TO_KDE_TOOLBAR_WIDGET);
-        Analyzed->insertItem(tr("All"));
-        Analyzed->insertItem(tr("Not analyzed"));
-        Analyzed->insertItem(tr("Analyzed"));
+        Analyzed = new QComboBox(toolbar);
+        Analyzed->addItem(tr("All"));
+        Analyzed->addItem(tr("Not analyzed"));
+        Analyzed->addItem(tr("Analyzed"));
+        toolbar->addWidget(Analyzed);
     }
-    else
-        Analyzed = NULL;
 
-    Schema = new toResultCombo(toolbar, TO_KDE_TOOLBAR_WIDGET);
+    Schema = new toResultCombo(toolbar, TO_TOOLBAR_WIDGET_NAME);
     Schema->setSelected(tr("All"));
     Schema->additionalItem(tr("All"));
+    toolbar->addWidget(Schema);
     try
     {
         Schema->query(toSQL::sql(toSQL::TOSQL_USERLIST));
     }
-    TOCATCH
-
+    TOCATCH;
 
     if (toIsOracle(connection))
     {
-        Type = new QComboBox(toolbar, TO_KDE_TOOLBAR_WIDGET);
-        Type->insertItem(tr("Tables"));
-        Type->insertItem(tr("Indexes"));
+        Type = new QComboBox(toolbar);
+        Type->addItem(tr("Tables"));
+        Type->addItem(tr("Indexes"));
+        toolbar->addWidget(Type);
 
         toolbar->addSeparator();
 
-        Operation = new QComboBox(toolbar, TO_KDE_TOOLBAR_WIDGET);
-        Operation->insertItem(tr("Compute statistics"));
-        Operation->insertItem(tr("Estimate statistics"));
-        Operation->insertItem(tr("Delete statistics"));
-        Operation->insertItem(tr("Validate references"));
-        connect(Operation, SIGNAL(activated(int)),
-                this, SLOT(changeOperation(int)));
+        Operation = new QComboBox(toolbar);
+        Operation->addItem(tr("Compute statistics"));
+        Operation->addItem(tr("Estimate statistics"));
+        Operation->addItem(tr("Delete statistics"));
+        Operation->addItem(tr("Validate references"));
+        toolbar->addWidget(Operation);
+        connect(Operation,
+                SIGNAL(activated(int)),
+                this,
+                SLOT(changeOperation(int)));
+
+        toolbar->addWidget(
+            new QLabel(" " + tr("for") + " ", toolbar));
+
+        For = new QComboBox(toolbar);
+        For->addItem(tr("All"));
+        For->addItem(tr("Table"));
+        For->addItem(tr("Indexed columns"));
+        For->addItem(tr("Local indexes"));
+        toolbar->addWidget(For);
 
-        new QLabel(" " + tr("for") + " ", toolbar, TO_KDE_TOOLBAR_WIDGET);
-        For = new QComboBox(toolbar, TO_KDE_TOOLBAR_WIDGET);
-        For->insertItem(tr("All"));
-        For->insertItem(tr("Table"));
-        For->insertItem(tr("Indexed columns"));
-        For->insertItem(tr("Local indexes"));
         toolbar->addSeparator();
-        new QLabel(tr("Sample") + " ", toolbar, TO_KDE_TOOLBAR_WIDGET);
-        Sample = new QSpinBox(1, 100, 1, toolbar, TO_KDE_TOOLBAR_WIDGET);
+
+        toolbar->addWidget(new QLabel(tr("Sample") + " ",
+                                      toolbar));
+
+        Sample = new QSpinBox(toolbar);
+        Sample->setMinimum(1);
+        Sample->setMaximum(100);
         Sample->setValue(100);
         Sample->setSuffix(" " + tr("%"));
         Sample->setEnabled(false);
+        toolbar->addWidget(Sample);
+    }
+    else if (toIsPostgreSQL(connection))
+    {
+        Type = new QComboBox(toolbar);
+        Type->addItem(tr("Tables"));
+        Type->addItem(tr("Indexes"));
+        toolbar->addWidget(Type);
+
+        toolbar->addSeparator();
+
+        Operation = new QComboBox(toolbar);
+        Operation->addItem(tr("Vacuum table"));
+        Operation->addItem(tr("Analyze table"));
+        toolbar->addWidget(Operation);
+        connect(Operation,
+                SIGNAL(activated(int)),
+                this,
+                SLOT(changeOperation(int)));
+
+        Sample = NULL;
+        For    = NULL;
     }
     else
     {
-        Operation = new QComboBox(toolbar, TO_KDE_TOOLBAR_WIDGET);
-        Operation->insertItem(tr("Analyze table"));
-        Operation->insertItem(tr("Optimize table"));
-        connect(Operation, SIGNAL(activated(int)),
-                this, SLOT(changeOperation(int)));
+        Operation = new QComboBox(toolbar);
+        Operation->addItem(tr("Analyze table"));
+        Operation->addItem(tr("Optimize table"));
+        toolbar->addWidget(Operation);
+        connect(Operation,
+                SIGNAL(activated(int)),
+                this,
+                SLOT(changeOperation(int)));
 
-        Type = NULL;
+        Type   = NULL;
         Sample = NULL;
-        For = NULL;
+        For    = NULL;
     }
 
     toolbar->addSeparator();
-    new QLabel(tr("Parallel") + " ", toolbar, TO_KDE_TOOLBAR_WIDGET);
-    Parallel = new QSpinBox(1, 100, 1, toolbar, TO_KDE_TOOLBAR_WIDGET);
+
+    toolbar->addWidget(new QLabel(tr("Parallel") + " ",
+                                  toolbar));
+    Parallel = new QSpinBox(toolbar);
+    Parallel->setMinimum(1);
+    Parallel->setMaximum(100);
+    toolbar->addWidget(Parallel);
+
     toolbar->addSeparator();
 
-    new QToolButton(QPixmap(const_cast<const char**>(execute_xpm)),
-                    tr("Start analyzing"),
-                    tr("Start analyzing"),
-                    this, SLOT(execute()),
-                    toolbar);
-    new QToolButton(QPixmap(const_cast<const char**>(sql_xpm)),
-                    tr("Display SQL"),
-                    tr("Display SQL"),
-                    this, SLOT(displaySQL()),
-                    toolbar);
+    toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(execute_xpm))),
+                       tr("Start analyzing"),
+                       this,
+                       SLOT(execute()));
 
-    Current = new QLabel(toolbar, TO_KDE_TOOLBAR_WIDGET);
-    Current->setAlignment(AlignRight | AlignVCenter | ExpandTabs);
-    toolbar->setStretchableWidget(Current);
+    toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(sql_xpm))),
+                       tr("Display SQL"),
+                       this,
+                       SLOT(displaySQL()));
 
-    Stop = new QToolButton(QPixmap(const_cast<const char**>(stop_xpm)),
-                           tr("Stop current run"),
-                           tr("Stop current run"),
-                           this, SLOT(stop()),
-                           toolbar);
+    Current = new QLabel(toolbar);
+    Current->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+    toolbar->addWidget(Current);
+    Current->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding,
+                                       QSizePolicy::Minimum));
+
+    Stop = new QToolButton(this);
+    Stop->setIcon(QIcon(stop_xpm));
+    Stop->setText(tr("Stop current run"));
     Stop->setEnabled(false);
+    connect(Stop, SIGNAL(triggered(QAction *)), this, SLOT(stop()));
+    toolbar->addWidget(Stop);
 
-    Statistics = new toResultLong(true, false, toQuery::Background, box);
-    Statistics->setSelectionMode(QListView::Extended);
+    Statistics = new toResultTableView(true, false, container);
+    Statistics->setSelectionMode(QAbstractItemView::ExtendedSelection);
     Statistics->setReadAll(true);
+    box->addWidget(Statistics);
     connect(Statistics, SIGNAL(done()), this, SLOT(fillOwner()));
-    connect(Statistics, SIGNAL(displayMenu(QPopupMenu *)), this, SLOT(displayMenu(QPopupMenu *)));
+    connect(Statistics,
+            SIGNAL(displayMenu(QMenu *)),
+            this,
+            SLOT(displayMenu(QMenu *)));
 
     if (Analyzed)
         connect(Analyzed, SIGNAL(activated(int)), this, SLOT(refresh()));
@@ -284,48 +378,60 @@ toAnalyze::toAnalyze(QWidget *main, toConnection &connection)
     if (Type)
         connect(Type, SIGNAL(activated(int)), this, SLOT(refresh()));
 
-    ToolMenu = NULL;
-    connect(toMainWidget()->workspace(), SIGNAL(windowActivated(QWidget *)),
-            this, SLOT(windowActivated(QWidget *)));
-
     connect(&Poll, SIGNAL(timeout()), this, SLOT(poll()));
 
+    box->setSpacing(0);
+    box->setContentsMargins(0, 0, 0, 0);
+    container->setLayout(box);
+
     if (toIsOracle(connection))
     {
-        box = new QVBox(Tabs);
-        toolbar = toAllocBar(box, tr("Explain plans"));
+        container = new QWidget(Tabs);
+        box = new QVBoxLayout;
+        toolbar = toAllocBar(container, tr("Explain plans"));
+        box->addWidget(toolbar);
 
-        Tabs->addTab(box, tr("Explain plans"));
-        QSplitter *splitter = new QSplitter(Horizontal, box);
-        Plans = new toResultLong(false, false, toQuery::Background, splitter);
-        Plans->setSelectionMode(QListView::Single);
+        Tabs->addTab(container, tr("Explain plans"));
+        QSplitter *splitter = new QSplitter(Qt::Horizontal, container);
+        box->addWidget(splitter);
+        Plans = new toResultTableView(false, false, splitter);
         try
         {
-            Plans->query(toSQL::string(SQLListPlans,
-                                       connection).arg(toConfigurationSingle::Instance().globalConfig(CONF_PLAN_TABLE,
-                                                                            DEFAULT_PLAN_TABLE)));
+            Plans->query(toSQL::string(SQLListPlans, connection).arg(
+                             toConfigurationSingle::Instance().planTable()));
         }
-        TOCATCH
+        TOCATCH;
 
-        connect(Plans, SIGNAL(selectionChanged()),
-                this, SLOT(selectPlan()));
-        new QToolButton(QPixmap(const_cast<const char**>(refresh_xpm)),
-                        tr("Refresh"),
-                        tr("Refresh"),
-                        Plans, SLOT(refresh()),
-                        toolbar);
-        toolbar->setStretchableWidget(new QLabel(toolbar, TO_KDE_TOOLBAR_WIDGET));
+        connect(Plans,
+                SIGNAL(selectionChanged()),
+                this,
+                SLOT(selectPlan()));
+
+        toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(refresh_xpm))),
+                           tr("Refresh"),
+                           Plans,
+                           SLOT(refresh()));
+
+        QLabel *s = new QLabel(toolbar);
+        s->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+        s->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding,
+                                     QSizePolicy::Minimum));
+        toolbar->addWidget(s);
 
         CurrentPlan = new toResultPlan(splitter);
 
         Worksheet = new toWorksheetStatistic(Tabs);
         Tabs->addTab(Worksheet, tr("Worksheet statistics"));
+
+        box->setSpacing(0);
+        box->setContentsMargins(0, 0, 0, 0);
+        container->setLayout(box);
     }
     else
     {
-        Plans = NULL;
+        Plans       = NULL;
         CurrentPlan = NULL;
-        Worksheet = NULL;
+        Worksheet   = NULL;
     }
 
     refresh();
@@ -334,43 +440,28 @@ toAnalyze::toAnalyze(QWidget *main, toConnection &connection)
 
 void toAnalyze::fillOwner(void)
 {
-    for (QListViewItem *item = Statistics->firstChild();item;item = item->nextSibling())
+    for (toResultTableView::iterator it(Statistics); (*it).isValid(); it++)
     {
-        if (toUnnull(item->text(0)).isNull())
-            item->setText(0, Schema->selected());
+        if ((*it).data(Qt::EditRole).isNull())
+        {
+            Statistics->model()->setData(
+                (*it),
+                Schema->selected(),
+                Qt::EditRole);
+        }
     }
 }
 
 void toAnalyze::selectPlan(void)
 {
-    QListViewItem *item = Plans->selectedItem();
-    if (item)
-        CurrentPlan->query("SAVED:" + item->text(0));
-}
-
-void toAnalyze::windowActivated(QWidget *widget)
-{
-    if (widget == this)
-    {
-        if (!ToolMenu)
-        {
-            ToolMenu = new QPopupMenu(this);
-            ToolMenu->insertItem(QPixmap(const_cast<const char**>(refresh_xpm)), tr("&Refresh"),
-                                 this, SLOT(refresh(void)), toKeySequence(tr("F5", "Statistics|Refresh")));
-
-            toMainWidget()->menuBar()->insertItem(tr("&Statistics"), ToolMenu, -1, toToolMenuIndex());
-        }
-    }
-    else
-    {
-        delete ToolMenu;
-        ToolMenu = NULL;
-    }
+    QModelIndex index = Plans->selectedIndex();
+    if (index.isValid())
+        CurrentPlan->query("SAVED:" + index.data(Qt::EditRole).toString());
 }
 
 toWorksheetStatistic *toAnalyze::worksheet(void)
 {
-    Tabs->showPage(Worksheet);
+    Tabs->setCurrentIndex(Tabs->indexOf(Worksheet));
     return Worksheet;
 }
 
@@ -389,7 +480,7 @@ void toAnalyze::refresh(void)
         Statistics->setSQL(QString::null);
         toQList par;
         QString sql;
-        if (!Type || Type->currentItem() == 0)
+        if (!Type || Type->currentIndex() == 0)
             sql = toSQL::string(SQLListTables, connection());
         else
             sql = toSQL::string(SQLListIndex, connection());
@@ -398,6 +489,12 @@ void toAnalyze::refresh(void)
             par.insert(par.end(), Schema->selected());
             if (toIsOracle(connection()))
                 sql += "\n   AND owner = :own<char[100]>";
+            else if (toIsPostgreSQL(connection()))
+            {
+                sql =
+                    QString(" SELECT * FROM ( %1 ) sub\n"
+                            "  WHERE schemaname = :own<char[100]>").arg(sql);
+            }
             else
                 sql += " FROM :f1<noquote>";
         }
@@ -405,7 +502,7 @@ void toAnalyze::refresh(void)
             sql += " FROM :f1<alldatabases>";
         if (Analyzed)
         {
-            switch (Analyzed->currentItem())
+            switch (Analyzed->currentIndex())
             {
             default:
                 break;
@@ -420,7 +517,7 @@ void toAnalyze::refresh(void)
 
         Statistics->query(sql, (const toQList &)par);
     }
-    TOCATCH
+    TOCATCH;
 }
 
 void toAnalyze::poll(void)
@@ -460,7 +557,7 @@ void toAnalyze::poll(void)
                 QString sql = toShift(Pending);
                 if (!sql.isEmpty())
                 {
-                    delete (*i);
+                    delete(*i);
                     toQList par;
                     (*i) = new toNoBlockQuery(connection(), sql, par);
                     running++;
@@ -478,23 +575,23 @@ void toAnalyze::poll(void)
         else
             Current->setText(tr("Running %1 Pending %2").arg(running).arg(Pending.size()));
     }
-    TOCATCH
+    TOCATCH;
 }
 
 std::list<QString> toAnalyze::getSQL(void)
 {
     std::list<QString> ret;
-    for (QListViewItem *item = Statistics->firstChild();item;item = item->nextSibling())
+    for (toResultTableView::iterator it(Statistics); (*it).isValid(); it++)
     {
-        if (item->isSelected())
+        if (Statistics->isRowSelected((*it)))
         {
             if (toIsOracle(connection()))
             {
                 QString sql = QString::fromLatin1("ANALYZE %3 %1.%2 ");
                 QString forc;
-                if (item->text(0) == QString::fromLatin1("TABLE"))
+                if ((*it).data(Qt::EditRole) == QString::fromLatin1("TABLE"))
                 {
-                    switch (For->currentItem())
+                    switch (For->currentIndex())
                     {
                     case 0:
                         forc = QString::null;
@@ -511,7 +608,7 @@ std::list<QString> toAnalyze::getSQL(void)
                     }
                 }
 
-                switch (Operation->currentItem())
+                switch (Operation->currentIndex())
                 {
                 case 0:
                     sql += QString::fromLatin1("COMPUTE STATISTICS");
@@ -529,13 +626,37 @@ std::list<QString> toAnalyze::getSQL(void)
                     sql += QString::fromLatin1("VALIDATE REF UPDATE");
                     break;
                 }
-                toPush(ret, sql.arg(item->text(1)).arg(item->text(2)).arg(item->text(0)));
+                toPush(ret,
+                       sql.arg(Statistics->model()->data((*it).row(), 2).toString())
+                       .arg(Statistics->model()->data((*it).row(), 3).toString())
+                       .arg(Statistics->model()->data((*it).row(), 1).toString()));
 
             }
+            else if (toIsPostgreSQL(connection()))
+            {
+                QString sql;
+
+                switch (Operation->currentIndex())
+                {
+                case 0:
+                    sql += QString("VACUUM FULL VERBOSE %1.%2");
+                    break;
+                case 1:
+                    sql += QString("ANALYZE VERBOSE %1.%2");
+                    break;
+                default:
+                    toStatusMessage(tr("Internal Error"));
+                    continue;
+                }
+
+                QString table = Statistics->model()->data((*it).row(), 3).toString();
+                QString schema = Statistics->model()->data((*it).row(), 2).toString();
+                toPush(ret, sql.arg(schema).arg(table));
+            }
             else
             {
                 QString sql;
-                switch (Operation->currentItem())
+                switch (Operation->currentIndex())
                 {
                 case 0:
                     sql = QString::fromLatin1("ANALYZE TABLE %1.%2 ");
@@ -544,10 +665,12 @@ std::list<QString> toAnalyze::getSQL(void)
                     sql = QString::fromLatin1("OPTIMIZE TABLE %1.%2 ");
                     break;
                 }
-                QString owner = item->text(0);
+                QString owner = Statistics->model()->data((*it).row(), 2).toString();
                 if (toUnnull(owner).isNull())
                     owner = Schema->selected();
-                toPush(ret, sql.arg(owner).arg(item->text(1)));
+                toPush(ret,
+                       sql.arg(owner).arg(
+                           Statistics->model()->data((*it).row(), 1).toString()));
             }
         }
     }
@@ -574,7 +697,7 @@ void toAnalyze::execute(void)
     try
     {
         toQList par;
-        for (int i = 0;i < Parallel->value();i++)
+        for (int i = 0; i < Parallel->value(); i++)
         {
             QString sql = toShift(Pending);
             if (!sql.isEmpty())
@@ -584,7 +707,7 @@ void toAnalyze::execute(void)
         Stop->setEnabled(true);
         poll();
     }
-    TOCATCH
+    TOCATCH;
 }
 
 void toAnalyze::stop(void)
@@ -602,11 +725,10 @@ void toAnalyze::stop(void)
             {
                 connection().rollback();
             }
-            catch (...)
-            { }
+            catch (...) { }
         }
     }
-    TOCATCH
+    TOCATCH;
 }
 
 void toAnalyze::createTool(void)
@@ -614,11 +736,25 @@ void toAnalyze::createTool(void)
     AnalyzeTool.createWindow();
 }
 
-void toAnalyze::displayMenu(QPopupMenu *menu)
+void toAnalyze::displayMenu(QMenu *menu)
 {
-    menu->insertSeparator(0);
-    menu->insertItem(QPixmap(const_cast<const char**>(sql_xpm)), tr("Display SQL"), this, SLOT(displaySQL()), 0, 0, 0);
-    menu->insertItem(QPixmap(const_cast<const char**>(execute_xpm)), tr("Execute"), this, SLOT(execute()), 0, 0, 0);
-    menu->insertSeparator(0);
-    menu->insertItem(QPixmap(const_cast<const char**>(refresh_xpm)), tr("Refresh"), this, SLOT(refresh()), 0, 0, 0);
+    QAction *before = menu->actions()[0];
+
+    menu->insertSeparator(before);
+
+    QAction *action;
+
+    action = new QAction(QIcon(QPixmap(const_cast<const char**>(sql_xpm))),
+                         tr("Display SQL"),
+                         menu);
+    connect(action, SIGNAL(triggered()), this, SLOT(displaySQL()));
+    menu->insertAction(before, action);
+
+    action = new QAction(QIcon(QPixmap(const_cast<const char**>(execute_xpm))),
+                         tr("Execute"),
+                         menu);
+    connect(action, SIGNAL(triggered()), this, SLOT(execute()));
+    menu->insertAction(before, action);
+
+    menu->insertSeparator(before);
 }
