@@ -1,39 +1,43 @@
-/*****
-*
-* TOra - An Oracle Toolkit for DBA's and developers
-* Copyright (C) 2003-2005 Quest Software, Inc
-* Portions Copyright (C) 2005 Other Contributors
-* 
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License
-* as published by the Free Software Foundation;  only version 2 of
-* the License is valid for this program.
-* 
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-* 
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*
-*      As a special exception, you have permission to link this program
-*      with the Oracle Client libraries and distribute executables, as long
-*      as you follow the requirements of the GNU GPL in regard to all of the
-*      software in the executable aside from Oracle client libraries.
-*
-*      Specifically you are not permitted to link this program with the
-*      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
-*      And you are not permitted to distribute binaries compiled against
-*      these libraries without written consent from Quest Software, Inc.
-*      Observe that this does not disallow linking to the Qt Free Edition.
-*
-*      You may link this product with any GPL'd Qt library such as Qt/Free
-*
-* All trademarks belong to their respective owners.
-*
-*****/
+
+/* BEGIN_COMMON_COPYRIGHT_HEADER
+ *
+ * TOra - An Oracle Toolkit for DBA's and developers
+ * 
+ * Shared/mixed copyright is held throughout files in this product
+ * 
+ * Portions Copyright (C) 2000-2001 Underscore AB
+ * Portions Copyright (C) 2003-2005 Quest Software, Inc.
+ * Portions Copyright (C) 2004-2008 Numerous Other Contributors
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation;  only version 2 of
+ * the License is valid for this program.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ *      As a special exception, you have permission to link this program
+ *      with the Oracle Client libraries and distribute executables, as long
+ *      as you follow the requirements of the GNU GPL in regard to all of the
+ *      software in the executable aside from Oracle client libraries.
+ * 
+ *      Specifically you are not permitted to link this program with the
+ *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
+ *      And you are not permitted to distribute binaries compiled against
+ *      these libraries. 
+ * 
+ *      You may link this product with any GPL'd Qt library.
+ * 
+ * All trademarks belong to their respective owners.
+ *
+ * END_COMMON_COPYRIGHT_HEADER */
 
 #include "utils.h"
 
@@ -41,26 +45,22 @@
 #include "tochangeconnection.h"
 #include "toconf.h"
 #include "tomain.h"
-#include "toresultlong.h"
+#include "toresulttableview.h"
 #include "tosql.h"
 #include "totool.h"
 
-#ifdef TO_KDE
-#  include <kmenubar.h>
-#endif
-
 #include <qlabel.h>
 #include <qmenubar.h>
-#include <qpopupmenu.h>
 #include <qtabwidget.h>
 #include <qtoolbar.h>
 #include <qtoolbutton.h>
-#include <qworkspace.h>
+#include <QMdiArea>
+
+#include <QPixmap>
+#include <QVBoxLayout>
 
 #include <loki/Singleton.h>
 
-#include "tobackup.moc"
-
 #include "icons/refresh.xpm"
 
 
@@ -318,59 +318,80 @@ static toSQL SQLCurrentBackup7("toBackup:CurrentBackup",
                                "0703");
 
 toBackup::toBackup(toTool* tool, QWidget *main, toConnection &connection)
-        : toToolWidget(*tool, "backup.html", main, connection) , tool_(tool)
+        : toToolWidget(*tool, "backup.html", main, connection, "toBackup")
+        , tool_(tool)
 {
     QToolBar *toolbar = toAllocBar(this, tr("Backup Manager"));
+    layout()->addWidget(toolbar);
 
-    new QToolButton(QPixmap(const_cast<const char**>(refresh_xpm)),
-                    tr("Update"),
-                    tr("Update"),
-                    this, SLOT(refresh(void)),
-                    toolbar);
-    toolbar->setStretchableWidget(new QLabel(toolbar, TO_KDE_TOOLBAR_WIDGET));
-    new toChangeConnection(toolbar, TO_KDE_TOOLBAR_WIDGET);
+    updateAct = new QAction(QPixmap(const_cast<const char**>(refresh_xpm)),
+                            tr("Update"), this);
+    updateAct->setShortcut(QKeySequence::Refresh);
+    connect(updateAct, SIGNAL(triggered()), this, SLOT(refresh(void)));
+    toolbar->addAction(updateAct);
+
+    toolbar->addWidget(new toSpacer());
+
+    new toChangeConnection(toolbar, TO_TOOLBAR_WIDGET_NAME);
 
     Tabs = new QTabWidget(this);
+    layout()->addWidget(Tabs);
 
-    QVBox *box = new QVBox(Tabs, "history");
-    new QLabel(tr("Logswitches per day and hour"), box);
-    LogSwitches = new toResultLong(true, false, toQuery::Background, box);
+    QWidget *box = new QWidget(Tabs);
+    QVBoxLayout *vbox = new QVBoxLayout;
+    vbox->setSpacing(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
+    box->setLayout(vbox);
+
+    vbox->addWidget(new QLabel(tr("Logswitches per day and hour"), box));
+    LogSwitches = new toResultTableView(true, false, box);
     LogSwitches->setSQL(SQLLogSwitches);
+    vbox->addWidget(LogSwitches);
     Tabs->addTab(box, tr("Redo Switches"));
 
-    LogHistory = new toResultLong(true, false, toQuery::Background, Tabs);
+    LogHistory = new toResultTableView(true, false, Tabs);
     LogHistory->setSQL(SQLLogHistory);
     Tabs->addTab(LogHistory, tr("Archived Logs"));
 
-    box = new QVBox(Tabs);
+    box = new QWidget(Tabs);
+    vbox = new QVBoxLayout;
+    vbox->setSpacing(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
+    box->setLayout(vbox);
+
     LastLabel = new QLabel(box);
-    LastBackup = new toResultLong(true, false, toQuery::Background, box);
+    vbox->addWidget(LastLabel);
+    LastBackup = new toResultTableView(true, false, box);
+    vbox->addWidget(LastBackup);
     LastBackup->setSQL(SQLLastBackup);
     Tabs->addTab(box, tr("Last Backup"));
 
-    CurrentBackup = new toResultLong(true, false, toQuery::Background, Tabs);
+    CurrentBackup = new toResultTableView(true, false, Tabs);
     CurrentBackup->setSQL(SQLCurrentBackup);
     Tabs->addTab(CurrentBackup, tr("Backup Progress"));
 
     ToolMenu = NULL;
-    connect(toMainWidget()->workspace(), SIGNAL(windowActivated(QWidget *)),
-            this, SLOT(windowActivated(QWidget *)));
+    connect(toMainWidget()->workspace(), SIGNAL(subWindowActivated(QMdiSubWindow *)),
+            this, SLOT(windowActivated(QMdiSubWindow *)));
 
     refresh();
 
     setFocusProxy(Tabs);
 }
 
-void toBackup::windowActivated(QWidget *widget)
+void toBackup::windowActivated(QMdiSubWindow *widget)
 {
-    if (widget == this)
+    if (!widget)
+        return;
+    if (widget->widget() == this)
     {
         if (!ToolMenu)
         {
-            ToolMenu = new QPopupMenu(this);
-            ToolMenu->insertItem(QPixmap(const_cast<const char**>(refresh_xpm)), tr("&Refresh"),
-                                 this, SLOT(refresh(void)), toKeySequence(tr("F5", "Backup|Refresh")));
-            toMainWidget()->menuBar()->insertItem(tr("&Backup Manager"), ToolMenu, -1, toToolMenuIndex());
+            ToolMenu = new QMenu(tr("&Backup Manager"), this);
+
+            ToolMenu->addAction(updateAct);
+
+            toMainWidget()->addCustomMenu(ToolMenu);
         }
     }
     else
@@ -400,7 +421,7 @@ void toBackup::refresh()
         val = query.readValue().toInt();
     }
     catch (...)
-    {}
+        {}
     if (val == 0)
         LastLabel->setText(tr("This appears to be a cold backup database"));
     else
