@@ -1,40 +1,45 @@
-/*****
-*
-* TOra - An Oracle Toolkit for DBA's and developers
-* Copyright (C) 2003-2005 Quest Software, Inc
-* Portions Copyright (C) 2005 Other Contributors
-* 
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License
-* as published by the Free Software Foundation;  only version 2 of
-* the License is valid for this program.
-* 
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-* 
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*
-*      As a special exception, you have permission to link this program
-*      with the Oracle Client libraries and distribute executables, as long
-*      as you follow the requirements of the GNU GPL in regard to all of the
-*      software in the executable aside from Oracle client libraries.
-*
-*      Specifically you are not permitted to link this program with the
-*      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
-*      And you are not permitted to distribute binaries compiled against
-*      these libraries without written consent from Quest Software, Inc.
-*      Observe that this does not disallow linking to the Qt Free Edition.
-*
-*      You may link this product with any GPL'd Qt library such as Qt/Free
-*
-* All trademarks belong to their respective owners.
-*
-*****/
 
+/* BEGIN_COMMON_COPYRIGHT_HEADER
+ *
+ * TOra - An Oracle Toolkit for DBA's and developers
+ * 
+ * Shared/mixed copyright is held throughout files in this product
+ * 
+ * Portions Copyright (C) 2000-2001 Underscore AB
+ * Portions Copyright (C) 2003-2005 Quest Software, Inc.
+ * Portions Copyright (C) 2004-2008 Numerous Other Contributors
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation;  only version 2 of
+ * the License is valid for this program.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ *      As a special exception, you have permission to link this program
+ *      with the Oracle Client libraries and distribute executables, as long
+ *      as you follow the requirements of the GNU GPL in regard to all of the
+ *      software in the executable aside from Oracle client libraries.
+ * 
+ *      Specifically you are not permitted to link this program with the
+ *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
+ *      And you are not permitted to distribute binaries compiled against
+ *      these libraries. 
+ * 
+ *      You may link this product with any GPL'd Qt library.
+ * 
+ * All trademarks belong to their respective owners.
+ *
+ * END_COMMON_COPYRIGHT_HEADER */
+
+#include "tochartmanager.h"
 #include "utils.h"
 
 #include "tobarchart.h"
@@ -48,10 +53,6 @@
 
 #include <ctype.h>
 
-#ifdef TO_KDE
-#  include <kmenubar.h>
-#endif
-
 #include <qcheckbox.h>
 #include <qcombobox.h>
 #include <qlabel.h>
@@ -59,15 +60,13 @@
 #include <qlineedit.h>
 #include <qmenubar.h>
 #include <qmessagebox.h>
-#include <qpopupmenu.h>
 #include <qtoolbar.h>
 #include <qtoolbutton.h>
 #include <qvalidator.h>
-#include <qworkspace.h>
+#include <QMdiArea>
 
-#include "tochartalarmui.moc"
-#include "tochartmanager.moc"
-#include "tochartsetupui.moc"
+#include <QString>
+#include <QPixmap>
 
 #include "icons/chart.xpm"
 #include "icons/fileopen.xpm"
@@ -88,22 +87,27 @@ public:
     {
         if (!Handler)
             return NULL;
-        if (!Window)
+
+        if (Window)
         {
-            Window = new toChartManager(toMainWidget()->workspace());
-            Window->setCaption(qApp->translate("toChartTool", "Chart Manager"));
-            Window->setIcon(QPixmap(const_cast<const char**>(chart_xpm)));
+            Window->setFocus(Qt::OtherFocusReason);
+            // already opened, prevent creating new sub window
+            return 0;
         }
+
+        Window = new toChartManager(toMainWidget()->workspace());
+        Window->setWindowTitle(qApp->translate("toChartTool", "Chart Manager"));
+        Window->setWindowIcon(QPixmap(const_cast<const char**>(chart_xpm)));
         Window->refresh();
-        Window->show();
-        Window->raise();
-        Window->setFocus();
         return Window;
     }
-    virtual void customSetup(int toolid)
+    virtual void customSetup()
     {
-        toMainWidget()->editMenu()->insertItem(QPixmap(const_cast<const char**>(chart_xpm)),
-                                               qApp->translate("toChartTool", "Chart Manager..."), toolid);
+        toMainWidget()->getEditMenu()->addAction(
+            QIcon(chart_xpm),
+            qApp->translate("toChartTool", "Chart Manager..."),
+            this,
+            SLOT(createWindow()));
 
         Handler = new toChartHandler();
     }
@@ -134,111 +138,124 @@ public:
 
 static toChartTool ChartTool;
 
-class toChartAlarm : public toChartAlarmUI
+toChartAlarm::toChartAlarm(QWidget *parent,
+                           const char *name,
+                           bool modal,
+                           Qt::WFlags fl)
+        : QDialog(parent)
 {
-public:
-    toChartAlarm(QWidget *parent = 0, const char *name = 0, bool modal = FALSE, WFlags fl = 0)
-            : toChartAlarmUI(parent, name, modal, fl)
-    { }
-    virtual void changeValue(int val)
-    {
-        if (val == 1)
-            ExtraLabel->setText(qApp->translate("toChartAlarm", "Email"));
-        else
-            ExtraLabel->setText(QString::null);
+    setupUi(this);
+}
 
-        Extra->setEnabled(val == 1);
-    }
-};
-
-class toChartSetup : public toChartSetupUI
+void toChartAlarm::changeValue(int val)
 {
-    toLineChart *Chart;
-public:
-    toChartSetup(toLineChart *chart, QWidget* parent, const char* name, bool modal)
-            : toChartSetupUI(parent, name, modal)
-    {
-        Chart = chart;
-    }
+    if (val == 1)
+        ExtraLabel->setText(qApp->translate("toChartAlarm", "Email"));
+    else
+        ExtraLabel->setText(QString::null);
 
-    virtual void browseFile()
+    Extra->setEnabled(val == 1);
+}
+
+toChartSetup::toChartSetup(toLineChart *chart,
+                           QWidget* parent,
+                           const char* name,
+                           bool modal)
+        : QDialog(parent)
+{
+
+    setupUi(this);
+    Chart = chart;
+
+    connect(BrowseButton, SIGNAL(clicked()), this, SLOT(browseFile()));
+    connect(AddButton, SIGNAL(clicked()), this, SLOT(addAlarm()));
+    connect(RemoveButton, SIGNAL(clicked()), this, SLOT(removeAlarm()));
+    connect(ModifyButton, SIGNAL(clicked()), this, SLOT(modifyAlarm()));
+}
+
+
+void toChartSetup::browseFile()
+{
+    QString str = toOpenFilename(Filename->text(), QString::fromLatin1("*.csv"), this);
+    if (!str.isEmpty())
+        Filename->setText(str);
+}
+
+
+QString toChartSetup::modifyAlarm(const QString &str, bool &persistent)
+{
+    toChartManager::chartAlarm alarm(str, persistent);
+    toChartAlarm diag(this, NULL, true);
+    diag.Operation->setCurrentIndex((int)alarm.Operation);
+    diag.Comparison->setCurrentIndex((int)alarm.Comparison);
+    diag.Action->setCurrentIndex((int)alarm.Action);
+    diag.Value->setText(QString::number(alarm.Value));
+    diag.changeValue((int)alarm.Action);
+    diag.Value->setValidator(new QDoubleValidator(diag.Value));
+    diag.Extra->setText(alarm.Extra);
+    std::list<int>::iterator sel = alarm.Columns.begin();
+    diag.Charts->addColumn(qApp->translate("toChartSetup", "Charts"));
+    diag.Charts->setSelectionMode(toTreeWidget::Multi);
+    toTreeWidgetItem *item = NULL;
+    std::list<QString>::iterator lab = Chart->labels().begin();
+    for (int i = 0;lab != Chart->labels().end();i++, lab++)
     {
-        QString str = toOpenFilename(Filename->text(), QString::fromLatin1("*.csv"), this);
+        item = new toTreeWidgetItem(diag.Charts, item, *lab);
+        if (sel != alarm.Columns.end() && *sel == i)
+        {
+            item->setSelected(true);
+            sel++;
+        }
+    }
+    diag.Persistent->setChecked(persistent);
+    if (diag.exec())
+    {
+        persistent = diag.Persistent->isChecked();
+        int i = 0;
+        alarm.Columns.clear();
+        for (toTreeWidgetItem *item = diag.Charts->firstChild();item;item = item->nextSibling())
+        {
+            if (item->isSelected())
+                alarm.Columns.insert(alarm.Columns.end(), i);
+            i++;
+        }
+        alarm.Action = (toChartManager::action)diag.Action->currentIndex();
+        alarm.Operation = (toChartManager::chartAlarm::operation)diag.Operation->currentIndex();
+        alarm.Comparison = (toChartManager::chartAlarm::comparison)diag.Comparison->currentIndex();
+        alarm.Value = diag.Value->text().toDouble();
+        alarm.Extra = diag.Extra->text();
+        return alarm.toString();
+    }
+    return QString::null;
+}
+
+void toChartSetup::addAlarm()
+{
+    toChartManager::chartAlarm alarm;
+    QString str = modifyAlarm(alarm.toString(), alarm.Persistent);
+    if (!str.isEmpty())
+        new toTreeWidgetItem(Alarms, str, alarm.Persistent ? qApp->translate("toChartSetup", "Persistent") : qApp->translate("toChartSetup", "Temporary"));
+}
+
+void toChartSetup::modifyAlarm()
+{
+    toTreeWidgetItem *item = Alarms->selectedItem();
+    if (item)
+    {
+        bool pers = item->text(1) == qApp->translate("toChartSetup", "Persistent");
+        QString str = modifyAlarm(item->text(0), pers);
         if (!str.isEmpty())
-            Filename->setText(str);
-    }
-    virtual QString modifyAlarm(const QString &str, bool &persistent)
-    {
-        toChartManager::chartAlarm alarm(str, persistent);
-        toChartAlarm diag(this, NULL, true);
-        diag.Operation->setCurrentItem((int)alarm.Operation);
-        diag.Comparison->setCurrentItem((int)alarm.Comparison);
-        diag.Action->setCurrentItem((int)alarm.Action);
-        diag.Value->setText(QString::number(alarm.Value));
-        diag.changeValue((int)alarm.Action);
-        diag.Value->setValidator(new QDoubleValidator(diag.Value));
-        diag.Extra->setText(alarm.Extra);
-        std::list<int>::iterator sel = alarm.Columns.begin();
-        diag.Charts->addColumn(qApp->translate("toChartSetup", "Charts"));
-        diag.Charts->setSelectionMode(QListView::Multi);
-        QListViewItem *item = NULL;
-        std::list<QString>::iterator lab = Chart->labels().begin();
-        for (int i = 0;lab != Chart->labels().end();i++, lab++)
         {
-            item = new QListViewItem(diag.Charts, item, *lab);
-            if (sel != alarm.Columns.end() && *sel == i)
-            {
-                item->setSelected(true);
-                sel++;
-            }
-        }
-        diag.Persistent->setChecked(persistent);
-        if (diag.exec())
-        {
-            persistent = diag.Persistent->isChecked();
-            int i = 0;
-            alarm.Columns.clear();
-            for (QListViewItem *item = diag.Charts->firstChild();item;item = item->nextSibling())
-            {
-                if (item->isSelected())
-                    alarm.Columns.insert(alarm.Columns.end(), i);
-                i++;
-            }
-            alarm.Action = (toChartManager::action)diag.Action->currentItem();
-            alarm.Operation = (toChartManager::chartAlarm::operation)diag.Operation->currentItem();
-            alarm.Comparison = (toChartManager::chartAlarm::comparison)diag.Comparison->currentItem();
-            alarm.Value = diag.Value->text().toDouble();
-            alarm.Extra = diag.Extra->text();
-            return alarm.toString();
-        }
-        return QString::null;
-    }
-    virtual void addAlarm()
-    {
-        toChartManager::chartAlarm alarm;
-        QString str = modifyAlarm(alarm.toString(), alarm.Persistent);
-        if (!str.isEmpty())
-            new QListViewItem(Alarms, str, alarm.Persistent ? qApp->translate("toChartSetup", "Persistent") : qApp->translate("toChartSetup", "Temporary"));
-    }
-    virtual void modifyAlarm()
-    {
-        QListViewItem *item = Alarms->selectedItem();
-        if (item)
-        {
-            bool pers = item->text(1) == qApp->translate("toChartSetup", "Persistent");
-            QString str = modifyAlarm(item->text(0), pers);
-            if (!str.isEmpty())
-            {
-                item->setText(0, str);
-                item->setText(1, pers ? qApp->translate("toChartSetup", "Persistent") : qApp->translate("toChartSetup", "Temporary"));
-            }
+            item->setText(0, str);
+            item->setText(1, pers ? qApp->translate("toChartSetup", "Persistent") : qApp->translate("toChartSetup", "Temporary"));
         }
     }
-    virtual void removeAlarm()
-    {
-        delete Alarms->selectedItem();
-    }
-};
+}
+
+void toChartSetup::removeAlarm()
+{
+    delete Alarms->selectedItem();
+}
 
 toChartReceiver::toChartReceiver(toChartHandler *parent, toLineChart *chart)
         : QObject(parent)
@@ -263,10 +280,10 @@ QString toChartReceiver::name(void)
         return QString::null;
     try
     {
-        LastName = Result->connection().description(false) + QString::fromLatin1(":") + QString::fromLatin1(Result->sqlName());
+        LastName = Result->connection().description(false) + QString(":") + QString(Result->sqlName());
     }
     catch (...)
-    {}
+        {}
     return LastName;
 }
 
@@ -276,28 +293,31 @@ void toChartReceiver::valueAdded(std::list<double> &value, const QString &xValue
 }
 
 toChartManager::toChartManager(QWidget *main)
-        : QVBox(main), toHelpContext(QString::fromLatin1("chartmanager.html"))
+        : QWidget(main), toHelpContext(QString::fromLatin1("chartmanager.html"))
 {
+
+    QVBoxLayout *vbox = new QVBoxLayout;
+
     QToolBar *toolbar = toAllocBar(this, tr("Chart Manager"));
+    vbox->addWidget(toolbar);
+
+    toolbar->addAction(QIcon(refresh_xpm),
+                       tr("Refresh list"),
+                       this,
+                       SLOT(refresh()));
 
-    new QToolButton(QPixmap(const_cast<const char**>(refresh_xpm)),
-                    tr("Refresh list"),
-                    tr("Refresh list"),
-                    this, SLOT(refresh()),
-                    toolbar);
     toolbar->addSeparator();
-    new QToolButton(QPixmap(const_cast<const char**>(fileopen_xpm)),
-                    tr("Open tracker file"),
-                    tr("Open tracker file"),
-                    this, SLOT(openChart()),
-                    toolbar);
-    new QToolButton(QPixmap(const_cast<const char**>(chart_xpm)),
-                    tr("Setup chart"),
-                    tr("Setup chart"),
-                    this, SLOT(setupChart()),
-                    toolbar);
 
-    toolbar->setStretchableWidget(new QLabel(toolbar, TO_KDE_TOOLBAR_WIDGET));
+    toolbar->addAction(QIcon(fileopen_xpm),
+                       tr("Open tracker file"),
+                       this,
+                       SLOT(openChart()));
+    toolbar->addAction(QIcon(chart_xpm),
+                       tr("Setup chart"),
+                       this,
+                       SLOT(setupChart()));
+
+    toolbar->addWidget(new toSpacer());
 
     List = new toListView(this);
     List->addColumn(tr("Connection"));
@@ -306,35 +326,16 @@ toChartManager::toChartManager(QWidget *main)
     List->addColumn(tr("Tracking"));
     List->addColumn(tr("Alarms"));
     List->setSorting(2);
-    List->setSelectionMode(QListView::Single);
+    List->setSelectionMode(toTreeWidget::Single);
+    vbox->addWidget(List);
 
-    ToolMenu = NULL;
-    connect(toMainWidget()->workspace(), SIGNAL(windowActivated(QWidget *)),
-            this, SLOT(windowActivated(QWidget *)));
     connect(&Refresh, SIGNAL(timeout()), this, SLOT(refresh()));
 
     setFocusProxy(List);
-}
 
-void toChartManager::windowActivated(QWidget *widget)
-{
-    if (widget == this)
-    {
-        if (!ToolMenu)
-        {
-            ToolMenu = new QPopupMenu(this);
-            ToolMenu->insertItem(QPixmap(const_cast<const char**>(refresh_xpm)), tr("&Refresh"),
-                                 this, SLOT(refresh(void)),
-                                 toKeySequence(tr("F5", "Chart Manager|Refresh")));
-
-            toMainWidget()->menuBar()->insertItem(tr("&Chart Manager"), ToolMenu, -1, toToolMenuIndex());
-        }
-    }
-    else
-    {
-        delete ToolMenu;
-        ToolMenu = NULL;
-    }
+    vbox->setSpacing(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
+    setLayout(vbox);
 }
 
 toChartManager::~toChartManager()
@@ -347,7 +348,10 @@ void toChartHandler::addChart(toLineChart *chart)
     Charts.insert(Charts.end(), new toChartReceiver(this, chart));
     toChartManager *manager = ChartTool.manager();
     if (manager)
-        manager->Refresh.start(1, true);
+    {
+        manager->Refresh.setSingleShot(true);
+        manager->Refresh.start(1);
+    }
 }
 
 void toChartHandler::removeChart(toLineChart *chart)
@@ -392,7 +396,10 @@ void toChartHandler::removeChart(toLineChart *chart)
             Charts.erase(i);
             toChartManager *manager = ChartTool.manager();
             if (manager)
-                manager->Refresh.start(1, true);
+            {
+                manager->Refresh.setSingleShot(true);
+                manager->Refresh.start(1);
+            }
             return ;
         }
     }
@@ -414,7 +421,7 @@ toChartManager::chartAlarm::chartAlarm(const QString &inp, bool pers)
     Persistent = pers;
 
     // The \01 is just one character unlikely to be in an email address
-    int ret = sscanf(inp.utf8(), "%s %s %s %lf %s %[^\01]", oper, cols, comp, &Value, act, extra);
+    int ret = sscanf(inp.toUtf8(), "%s %s %s %lf %s %[^\01]", oper, cols, comp, &Value, act, extra);
     if (ret != 5 && ret != 6)
     {
         Operation = Any;
@@ -441,8 +448,8 @@ toChartManager::chartAlarm::chartAlarm(const QString &inp, bool pers)
     t = QString::fromUtf8(cols);
     if (t.length() > 2)
     {
-        QStringList lst = QStringList::split(QString::fromLatin1(","), t.mid(1, t.length() - 2));
-        for (unsigned int i = 0;i < lst.count();i++)
+        QStringList lst = t.mid(1, t.length() - 2).split(",");
+        for (int i = 0;i < lst.count();i++)
             Columns.insert(Columns.end(), lst[i].toInt());
         Columns.sort();
     }
@@ -629,15 +636,15 @@ void toChartManager::chartAlarm::valueAdded(toChartHandler *handler,
     switch (Operation)
     {
     case Any:
-        {
-            for (std::list<double>::iterator i = vals.begin();i != vals.end();i++)
-                if (checkValue(*i))
-                {
-                    sig = true;
-                    break;
-                }
-        }
-        break;
+    {
+        for (std::list<double>::iterator i = vals.begin();i != vals.end();i++)
+            if (checkValue(*i))
+            {
+                sig = true;
+                break;
+            }
+    }
+    break;
     case All:
         sig = true;
         {
@@ -650,55 +657,55 @@ void toChartManager::chartAlarm::valueAdded(toChartHandler *handler,
         }
         break;
     case Sum:
-        {
-            double val = 0;
-            for (std::list<double>::iterator i = vals.begin();i != vals.end();i++)
-                val += *i;
-            sig = checkValue(val);
-        }
-        break;
+    {
+        double val = 0;
+        for (std::list<double>::iterator i = vals.begin();i != vals.end();i++)
+            val += *i;
+        sig = checkValue(val);
+    }
+    break;
     case Average:
-        {
-            double val = 0;
-            for (std::list<double>::iterator i = vals.begin();i != vals.end();i++)
-                val += *i;
-            sig = checkValue(val / vals.size());
-        }
-        break;
+    {
+        double val = 0;
+        for (std::list<double>::iterator i = vals.begin();i != vals.end();i++)
+            val += *i;
+        sig = checkValue(val / vals.size());
+    }
+    break;
     case Max:
+    {
+        bool first = true;
+        double val = 0;
+        for (std::list<double>::iterator i = vals.begin();i != vals.end();i++)
         {
-            bool first = true;
-            double val = 0;
-            for (std::list<double>::iterator i = vals.begin();i != vals.end();i++)
+            if (first)
             {
-                if (first)
-                {
-                    first = false;
-                    val = *i;
-                }
-                else
-                    val = std::max(*i, val);
+                first = false;
+                val = *i;
             }
-            sig = checkValue(val);
+            else
+                val = std::max(*i, val);
         }
-        break;
+        sig = checkValue(val);
+    }
+    break;
     case Min:
+    {
+        bool first = true;
+        double val = 0;
+        for (std::list<double>::iterator i = vals.begin();i != vals.end();i++)
         {
-            bool first = true;
-            double val = 0;
-            for (std::list<double>::iterator i = vals.begin();i != vals.end();i++)
+            if (first)
             {
-                if (first)
-                {
-                    first = false;
-                    val = *i;
-                }
-                else
-                    val = std::min(*i, val);
+                first = false;
+                val = *i;
             }
-            sig = checkValue(val);
+            else
+                val = std::min(*i, val);
         }
-        break;
+        sig = checkValue(val);
+    }
+    break;
     }
     if (sig)
     {
@@ -706,7 +713,8 @@ void toChartManager::chartAlarm::valueAdded(toChartHandler *handler,
             return ;
         handler->SignalAlarms.insert(handler->SignalAlarms.end(),
                                      alarmSignal(Action, xValue, str, toString(), Extra));
-        handler->Timer.start(1, true);
+        handler->Timer.setSingleShot(true);
+        handler->Timer.start(1);
         Signal = true;
     }
     else
@@ -716,21 +724,25 @@ void toChartManager::chartAlarm::valueAdded(toChartHandler *handler,
 void toChartHandler::saveSettings(void)
 {
     {
-        int num = 0;
+//         int num = 0;
+        ChartsMap c;
         for (std::map<QString, toChartManager::chartTrack>::iterator i = Files.begin();i != Files.end();i++)
         {
             if ((*i).second.Persistent)
             {
-                num++;
-                QCString name = QCString("Files:") + QString::number(num).latin1();
-                ChartTool.setConfig(name + ":Name", (*i).first);
-                ChartTool.setConfig(name + ":Spec", (*i).second.File.name());
+//                 num++;
+//                 QString name = QString("Files:") + QString::number(num).toLatin1();
+//                 ChartTool.setConfig(name + ":Name", (*i).first);
+//                 ChartTool.setConfig(name + ":Spec", (*i).second.File.fileName());
+                c[(*i).first] = (*i).second.File.fileName();
             }
         }
-        ChartTool.setConfig("FilesCount", QString::number(num));
+//         ChartTool.setConfig("FilesCount", QString::number(num));
+        toConfigurationSingle::Instance().setChartFiles(c);
     }
     {
-        int num = 0;
+        ChartsMap c;
+//         int num = 0;
         for (std::map<QString, std::list<toChartManager::chartAlarm> >::iterator i = Alarms.begin();
                 i != Alarms.end();i++)
         {
@@ -738,39 +750,55 @@ void toChartHandler::saveSettings(void)
             {
                 if ((*j).Persistent)
                 {
-                    num++;
-                    QCString name = QCString("Alarms:") + QString::number(num).latin1();
-                    ChartTool.setConfig(name + ":Name", (*i).first);
-                    ChartTool.setConfig(name + ":Spec", (*j).toString());
+//                     num++;
+//                     QString name = QString("Alarms:") + QString::number(num).toLatin1();
+//                     ChartTool.setConfig(name + ":Name", (*i).first);
+//                     ChartTool.setConfig(name + ":Spec", (*j).toString());
+                    c[(*i).first] = (*j).toString();
                 }
             }
         }
-        ChartTool.setConfig("AlarmCount", QString::number(num));
+//         ChartTool.setConfig("AlarmCount", QString::number(num));
+        toConfigurationSingle::Instance().setChartAlarms(c);
     }
     toConfigurationSingle::Instance().saveConfig();
 }
 
 void toChartHandler::loadSettings(void)
 {
+//     {
+//         for (int num = ChartTool.config("FilesCount", "0").toInt();num > 0;num--)
+//         {
+//             QString name = QString("Files:") + QString::number(num).toLatin1();
+//             QString t = ChartTool.config(name + ":Name", "");
+//             QString s = ChartTool.config(name + ":Spec", "");
+//             if (!t.isEmpty() && !s.isEmpty())
+//                 Files[t] = toChartManager::chartTrack(s, true);
+//         }
+//     }
+    ChartsMapIterator i(toConfigurationSingle::Instance().chartFiles());
+    while (i.hasNext())
     {
-        for (int num = ChartTool.config("FilesCount", "0").toInt();num > 0;num--)
-        {
-            QCString name = QCString("Files:") + QString::number(num).latin1();
-            QString t = ChartTool.config(name + ":Name", "");
-            QString s = ChartTool.config(name + ":Spec", "");
-            if (!t.isEmpty() && !s.isEmpty())
-                Files[t] = toChartManager::chartTrack(s, true);
-        }
+        i.next();
+        if (!i.key().isEmpty() && !i.value().isEmpty())
+            Files[i.key()] = toChartManager::chartTrack(i.value(), true);
     }
+//     {
+//         for (int num = ChartTool.config("AlarmCount", "0").toInt();num > 0;num--)
+//         {
+//             QString name = QString("Alarms:") + QString::number(num).toLatin1();
+//             QString t = ChartTool.config(name + ":Name", "");
+//             QString s = ChartTool.config(name + ":Spec", "");
+//             if (!t.isEmpty() && !s.isEmpty())
+//                 Alarms[t].insert(Alarms[t].end(), toChartManager::chartAlarm(s, true));
+//         }
+//     }
+    ChartsMapIterator i1(toConfigurationSingle::Instance().chartAlarms());
+    while (i1.hasNext())
     {
-        for (int num = ChartTool.config("AlarmCount", "0").toInt();num > 0;num--)
-        {
-            QCString name = QCString("Alarms:") + QString::number(num).latin1();
-            QString t = ChartTool.config(name + ":Name", "");
-            QString s = ChartTool.config(name + ":Spec", "");
-            if (!t.isEmpty() && !s.isEmpty())
-                Alarms[t].insert(Alarms[t].end(), toChartManager::chartAlarm(s, true));
-        }
+        i1.next();
+        if (!i1.key().isEmpty() && !i1.value().isEmpty())
+            Alarms[i1.key()].insert(Alarms[i1.key()].end(), toChartManager::chartAlarm(i1.value(), true));
     }
 }
 
@@ -811,44 +839,44 @@ void toChartHandler::valueAdded(toLineChart *chart,
         {
             if (!file.exists())
                 header = true;
-            file.open(IO_Raw | IO_WriteOnly | IO_Append);
+            file.open(QIODevice::Unbuffered | QIODevice::WriteOnly | QIODevice::Append);
         }
         if (file.isOpen())
         {
             static QRegExp quote(QString::fromLatin1("\""));
-            QCString out = "\"";
+            QString out = "\"";
             if (header)
             {
                 QString t = chart->title();
                 t.replace(quote, QString::fromLatin1("\"\""));
-                out += t.utf8();
+                out += t.toUtf8();
                 std::list<QString> labels = chart->labels();
                 for (std::list<QString>::iterator i = labels.begin();i != labels.end();i++)
                 {
                     out += "\";\"";
                     QString t = (*i);
                     t.replace(quote, QString::fromLatin1("\"\""));
-                    out += t.utf8();
+                    out += t.toUtf8();
                 }
                 out += "\"\n\"";
             }
             QString t = xValue;
             t.replace(quote, QString::fromLatin1("\"\""));
-            out += t.utf8();
+            out += t.toUtf8();
             for (std::list<double>::iterator i = value.begin();i != value.end();i++)
             {
                 out += "\";\"";
                 out += QString::number(*i);
             }
             out += "\"\n";
-            file.writeBlock(out, out.length());
+            file.write(out.toUtf8());
         }
     }
 }
 
-static QString ReadCSV(const QCString &data, unsigned int &pos, bool &nl)
+static QString ReadCSV(const QString &data, int &pos, bool &nl)
 {
-    QCString ret;
+    QString ret;
     if (data.at(pos) != '\"')
         throw qApp->translate("toChartManager", "Initial value didn't start with \" in CSV file");
     pos++;
@@ -865,13 +893,13 @@ static QString ReadCSV(const QCString &data, unsigned int &pos, bool &nl)
         throw qApp->translate("toChartManager", "Missing closing \" in CSV file");
     pos++;
     nl = false;
-    while (pos < data.length() && (isspace(data.at(pos)) || data.at(pos) == ',' || data.at(pos) == ';'))
+    while (pos < data.length() && (data.at(pos).isSpace() || data.at(pos) == ',' || data.at(pos) == ';'))
     {
         if (data.at(pos) == '\n')
             nl = true;
         pos++;
     }
-    return QString::fromUtf8(ret);
+    return ret;
 }
 
 void toChartManager::openChart(void)
@@ -881,8 +909,8 @@ void toChartManager::openChart(void)
     {
         try
         {
-            QCString data = toReadFile(name);
-            unsigned int pos = 0;
+            QString data = toReadFile(name);
+            int pos = 0;
 
             toLineChart *chart;
             switch (TOMessageBox::information(toMainWidget(),
@@ -893,12 +921,12 @@ void toChartManager::openChart(void)
                                               tr("Cancel")))
             {
             case 0:
-                chart = new toBarChart(toMainWidget()->workspace(), NULL,
-                                       WDestructiveClose);
+                chart = new toBarChart(toMainWidget()->workspace(), NULL);
+                chart->setAttribute(Qt::WA_DeleteOnClose);
                 break;
             case 1:
-                chart = new toLineChart(toMainWidget()->workspace(), NULL,
-                                        WDestructiveClose);
+                chart = new toLineChart(toMainWidget()->workspace(), NULL);
+                chart->setAttribute(Qt::WA_DeleteOnClose);
                 break;
             default:
                 return ;
@@ -935,7 +963,7 @@ toChartReceiver *toChartManager::selectedChart(void)
 {
     try
     {
-        QListViewItem *item = List->selectedItem();
+        toTreeWidgetItem *item = List->selectedItem();
         if (item && ChartTool.handler())
         {
             for (std::list<toChartReceiver *>::iterator i = ChartTool.handler()->Charts.begin();i != ChartTool.handler()->Charts.end();i++)
@@ -977,9 +1005,9 @@ void toChartHandler::setupChart(toLineChart *chart)
                 setup.Alarms->addColumn(tr("Alarms"));
                 setup.Alarms->addColumn(tr("Persistent"));
                 setup.Alarms->setSorting(0);
-                setup.Alarms->setSelectionMode(QListView::Single);
+                setup.Alarms->setSelectionMode(toTreeWidget::Single);
                 setup.Persistent->setChecked(file.Persistent);
-                setup.Filename->setText(file.File.name());
+                setup.Filename->setText(file.File.fileName());
                 if (!setup.Filename->text().isEmpty())
                     setup.Enabled->setChecked(true);
                 setup.ChartFrame->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,
@@ -990,10 +1018,11 @@ void toChartHandler::setupChart(toLineChart *chart)
                                              QSizePolicy::Preferred));
                 t->showLegend(false);
                 t->showAxisLegend(false);
+                setup.ChartFrame->layout()->addWidget(t);
                 for (std::list<toChartManager::chartAlarm>::iterator j = alarm.begin();j != alarm.end();j++)
-                    new QListViewItem(setup.Alarms,
-                                      (*j).toString(),
-                                      (*j).Persistent ? tr("Persistent") : tr("Temporary"));
+                    new toTreeWidgetItem(setup.Alarms,
+                                         (*j).toString(),
+                                         (*j).Persistent ? tr("Persistent") : tr("Temporary"));
 
                 if (setup.exec())
                 {
@@ -1010,7 +1039,7 @@ void toChartHandler::setupChart(toLineChart *chart)
                     if (fnda != Alarms.end())
                         Alarms.erase(fnda);
                     alarm.clear();
-                    for (QListViewItem *item = setup.Alarms->firstChild();
+                    for (toTreeWidgetItem *item = setup.Alarms->firstChild();
                             item;item = item->nextSibling())
                     {
                         alarm.insert(alarm.end(), toChartManager::chartAlarm(item->text(0),
@@ -1039,8 +1068,8 @@ void toChartManager::refresh(void)
             if (result)
             {
                 toResultViewItem *item = new toResultViewMLine(List,
-                                         NULL,
-                                         result->connection().description(false));
+                        NULL,
+                        result->connection().description(false));
                 item->setText(1, (*i)->chart()->title());
                 item->setText(2, result->sqlName());
                 QString name = (*i)->name();
@@ -1061,7 +1090,7 @@ void toChartManager::refresh(void)
 
                     std::map<QString, chartTrack>::iterator fndt = ChartTool.handler()->Files.find(name);
                     if (fndt != ChartTool.handler()->Files.end())
-                        item->setText(3, (*fndt).second.File.name());
+                        item->setText(3, (*fndt).second.File.fileName());
                 }
             }
         }
