@@ -1,65 +1,68 @@
-/*****
-*
-* TOra - An Oracle Toolkit for DBA's and developers
-* Copyright (C) 2003-2005 Quest Software, Inc
-* Portions Copyright (C) 2005 Other Contributors
-* 
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License
-* as published by the Free Software Foundation;  only version 2 of
-* the License is valid for this program.
-* 
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-* 
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*
-*      As a special exception, you have permission to link this program
-*      with the Oracle Client libraries and distribute executables, as long
-*      as you follow the requirements of the GNU GPL in regard to all of the
-*      software in the executable aside from Oracle client libraries.
-*
-*      Specifically you are not permitted to link this program with the
-*      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
-*      And you are not permitted to distribute binaries compiled against
-*      these libraries without written consent from Quest Software, Inc.
-*      Observe that this does not disallow linking to the Qt Free Edition.
-*
-*      You may link this product with any GPL'd Qt library such as Qt/Free
-*
-* All trademarks belong to their respective owners.
-*
-*****/
+
+/* BEGIN_COMMON_COPYRIGHT_HEADER
+ *
+ * TOra - An Oracle Toolkit for DBA's and developers
+ * 
+ * Shared/mixed copyright is held throughout files in this product
+ * 
+ * Portions Copyright (C) 2000-2001 Underscore AB
+ * Portions Copyright (C) 2003-2005 Quest Software, Inc.
+ * Portions Copyright (C) 2004-2008 Numerous Other Contributors
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation;  only version 2 of
+ * the License is valid for this program.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ *      As a special exception, you have permission to link this program
+ *      with the Oracle Client libraries and distribute executables, as long
+ *      as you follow the requirements of the GNU GPL in regard to all of the
+ *      software in the executable aside from Oracle client libraries.
+ * 
+ *      Specifically you are not permitted to link this program with the
+ *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
+ *      And you are not permitted to distribute binaries compiled against
+ *      these libraries. 
+ * 
+ *      You may link this product with any GPL'd Qt library.
+ * 
+ * All trademarks belong to their respective owners.
+ *
+ * END_COMMON_COPYRIGHT_HEADER */
 
 #include "utils.h"
 
 #include "toconf.h"
 #include "tolinechart.h"
-#include "tolinechartsetupui.h"
+#include "ui_tolinechartsetupui.h"
 #include "tomain.h"
 #include "toresultview.h"
 #include "totool.h"
 
-#ifdef TO_HAS_KPRINT
-#include <kprinter.h>
-#endif
-
 #include <qcheckbox.h>
 #include <qlineedit.h>
-#include <qpaintdevicemetrics.h>
 #include <qpainter.h>
-#include <qpopupmenu.h>
 #include <qprinter.h>
 #include <qspinbox.h>
 #include <qvalidator.h>
-#include <qworkspace.h>
+#include <QMdiArea>
 
-#include "tolinechart.moc"
-#include "tolinechartsetupui.moc"
+#include <QString>
+#include <QPixmap>
+#include <QMouseEvent>
+#include <QPaintEvent>
+#include <QScrollBar>
+#include <QMenu>
+#include <QPrintDialog>
 
 #include "icons/print.xpm"
 #include "icons/chart.xpm"
@@ -115,10 +118,13 @@ void toLineChart::setSamples(int samples)
     update();
 }
 
-toLineChart::toLineChart(QWidget *parent, const char *name, WFlags f)
-        : QWidget(parent, name, f)
+toLineChart::toLineChart(QWidget *parent, const char *name, Qt::WFlags f)
+        : QWidget(parent, f)
 {
-    setIcon(QPixmap((const char**)chart_xpm));
+    if (name)
+        setObjectName(name);
+
+    setWindowIcon(QPixmap((const char**)chart_xpm));
     Menu = NULL;
     MinAuto = MaxAuto = true;
     MinValue = MaxValue = 0;
@@ -127,25 +133,25 @@ toLineChart::toLineChart(QWidget *parent, const char *name, WFlags f)
     Grid = 5;
     AxisText = true;
     MousePoint[0] = MousePoint[1] = QPoint( -1, -1);
-    DisplaySamples = toConfigurationSingle::Instance().globalConfig(CONF_DISPLAY_SAMPLES, DEFAULT_DISPLAY_SAMPLES).toInt();
+    DisplaySamples = toConfigurationSingle::Instance().displaySamples();
 
     clearZoom();
 
-    setSamples(toConfigurationSingle::Instance().globalConfig(CONF_CHART_SAMPLES, DEFAULT_CHART_SAMPLES).toInt());
+    setSamples(toConfigurationSingle::Instance().chartSamples());
 
     setMinimumSize(80, 50);
 
     // Use list font
-    QString str = toConfigurationSingle::Instance().globalConfig(CONF_LIST, "");
+    QString str(toConfigurationSingle::Instance().listFont());
     if (!str.isEmpty())
     {
         QFont font(toStringToFont(str));
         setFont(font);
     }
 
-    Horizontal = new QScrollBar(QScrollBar::Horizontal, this);
+    Horizontal = new QScrollBar(Qt::Horizontal, this);
     Horizontal->hide();
-    Vertical = new QScrollBar(QScrollBar::Vertical, this);
+    Vertical = new QScrollBar(Qt::Vertical, this);
     Vertical->hide();
     connect(Vertical, SIGNAL(valueChanged(int)), this, SLOT(verticalChange(int)));
     connect(Horizontal, SIGNAL(valueChanged(int)), this, SLOT(horizontalChange(int)));
@@ -209,7 +215,7 @@ QRect toLineChart::fixRect(QPoint p1, QPoint p2)
                  abs(p1.y() - p2.y()));
 }
 
-#define FONT_ALIGN AlignLeft|AlignTop|ExpandTabs
+#define FONT_ALIGN Qt::AlignLeft|Qt::AlignTop|Qt::TextExpandTabs
 
 void toLineChart::paintTitle(QPainter *p, QRect &rect)
 {
@@ -221,7 +227,7 @@ void toLineChart::paintTitle(QPainter *p, QRect &rect)
         p->setFont(f);
         QFontMetrics fm = p->fontMetrics();
         QRect bounds = fm.boundingRect(0, 0, rect.width(), rect.width(), FONT_ALIGN, Title);
-        p->drawText(0, 2, rect.width(), bounds.height(), AlignHCenter | AlignTop | ExpandTabs, Title);
+        p->drawText(0, 2, rect.width(), bounds.height(), Qt::AlignHCenter | Qt::AlignTop, Title);
         p->restore();
         p->translate(0, bounds.height() + 2);
         rect.setTop(rect.top() + bounds.height() + 2);
@@ -243,7 +249,7 @@ void toLineChart::paintTitle(QPainter *p, QRect &rect)
         {
             QFontMetrics fm = p->fontMetrics();
             QRect bounds = fm.boundingRect(0, 0, rect.width(), rect.height(), FONT_ALIGN, str);
-            p->drawText(0, 2, rect.width(), bounds.height(), AlignHCenter | AlignTop | ExpandTabs, str);
+            p->drawText(0, 2, rect.width(), bounds.height(), Qt::AlignHCenter | Qt::AlignTop, str);
             p->translate(0, bounds.height());
             rect.setTop(rect.top() + bounds.height());
         }
@@ -286,7 +292,7 @@ void toLineChart::paintLegend(QPainter *p, QRect &rect)
         if (lx < 50)
             lx = 50;
         p->save();
-        p->setBrush(white);
+        p->setBrush(Qt::white);
         p->drawRect(lx, ly, lwidth, lheight);
         p->restore();
         rect.setRight(lx - 2);
@@ -305,7 +311,7 @@ void toLineChart::paintLegend(QPainter *p, QRect &rect)
                 QBrush brush(toChartBrush(cp));
                 p->setBrush(brush.color());
                 p->drawRect(lx - 10, ly + bounds.height() / 2 - fm.ascent() / 2, 8, fm.ascent());
-                if (brush.style() != QBrush::SolidPattern)
+                if (brush.style() != Qt::SolidPattern)
                 {
                     p->setBrush(QBrush(Qt::white, brush.style()));
                     p->drawRect(lx - 10, ly + bounds.height() / 2 - fm.ascent() / 2, 8, fm.ascent());
@@ -397,12 +403,12 @@ void toLineChart::paintAxis(QPainter *p, QRect &rect)
                         rect.height() - xoffset - 2 + (xscroll ? Horizontal->sizeHint().height() : 0),
                         rect.width() - 4 - yoffset,
                         xoffset - (xscroll ? Horizontal->sizeHint().height() : 0),
-                        AlignLeft | AlignTop | ExpandTabs, minXstr);
+                        Qt::AlignLeft | Qt::AlignTop, minXstr);
             p->drawText(yoffset + 2,
                         rect.height() - xoffset - 2 + (xscroll ? Horizontal->sizeHint().height() : 0),
                         rect.width() - 4 - yoffset,
                         xoffset - (xscroll ? Horizontal->sizeHint().height() : 0),
-                        AlignRight | AlignTop | ExpandTabs, maxXstr);
+                        Qt::AlignRight | Qt::AlignTop, maxXstr);
             p->translate(yoffset, 0);
 
             rect.setLeft(yoffset);
@@ -415,11 +421,11 @@ void toLineChart::paintAxis(QPainter *p, QRect &rect)
                                         rect.width() - 3,
                                         Horizontal->sizeHint().height());
                 disconnect(Horizontal, SIGNAL(valueChanged(int)), this, SLOT(horizontalChange(int)));
-                Horizontal->setMinValue(0);
-                Horizontal->setMaxValue(count - UseSamples);
+                Horizontal->setMinimum(0);
+                Horizontal->setMaximum(count - UseSamples);
                 Horizontal->setValue(count - UseSamples - SkipSamples);
                 connect(Horizontal, SIGNAL(valueChanged(int)), this, SLOT(horizontalChange(int)));
-                Horizontal->setSteps(1, UseSamples);
+//                 Horizontal->setSteps(1, UseSamples); - qt4 no equivalent found
                 Horizontal->show();
             }
             else
@@ -433,13 +439,13 @@ void toLineChart::paintAxis(QPainter *p, QRect &rect)
                                       Vertical->sizeHint().width(),
                                       rect.height() - 3);
                 disconnect(Vertical, SIGNAL(valueChanged(int)), this, SLOT(verticalChange(int)));
-                Vertical->setMinValue(0);
-                Vertical->setMaxValue(part - 100);
+                Vertical->setMinimum(0);
+                Vertical->setMaximum(part - 100);
 
                 Vertical->setValue(int(100*(MaxValue - zMaxValue) / (zMaxValue - zMinValue)));
 
                 connect(Vertical, SIGNAL(valueChanged(int)), this, SLOT(verticalChange(int)));
-                Vertical->setSteps(10, 100);
+//                 Vertical->setSteps(10, 100);
                 Vertical->show();
             }
             else
@@ -449,14 +455,14 @@ void toLineChart::paintAxis(QPainter *p, QRect &rect)
     }
 
     p->save();
-    p->setBrush(white);
+    p->setBrush(Qt::white);
     Chart = QRect(rect.left() + 2, rect.top() + 2, rect.width() - 3, rect.height() - 3);
     p->drawRect(2, 2, rect.width() - 3, rect.height() - 3);
     p->restore();
     if (Grid > 1)
     {
         p->save();
-        p->setPen(gray);
+        p->setPen(Qt::gray);
         for (int i = 1;i < Grid;i++)
         {
             int ypos = (rect.height() - 4) * i / Grid + 2;
@@ -524,11 +530,11 @@ void toLineChart::paintChart(QPainter *p, QRect &rect)
     int samples = countSamples();
     if (samples > 1)
     {
-        const QWMatrix &mtx = p->worldMatrix();
+        const QMatrix &mtx = p->worldMatrix();
         p->setClipRect(int(mtx.dx() + 2), int(mtx.dy() + 2), rect.width() - 3, rect.height() - 3);
         if (Zooming)
             p->drawText(2, 2, rect.width() - 4, rect.height() - 4,
-                        AlignLeft | AlignTop, tr("Zoom"));
+                        Qt::AlignLeft | Qt::AlignTop, tr("Zoom"));
         std::list<bool>::iterator k = Enabled.begin();
         for (std::list<std::list<double> >::iterator i = Values.begin();i != Values.end();i++)
         {
@@ -539,20 +545,20 @@ void toLineChart::paintChart(QPainter *p, QRect &rect)
                 Qt::PenStyle pens;
                 switch (brush.style())
                 {
-                case QBrush::BDiagPattern:
-                    pens = DashLine;
+                case Qt::BDiagPattern:
+                    pens = Qt::DashLine;
                     break;
-                case QBrush::FDiagPattern:
-                    pens = DotLine;
+                case Qt::FDiagPattern:
+                    pens = Qt::DotLine;
                     break;
-                case QBrush::DiagCrossPattern:
-                    pens = DashDotLine;
+                case Qt::DiagCrossPattern:
+                    pens = Qt::DashDotLine;
                     break;
-                case QBrush::CrossPattern:
-                    pens = DashDotDotLine;
+                case Qt::CrossPattern:
+                    pens = Qt::DashDotDotLine;
                     break;
                 default:
-                    pens = SolidLine;
+                    pens = Qt::SolidLine;
                 }
                 p->setPen(QPen(brush.color(), pens));
                 std::list<double> &val = *i;
@@ -605,13 +611,13 @@ void toLineChart::paintEvent(QPaintEvent *)
 
 void toLineChart::mouseReleaseEvent(QMouseEvent *e)
 {
-    if (e->button() == LeftButton && MousePoint[0] != QPoint( -1, -1))
+    if (e->button() == Qt::LeftButton && MousePoint[0] != QPoint( -1, -1))
     {
         if (MousePoint[1] != QPoint( -1, -1))
         {
             QRect rect = fixRect(MousePoint[0], MousePoint[1]);
             QPainter p(this);
-            p.setRasterOp(NotROP);
+//FIXME qt4:             p.setRasterOp(NotROP);
             p.drawRect(rect);
         }
         if (MousePoint[0].x() != e->x() &&
@@ -632,7 +638,7 @@ void toLineChart::mouseReleaseEvent(QMouseEvent *e)
         }
         MousePoint[1] = MousePoint[0] = QPoint( -1, -1);
     }
-    else if (e->button() == RightButton)
+    else if (e->button() == Qt::RightButton)
     {
         if (Chart.contains(e->pos()))
         {
@@ -657,22 +663,29 @@ int toLineChart::countSamples(void)
 
 void toLineChart::mousePressEvent(QMouseEvent *e)
 {
-    if (e->button() == LeftButton)
+    if (e->button() == Qt::LeftButton)
         MousePoint[0] = e->pos();
-    else if (e->button() == RightButton)
+    else if (e->button() == Qt::RightButton)
     {
         if (!Chart.contains(e->pos()) || !Zooming)
         {
             if (!Menu)
             {
-                Menu = new QPopupMenu(this);
-                Menu->insertItem(QPixmap(const_cast<const char**>(print_xpm)), tr("&Print..."), this, SLOT(editPrint()));
-                Menu->insertItem(tr("&Open in new window"), this, SLOT(openCopy()));
-                Menu->insertSeparator();
-                Menu->insertItem(tr("&Chart Manager..."), this, SLOT(chartSetup()));
-                Menu->insertItem(tr("&Properties..."), this, SLOT(setup()));
-                Menu->insertSeparator();
-                Menu->insertItem(tr("Clear Chart"), this, SLOT(clear()));
+                Menu = new QMenu(this);
+                Menu->addAction(QIcon(QPixmap(const_cast<const char**>(print_xpm))),
+                                tr("&Print..."),
+                                this,
+                                SLOT(editPrint()));
+                Menu->addAction(tr("&Open in new window"), this, SLOT(openCopy()));
+
+                Menu->addSeparator();
+
+                Menu->addAction(tr("&Chart Manager..."), this, SLOT(chartSetup()));
+                Menu->addAction(tr("&Properties..."), this, SLOT(setup()));
+
+                Menu->addSeparator();
+
+                Menu->addAction(tr("Clear Chart"), this, SLOT(clear()));
                 addMenues(Menu);
             }
             Menu->popup(e->globalPos());
@@ -687,7 +700,10 @@ void toLineChart::chartSetup(void)
 
 void toLineChart::setup(void)
 {
-    toLineChartSetupUI setup(this, NULL, true);
+    QDialog dialog(this);
+    Ui::toLineChartSetupUI setup; //, NULL, true);
+    setup.setupUi(&dialog);
+
     setup.MinValue->setText(toQValue::formatNumber(MinValue));
     setup.MaxValue->setText(toQValue::formatNumber(MaxValue));
     setup.AutoMax->setChecked(MaxAuto);
@@ -700,9 +716,9 @@ void toLineChart::setup(void)
     setup.Enabled->addColumn(tr("Enabled charts"));
     std::list<QString>::iterator i = Labels.begin();
     std::list<bool>::iterator j = Enabled.begin();
-    QListViewItem *item = NULL;
+    toTreeWidgetItem *item = NULL;
     setup.Enabled->setSorting( -1);
-    setup.Enabled->setSelectionMode(QListView::Multi);
+    setup.Enabled->setSelectionMode(toTreeWidget::Multi);
     while (i != Labels.end())
     {
         item = new toResultViewItem(setup.Enabled, item, *i);
@@ -735,7 +751,7 @@ void toLineChart::setup(void)
     else
         setup.DisplaySamples->setValue(DisplaySamples);
 
-    if (setup.exec())
+    if (dialog.exec())
     {
         MinValue = setup.MinValue->text().toDouble();
         MaxValue = setup.MaxValue->text().toDouble();
@@ -769,7 +785,7 @@ void toLineChart::setup(void)
         Grid = setup.Grids->value();
 
         std::list<bool> ena;
-        for (QListViewItem *item = setup.Enabled->firstChild();item;item = item->nextSibling())
+        for (toTreeWidgetItem *item = setup.Enabled->firstChild();item;item = item->nextSibling())
             ena.insert(ena.end(), item->isSelected());
 
         Enabled = ena;
@@ -781,13 +797,13 @@ void toLineChart::setup(void)
 void toLineChart::editPrint(void)
 {
     TOPrinter printer;
-    printer.setMinMax(1, 1);
-    if (printer.setup())
+    QPrintDialog dialog(&printer, this);
+    dialog.setMinMax(1, 1);
+    if (dialog.exec())
     {
         printer.setCreator(tr(TOAPPNAME));
         QPainter painter(&printer);
-        QPaintDeviceMetrics metrics(&printer);
-        QRect rect(0, 0, metrics.width(), metrics.height());
+        QRect rect(printer.pageRect());
         paintChart(&painter, rect);
     }
 }
@@ -806,7 +822,7 @@ void toLineChart::mouseMoveEvent(QMouseEvent *e)
     if (MousePoint[0] != QPoint( -1, -1))
     {
         QPainter p(this);
-        p.setRasterOp(NotROP);
+//FIXME qt4        p.setRasterOp(NotROP);
         if (MousePoint[1] != QPoint( -1, -1))
             p.drawRect(fixRect(MousePoint[0], MousePoint[1]));
         MousePoint[1] = e->pos();
@@ -817,7 +833,7 @@ void toLineChart::mouseMoveEvent(QMouseEvent *e)
 
 void toLineChart::mouseDoubleClickEvent(QMouseEvent *e)
 {
-    if (e->button() == LeftButton)
+    if (e->button() == Qt::LeftButton)
         openCopy();
 }
 
@@ -825,35 +841,14 @@ toLineChart *toLineChart::openCopy(QWidget *parent)
 {
     toLineChart *newWin = new toLineChart(this,
                                           parent ? parent : toMainWidget()->workspace(),
-                                          NULL, parent ? 0 : WDestructiveClose);
+                                          NULL,
+                                          (Qt::WindowFlags) (parent ? 0 : Qt::WA_DeleteOnClose));
     if (!parent)
     {
         newWin->show();
         newWin->raise();
         newWin->setFocus();
-        toMainWidget()->windowsMenu();
-
-#if QT_VERSION < 0x030100
-        // This is a really ugly workaround for a Qt layout bug
-        QWidget *tmp = NULL;
-        QWidget *tmp2 = NULL;
-        for (unsigned int i = 0;i < toMainWidget()->workspace()->windowList(QWorkspace::CreationOrder).count();i++)
-        {
-            QWidget *widget = toMainWidget()->workspace()->windowList(QWorkspace::CreationOrder).at(i);
-            if (newWin != widget)
-                tmp2 = widget;
-            else
-                tmp = newWin;
-            if (tmp2 && tmp)
-                break;
-        }
-        if (tmp2 && tmp)
-        {
-            tmp2->setFocus();
-            tmp->setFocus();
-        }
-#endif
-
+        toMainWidget()->updateWindowsMenu();
     }
     return newWin;
 }
@@ -863,9 +858,13 @@ toLineChart::~toLineChart()
     toMainWidget()->removeChart(this);
 }
 
-toLineChart::toLineChart (toLineChart *chart, QWidget *parent, const char *name, WFlags f)
-        : QWidget(parent, name, f)
+toLineChart::toLineChart (toLineChart *chart, QWidget *parent, const char *name, Qt::WFlags f)
+        : QWidget(parent, f)
 {
+
+    if (name)
+        setObjectName(name);
+
     Menu = NULL;
     Values = chart->Values;
     XValues = chart->XValues;
@@ -884,22 +883,22 @@ toLineChart::toLineChart (toLineChart *chart, QWidget *parent, const char *name,
     DisplaySamples = chart->DisplaySamples;
     Enabled = chart->Enabled;
 
-    setCaption(Title);
-    setIcon(QPixmap((const char**)chart_xpm));
+    setWindowTitle(Title);
+    setWindowIcon(QPixmap((const char**)chart_xpm));
 
     clearZoom();
 
     setMinimumSize(80, 50);
 
-    Horizontal = new QScrollBar(QScrollBar::Horizontal, this);
+    Horizontal = new QScrollBar(Qt::Horizontal, this);
     Horizontal->hide();
-    Vertical = new QScrollBar(QScrollBar::Vertical, this);
+    Vertical = new QScrollBar(Qt::Vertical, this);
     Vertical->hide();
     connect(Vertical, SIGNAL(valueChanged(int)), this, SLOT(verticalChange(int)));
     connect(Horizontal, SIGNAL(valueChanged(int)), this, SLOT(horizontalChange(int)));
 
     // Use list font
-    QString str = toConfigurationSingle::Instance().globalConfig(CONF_LIST, "");
+    QString str(toConfigurationSingle::Instance().listFont());
     if (!str.isEmpty())
     {
         QFont font(toStringToFont(str));
@@ -909,14 +908,14 @@ toLineChart::toLineChart (toLineChart *chart, QWidget *parent, const char *name,
     toMainWidget()->addChart(this);
 }
 
-void toLineChart::exportData(std::map<QCString, QString> &ret, const QCString &prefix)
+void toLineChart::exportData(std::map<QString, QString> &ret, const QString &prefix)
 {
     int id = 0;
     {
         for (std::list<QString>::iterator i = Labels.begin();i != Labels.end();i++)
         {
             id++;
-            ret[prefix + ":Labels:" + QString::number(id).latin1()] = *i;
+            ret[prefix + ":Labels:" + QString::number(id).toLatin1()] = *i;
         }
     }
     id = 0;
@@ -924,7 +923,7 @@ void toLineChart::exportData(std::map<QCString, QString> &ret, const QCString &p
         for (std::list<QString>::iterator i = XValues.begin();i != XValues.end();i++)
         {
             id++;
-            ret[prefix + ":XValues:" + QString::number(id).latin1()] = *i;
+            ret[prefix + ":XValues:" + QString::number(id).toLatin1()] = *i;
         }
     }
     id = 0;
@@ -939,19 +938,19 @@ void toLineChart::exportData(std::map<QCString, QString> &ret, const QCString &p
             value += QString::number(*j);
         }
         id++;
-        ret[prefix + ":Values:" + QString::number(id).latin1()] = value;
+        ret[prefix + ":Values:" + QString::number(id).toLatin1()] = value;
     }
     ret[prefix + ":Title"] = Title;
 }
 
-void toLineChart::importData(std::map<QCString, QString> &ret, const QCString &prefix)
+void toLineChart::importData(std::map<QString, QString> &ret, const QString &prefix)
 {
     int id;
-    std::map<QCString, QString>::iterator i;
+    std::map<QString, QString>::iterator i;
 
     id = 1;
     Labels.clear();
-    while ((i = ret.find(prefix + ":Labels:" + QString::number(id).latin1())) != ret.end())
+    while ((i = ret.find(prefix + ":Labels:" + QString::number(id).toLatin1())) != ret.end())
     {
         Labels.insert(Labels.end(), (*i).second);
         id++;
@@ -959,7 +958,7 @@ void toLineChart::importData(std::map<QCString, QString> &ret, const QCString &p
 
     id = 1;
     XValues.clear();
-    while ((i = ret.find(prefix + ":XValues:" + QString::number(id).latin1())) != ret.end())
+    while ((i = ret.find(prefix + ":XValues:" + QString::number(id).toLatin1())) != ret.end())
     {
         XValues.insert(XValues.end(), (*i).second);
         id++;
@@ -968,11 +967,11 @@ void toLineChart::importData(std::map<QCString, QString> &ret, const QCString &p
     id = 1;
     Values.clear();
     QRegExp comma(QString::fromLatin1(","));
-    while ((i = ret.find(prefix + ":Values:" + QString::number(id).latin1())) != ret.end())
+    while ((i = ret.find(prefix + ":Values:" + QString::number(id).toLatin1())) != ret.end())
     {
-        QStringList lst = QStringList::split(comma, (*i).second);
+        QStringList lst = (*i).second.split(comma);
         std::list<double> vals;
-        for (unsigned int j = 0;j < lst.count();j++)
+        for (int j = 0;j < lst.count();j++)
             vals.insert(vals.end(), lst[j].toDouble());
 
         Values.insert(Values.end(), vals);
@@ -993,7 +992,7 @@ void toLineChart::verticalChange(int val)
 {
     double size = (zMaxValue - zMinValue);
     zMaxValue = MaxValue - size / 100 * val;
-    if (val == Vertical->maxValue())
+    if (val == Vertical->maximum())
         zMinValue = MinValue;
     else
         zMinValue = MaxValue - size / 100 * (val + 100);
