@@ -1,39 +1,43 @@
-/*****
-*
-* TOra - An Oracle Toolkit for DBA's and developers
-* Copyright (C) 2003-2005 Quest Software, Inc
-* Portions Copyright (C) 2005 Other Contributors
-* 
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License
-* as published by the Free Software Foundation;  only version 2 of
-* the License is valid for this program.
-* 
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-* 
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*
-*      As a special exception, you have permission to link this program
-*      with the Oracle Client libraries and distribute executables, as long
-*      as you follow the requirements of the GNU GPL in regard to all of the
-*      software in the executable aside from Oracle client libraries.
-*
-*      Specifically you are not permitted to link this program with the
-*      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
-*      And you are not permitted to distribute binaries compiled against
-*      these libraries without written consent from Quest Software, Inc.
-*      Observe that this does not disallow linking to the Qt Free Edition.
-*
-*      You may link this product with any GPL'd Qt library such as Qt/Free
-*
-* All trademarks belong to their respective owners.
-*
-*****/
+
+/* BEGIN_COMMON_COPYRIGHT_HEADER
+ *
+ * TOra - An Oracle Toolkit for DBA's and developers
+ * 
+ * Shared/mixed copyright is held throughout files in this product
+ * 
+ * Portions Copyright (C) 2000-2001 Underscore AB
+ * Portions Copyright (C) 2003-2005 Quest Software, Inc.
+ * Portions Copyright (C) 2004-2008 Numerous Other Contributors
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation;  only version 2 of
+ * the License is valid for this program.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ *      As a special exception, you have permission to link this program
+ *      with the Oracle Client libraries and distribute executables, as long
+ *      as you follow the requirements of the GNU GPL in regard to all of the
+ *      software in the executable aside from Oracle client libraries.
+ * 
+ *      Specifically you are not permitted to link this program with the
+ *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
+ *      And you are not permitted to distribute binaries compiled against
+ *      these libraries. 
+ * 
+ *      You may link this product with any GPL'd Qt library.
+ * 
+ * All trademarks belong to their respective owners.
+ *
+ * END_COMMON_COPYRIGHT_HEADER */
 
 #include "utils.h"
 
@@ -46,7 +50,7 @@
 #include "toresultlong.h"
 #include "tosql.h"
 #include "totool.h"
-#include "toworksheet.h"
+#include "toworksheetwidget.h"
 
 #include <qcombobox.h>
 #include <qlabel.h>
@@ -59,14 +63,12 @@
 #include <qtoolbar.h>
 #include <qtoolbutton.h>
 
-#include "toprofiler.moc"
+#include <QPixmap>
+#include <QVBoxLayout>
 
 #include "icons/clock.xpm"
 #include "icons/execute.xpm"
 #include "icons/refresh.xpm"
-#if 0
-#include "icons/background.xpm"
-#endif
 
 static toSQL SQLProfilerRuns("toProfiler:ProfilerRuns",
                              "create table plsql_profiler_runs\n"
@@ -277,47 +279,49 @@ public:
 class unitsItem : public toResultViewItem
     {
     public:
-        unitsItem(QListView *parent, QListViewItem *after, const QString &buf = QString::null)
+        unitsItem(toTreeWidget *parent, toTreeWidgetItem *after, const QString &buf = QString::null)
                 : toResultViewItem(parent, after, buf)
         { }
         virtual void paintCell(QPainter *p, const QColorGroup &cg,
                                int column, int width, int alignment)
         {
+#if 0                           // disabled - not overriding correct method
             if (column == 2)
             {
                 toProfilerUnits *units = dynamic_cast<toProfilerUnits *>(listView());
                 if (!units)
                 {
-                    QListViewItem::paintCell(p, cg, column, width, alignment);
+                    toTreeWidgetItem::paintCell(p, cg, column, width, alignment);
                     return ;
                 }
                 double total = allText(column).toDouble();
                 QString timstr = FormatTime(total / 1E9);
                 double val = total / units->total();
 
-                p->fillRect(0, 0, int(val*width), height(), QBrush(blue));
+                p->fillRect(0, 0, int(val*width), height(), QBrush(Qt::blue));
                 p->fillRect(int(val*width), 0, width, height(),
                             QBrush(isSelected() ? cg.highlight() : cg.base()));
 
                 QPen pen(isSelected() ? cg.highlightedText() : cg.foreground());
                 p->setPen(pen);
-                p->drawText(0, 0, width, height(), AlignRight, timstr);
+                p->drawText(0, 0, width, height(), Qt::AlignRight, timstr);
             }
             else
             {
-                QListViewItem::paintCell(p, cg, column, width, alignment);
+                toTreeWidgetItem::paintCell(p, cg, column, width, alignment);
             }
+#endif
         }
     };
 
-    virtual QListViewItem *createItem(QListViewItem *last, const QString &str)
+    virtual toTreeWidgetItem *createItem(toTreeWidgetItem *last, const QString &str)
     {
         return new unitsItem(this, last, str);
     }
     toProfilerUnits(QWidget *parent)
             : toResultLong(true, false, toQuery::Normal, parent)
     {
-        setColumnAlignment(3, AlignRight);
+        setColumnAlignment(3, Qt::AlignRight);
         setSQL(SQLListUnits);
     }
     double total(void) const
@@ -341,7 +345,7 @@ public:
 class listItem : public toResultViewItem
     {
     public:
-        listItem(QListView *parent, QListViewItem *after, const QString &buf = QString::null)
+        listItem(toTreeWidget *parent, toTreeWidgetItem *after, const QString &buf = QString::null)
                 : toResultViewItem(parent, after, buf)
         { }
         virtual QString text(int col) const
@@ -352,38 +356,38 @@ class listItem : public toResultViewItem
                 return toResultViewItem::text(col);
         }
 
-        virtual int compare (QListViewItem *i, int col, bool ascending) const
+        bool operator<(const toTreeWidgetItem &other)
         {
+#if 0                           // todo tree
+            int col = treeWidget()->sortColumn();
             if (col == 2 || col == 3 || col == 4)
             {
-                toProfilerSource::listItem* item = dynamic_cast<toProfilerSource::listItem*>(i);
+                toProfilerSource::listItem *item =
+                    dynamic_cast<toProfilerSource::listItem>(&other);
                 if (!i)
-                    return QListViewItem::compare(i, col, ascending);
+                    return toTreeWidgetItem::operator<(other);
                 else
                 {
                     double val_in = allText(col).toDouble();
                     double val_out = item->allText(col).toDouble();
-                    if (val_in > val_out)
-                        return 1;
-                    else if (val_in < val_out)
-                        return -1;
-                    else
-                        return 0;
+                    return val_in < val_out;
                 }
             }
             else
-                return QListViewItem::compare(i, col, ascending);
+#endif
+                return toTreeWidgetItem::operator<(other);
         }
 
         virtual void paintCell(QPainter *p, const QColorGroup &cg,
                                int column, int width, int alignment)
         {
+#if 0                           // disabled - not overriding correct class
             if (column == 1 || column == 2 || column == 3 || column == 4)
             {
                 toProfilerSource *source = dynamic_cast<toProfilerSource *>(listView());
                 if (!source)
                 {
-                    QListViewItem::paintCell(p, cg, column, width, alignment);
+                    toTreeWidgetItem::paintCell(p, cg, column, width, alignment);
                     return ;
                 }
                 double total = allText(column).toDouble();
@@ -406,22 +410,23 @@ class listItem : public toResultViewItem
                     val = 0;
                 }
 
-                p->fillRect(0, 0, int(val*width), height(), QBrush(blue));
+                p->fillRect(0, 0, int(val*width), height(), QBrush(Qt::blue));
                 p->fillRect(int(val*width), 0, width, height(),
                             QBrush(isSelected() ? cg.highlight() : cg.base()));
 
                 QPen pen(isSelected() ? cg.highlightedText() : cg.foreground());
                 p->setPen(pen);
-                p->drawText(0, 0, width, height(), AlignRight, text(column));
+                p->drawText(0, 0, width, height(), Qt::AlignRight, text(column));
             }
             else
             {
-                QListViewItem::paintCell(p, cg, column, width, alignment);
+                toTreeWidgetItem::paintCell(p, cg, column, width, alignment);
             }
+#endif
         }
     };
 
-    virtual QListViewItem *createItem(QListViewItem *last, const QString &str)
+    virtual toTreeWidgetItem *createItem(toTreeWidgetItem *last, const QString &str)
     {
         return new listItem(this, last, str);
     }
@@ -432,16 +437,16 @@ class listItem : public toResultViewItem
     toProfilerSource(QWidget *parent)
             : toResultLong(true, false, toQuery::Normal, parent)
     {
-        setColumnAlignment(1, AlignRight);
-        setColumnAlignment(2, AlignRight);
-        setColumnAlignment(3, AlignRight);
-        setColumnAlignment(4, AlignRight);
+        setColumnAlignment(1, Qt::AlignRight);
+        setColumnAlignment(2, Qt::AlignRight);
+        setColumnAlignment(3, Qt::AlignRight);
+        setColumnAlignment(4, Qt::AlignRight);
         clearTotals();
     }
     void calcTotals(void)
     {
         clearTotals();
-        for (QListViewItem *qi = firstChild();qi;qi = qi->nextSibling())
+        for (toTreeWidgetItem *qi = firstChild();qi;qi = qi->nextSibling())
         {
             toResultViewItem * item = dynamic_cast<toResultViewItem *>(qi);
             if (item)
@@ -463,76 +468,86 @@ class listItem : public toResultViewItem
 };
 
 toProfiler::toProfiler(QWidget *parent, toConnection &connection)
-        : toToolWidget(ProfilerTool, "toprofiler.html", parent, connection)
+        : toToolWidget(ProfilerTool, "toprofiler.html", parent, connection, "toProfiler")
 {
     QToolBar *toolbar = toAllocBar(this, tr("PL/SQL Profiler"));
+    layout()->addWidget(toolbar);
 
-    new QToolButton(QPixmap(const_cast<const char**>(refresh_xpm)),
-                    tr("Refresh list"),
-                    tr("Refresh list"),
-                    this, SLOT(refresh()),
-                    toolbar);
+    toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(refresh_xpm))),
+                       tr("Refresh list"),
+                       this,
+                       SLOT(refresh()));
 
     toolbar->addSeparator();
 
-    new QLabel(tr("Repeat run") + " ", toolbar, TO_KDE_TOOLBAR_WIDGET);
+    toolbar->addWidget(
+        new QLabel(tr("Repeat run") + " ", toolbar));
 
-    Repeat = new QSpinBox(toolbar, TO_KDE_TOOLBAR_WIDGET);
+    Repeat = new QSpinBox(toolbar);
     Repeat->setValue(5);
-    Repeat->setMaxValue(1000);
+    Repeat->setMaximum(1000);
+    toolbar->addWidget(Repeat);
 
     toolbar->addSeparator();
 
-    new QLabel(tr("Comment") + " ", toolbar);
-    Comment = new QLineEdit(toolbar, TO_KDE_TOOLBAR_WIDGET);
+    toolbar->addWidget(new QLabel(tr("Comment") + " ", toolbar));
+
+    Comment = new QLineEdit(toolbar);
     Comment->setText(tr("Unknown"));
+    toolbar->addWidget(Comment);
 
     toolbar->addSeparator();
 
 #if 0
-
     Background = new QToolButton(toolbar);
     Background->setToggleButton(true);
-    Background->setIconSet(QIconSet(QPixmap(const_cast<const char**>(background_xpm))));
+    Background->setIconSet(QIcon(QPixmap(const_cast<const char**>(background_xpm))));
     QToolTip::add
-        (Background, tr("Run profiling in background"));
+    (Background, tr("Run profiling in background"));
 
     toolbar->addSeparator();
 #endif
 
-    new QToolButton(QPixmap(const_cast<const char**>(execute_xpm)),
-                    tr("Execute current profiling"),
-                    tr("Execute current profiling"),
-                    this, SLOT(execute()),
-                    toolbar);
+    toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(execute_xpm))),
+                       tr("Execute current profiling"),
+                       this,
+                       SLOT(execute()));
 
-    toolbar->setStretchableWidget(new QLabel(toolbar, TO_KDE_TOOLBAR_WIDGET));
+    toolbar->addWidget(new toSpacer());
 
-    new toChangeConnection(toolbar, TO_KDE_TOOLBAR_WIDGET);
+    new toChangeConnection(toolbar, TO_TOOLBAR_WIDGET_NAME);
 
     Tabs = new QTabWidget(this);
-    Script = new toWorksheet(Tabs, NULL, connection);
+    layout()->addWidget(Tabs);
+
+    Script = new toWorksheetWidget(Tabs, NULL, connection);
     Tabs->addTab(Script, tr("Script"));
 
     Result = new QSplitter(Tabs);
     Tabs->addTab(Result, tr("Result"));
 
-    QVBox *box = new QVBox(Result);
+    QWidget *box = new QWidget(Result);
+    QVBoxLayout *vbox = new QVBoxLayout;
+    vbox->setSpacing(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
+    box->setLayout(vbox);
     Run = new QComboBox(box);
-    QSplitter *vsplit = new QSplitter(Vertical, box);
+    vbox->addWidget(Run);
+    QSplitter *vsplit = new QSplitter(Qt::Vertical, box);
+    vbox->addWidget(vsplit);
     Info = new toResultItem(2, vsplit);
     Info->setSQL(SQLRunInfo);
     connect(Run, SIGNAL(activated(int)), this, SLOT(changeRun()));
     Units = new toProfilerUnits(vsplit);
     Units->setReadAll(true);
-    Units->setSelectionMode(QListView::Single);
+    Units->setSelectionMode(toTreeWidget::Single);
     connect(Units, SIGNAL(selectionChanged()), this, SLOT(changeObject()));
     Lines = new toProfilerSource(Result);
     Lines->setReadAll(true);
     connect(Lines, SIGNAL(done()), this, SLOT(calcTotals()));
 
     LastUnit = CurrentRun = 0;
-    show();
+//     show();
 
     try
     {
@@ -574,7 +589,7 @@ toProfiler::toProfiler(QWidget *parent, toConnection &connection)
 void toProfiler::refresh(void)
 {
     Run->clear();
-    Run->insertItem(tr("Select run"));
+    Run->addItem(tr("Select run"));
     try
     {
         toQuery query(connection(), SQLListRuns);
@@ -588,10 +603,10 @@ void toProfiler::refresh(void)
             if (!owner.isEmpty())
                 owner = QString::fromLatin1("(") + owner + QString::fromLatin1(")");
             QString timstr = QString::fromLatin1(" [") + FormatTime(total) + QString::fromLatin1("]");
-            Run->insertItem(runid + owner + QString::fromLatin1(": ") + comment + timstr);
+            Run->addItem(runid + owner + QString::fromLatin1(": ") + comment + timstr);
             if (runid.toInt() == CurrentRun)
             {
-                Run->setCurrentItem(id);
+                Run->setCurrentIndex(id);
                 changeRun();
             }
             id++;
@@ -620,7 +635,7 @@ void toProfiler::execute(void)
         CurrentRun = query.readValue().toInt();
         if (CurrentRun > 0)
         {
-            Tabs->showPage(Result);
+            Tabs->setCurrentIndex(Tabs->indexOf(Result));
             refresh();
         }
         else
@@ -632,9 +647,9 @@ void toProfiler::execute(void)
 void toProfiler::changeRun(void)
 {
     QString t = Run->currentText();
-    int pos = t.find(QString::fromLatin1("("));
+    int pos = t.indexOf(QString::fromLatin1("("));
     if (pos < 0)
-        pos = t.find(QString::fromLatin1(":"));
+        pos = t.indexOf(QString::fromLatin1(":"));
     if (pos >= 0)
         CurrentRun = t.mid(0, pos).toInt();
     QString run = QString::number(CurrentRun);
@@ -655,7 +670,7 @@ void toProfiler::calcTotals(void)
 
 void toProfiler::changeObject(void)
 {
-    QListViewItem *qi = Units->selectedItem();
+    toTreeWidgetItem *qi = Units->selectedItem();
     toResultViewItem *item = qi ? dynamic_cast<toResultViewItem *>(qi) : NULL;
     if (item)
     {
