@@ -1,39 +1,43 @@
-/*****
-*
-* TOra - An Oracle Toolkit for DBA's and developers
-* Copyright (C) 2003-2005 Quest Software, Inc
-* Portions Copyright (C) 2005 Other Contributors
-* 
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License
-* as published by the Free Software Foundation;  only version 2 of
-* the License is valid for this program.
-* 
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-* 
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*
-*      As a special exception, you have permission to link this program
-*      with the Oracle Client libraries and distribute executables, as long
-*      as you follow the requirements of the GNU GPL in regard to all of the
-*      software in the executable aside from Oracle client libraries.
-*
-*      Specifically you are not permitted to link this program with the
-*      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
-*      And you are not permitted to distribute binaries compiled against
-*      these libraries without written consent from Quest Software, Inc.
-*      Observe that this does not disallow linking to the Qt Free Edition.
-*
-*      You may link this product with any GPL'd Qt library such as Qt/Free
-*
-* All trademarks belong to their respective owners.
-*
-*****/
+
+/* BEGIN_COMMON_COPYRIGHT_HEADER
+ *
+ * TOra - An Oracle Toolkit for DBA's and developers
+ * 
+ * Shared/mixed copyright is held throughout files in this product
+ * 
+ * Portions Copyright (C) 2000-2001 Underscore AB
+ * Portions Copyright (C) 2003-2005 Quest Software, Inc.
+ * Portions Copyright (C) 2004-2008 Numerous Other Contributors
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation;  only version 2 of
+ * the License is valid for this program.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ *      As a special exception, you have permission to link this program
+ *      with the Oracle Client libraries and distribute executables, as long
+ *      as you follow the requirements of the GNU GPL in regard to all of the
+ *      software in the executable aside from Oracle client libraries.
+ * 
+ *      Specifically you are not permitted to link this program with the
+ *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
+ *      And you are not permitted to distribute binaries compiled against
+ *      these libraries. 
+ * 
+ *      You may link this product with any GPL'd Qt library.
+ * 
+ * All trademarks belong to their respective owners.
+ *
+ * END_COMMON_COPYRIGHT_HEADER */
 
 #include "utils.h"
 
@@ -50,10 +54,12 @@
 #include <qregexp.h>
 #include <qtimer.h>
 #include <qtoolbar.h>
-#include <qtoolbutton.h>
-#include <qworkspace.h>
 
-#include "toproject.moc"
+#include <QMdiArea>
+#include <QString>
+#include <QPixmap>
+#include <QVBoxLayout>
+#include <QDir>
 
 #include "icons/addproject.xpm"
 #include "icons/filesave.xpm"
@@ -65,11 +71,7 @@
 
 static toProjectTemplate ProjectTemplate;
 
-#ifdef TO_KDE
-#define PROJECT_EXTENSIONS "*.sql *.pkg *.pkb|SQL files\n*.tpr|Project files\n*.txt|Text files\n*|All files"
-#else
 #define PROJECT_EXTENSIONS "SQL (*.sql *.pkg *.pkb),Project files (*.tpr) ,Text (*.txt), All (*)"
-#endif
 
 bool toProjectTemplateItem::project(void)
 {
@@ -88,10 +90,10 @@ void toProjectTemplateItem::setup(const QString &name, bool open)
     {
         try
         {
-            QString data = QString::fromUtf8(toReadFile(Filename));
-            QStringList files = QStringList::split(QRegExp(QString::fromLatin1("\n")), data);
+            QString data = toReadFile(Filename);
+            QStringList files = data.split(QRegExp(QString::fromLatin1("\n")));
             toProjectTemplateItem *last = NULL;
-            for (unsigned int i = 0;i < files.count();i++)
+            for (int i = 0;i < files.count();i++)
                 last = new toProjectTemplateItem(this, last, files[i]);
         }
         catch (const QString &exc)
@@ -105,9 +107,9 @@ void toProjectTemplateItem::setFilename(const QString &name)
 {
     if (parent())
     {
-        int pos = name.findRev(QString::fromLatin1("/"));
+        int pos = name.lastIndexOf(QString::fromLatin1("/"));
         if (pos < 0)
-            pos = name.findRev(QString::fromLatin1("\\"));
+            pos = name.lastIndexOf(QString::fromLatin1("\\"));
         if (pos >= 0)
             setText(0, name.mid(pos + 1));
         else
@@ -117,14 +119,14 @@ void toProjectTemplateItem::setFilename(const QString &name)
 }
 
 toProjectTemplateItem::toProjectTemplateItem(toTemplateItem *item,
-        QListViewItem *after,
+        toTreeWidgetItem *after,
         QString name, bool open)
         : toTemplateItem(item, QString::null, after)
 {
     setup(name, open);
 }
 
-toProjectTemplateItem::toProjectTemplateItem(QListView *item, QString name, bool open)
+toProjectTemplateItem::toProjectTemplateItem(toTreeWidget *item, QString name, bool open)
         : toTemplateItem(ProjectTemplate, item, qApp->translate("toProject", "SQL Project"))
 {
     setup(name, open);
@@ -161,7 +163,7 @@ int toProjectTemplateItem::order(bool asc)
 
 toProjectTemplateItem *toProjectTemplateItem::previousSibling()
 {
-    QListViewItem *item = itemAbove();
+    toTreeWidgetItem *item = itemAbove();
     if (!item)
         return NULL;
     if (item == parent())
@@ -192,7 +194,7 @@ void toProjectTemplateItem::selected(void)
     {
         toWorksheet::fileWorksheet(Filename);
     }
-    TOCATCH
+    TOCATCH;
 }
 
 QWidget *toProjectTemplateItem::selectedWidget(QWidget *parent)
@@ -209,10 +211,10 @@ toProject *toProjectTemplate::selectedWidget(QWidget *parent)
     return Details;
 }
 
-void toProjectTemplate::importData(std::map<QCString, QString> &data, const QCString &prefix)
+void toProjectTemplate::importData(std::map<QString, QString> &data, const QString &prefix)
 {
     bool any = false;
-    std::map<QCString, QString>::iterator i = data.find(prefix + ":");
+    std::map<QString, QString>::iterator i = data.find(prefix + ":");
     while (i != data.end())
     {
         if ((*i).first.mid(0, prefix.length()) == prefix)
@@ -226,20 +228,20 @@ void toProjectTemplate::importData(std::map<QCString, QString> &data, const QCSt
     }
 }
 
-void toProjectTemplate::exportData(std::map<QCString, QString> &data, const QCString &prefix)
+void toProjectTemplate::exportData(std::map<QString, QString> &data, const QString &prefix)
 {
     if (!Root)
         return ;
-    std::map<QListViewItem *, int> itemMap;
-    QListViewItem *next;
+    std::map<toTreeWidgetItem *, int> itemMap;
+    toTreeWidgetItem *next;
     int id = 0;
     data[prefix + ":"] = Root->filename();
-    for (QListViewItem *item = Root->firstChild();item;item = next)
+    for (toTreeWidgetItem *item = Root->firstChild();item;item = next)
     {
         id++;
-        QCString nam = prefix;
+        QString nam = prefix;
         nam += ":Items:";
-        nam += QString::number(id).latin1();
+        nam += QString::number(id).toLatin1();
         nam += ":";
         itemMap[item] = id;
         if (item->parent())
@@ -273,20 +275,20 @@ void toProjectTemplate::exportData(std::map<QCString, QString> &data, const QCSt
     }
 }
 
-void toProjectTemplate::insertItems(QListView *parent, QToolBar *toolbar)
+void toProjectTemplate::insertItems(toTreeWidget *parent, QToolBar *toolbar)
 {
     Root = new toProjectTemplateItem(parent, Import[""], false);
     Root->setOpen(true);
 
     int id = 1;
-    std::map<QCString, QString>::iterator i;
+    std::map<QString, QString>::iterator i;
     std::map<int, toProjectTemplateItem *> itemMap;
 
     toProjectTemplateItem *last = NULL;
 
-    while ((i = Import.find(QCString("Items:") + QString::number(id).latin1() + ":Parent")) != Import.end())
+    while ((i = Import.find(QString("Items:") + QString::number(id).toLatin1() + ":Parent")) != Import.end())
     {
-        QCString nam = QCString("Items:") + QString::number(id).latin1() + ":";
+        QString nam = QString("Items:") + QString::number(id).toLatin1() + ":";
         int parent = (*i).second.toInt();
         if (parent)
             last = new toProjectTemplateItem(itemMap[parent], last, Import[nam + "0"], false);
@@ -298,29 +300,27 @@ void toProjectTemplate::insertItems(QListView *parent, QToolBar *toolbar)
         id++;
     }
 
-    connect(parent, SIGNAL(selectionChanged(QListViewItem *)), this, SLOT(changeItem(QListViewItem *)));
-    AddFile = new QToolButton(QPixmap(const_cast<const char**>(addproject_xpm)),
-                              qApp->translate("toProject", "Add file to project"),
-                              qApp->translate("toProject", "Add file to project"),
-                              this, SLOT(addFile()),
-                              toolbar);
-    DelFile = new QToolButton(QPixmap(const_cast<const char**>(trash_xpm)),
-                              qApp->translate("toProject", "Remove file from project"),
-                              qApp->translate("toProject", "Remove file from project"),
-                              this, SLOT(delFile()),
-                              toolbar);
+    connect(parent, SIGNAL(selectionChanged(toTreeWidgetItem *)), this, SLOT(changeItem(toTreeWidgetItem *)));
+    AddFile = toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(addproject_xpm))),
+                                 qApp->translate("toProject", "Add file to project"),
+                                 this,
+                                 SLOT(addFile()));
+    DelFile = toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(trash_xpm))),
+                                 qApp->translate("toProject", "Remove file from project"),
+                                 this,
+                                 SLOT(delFile()));
     AddFile->setEnabled(false);
     DelFile->setEnabled(false);
 }
 
-void toProjectTemplate::changeItem(QListViewItem *item)
+void toProjectTemplate::changeItem(toTreeWidgetItem *item)
 {
     bool ena = dynamic_cast<toProjectTemplateItem *>(item);
     AddFile->setEnabled(ena);
     DelFile->setEnabled(ena && item->parent());
 }
 
-void toProjectTemplate::removeItems(QListViewItem *item)
+void toProjectTemplate::removeItems(toTreeWidgetItem *item)
 {
     delete item;
 }
@@ -332,12 +332,12 @@ void toProjectTemplate::addFile(void)
                                   toMainWidget());
     if (!file.isNull())
     {
-        QListView *view = Root->listView();
+        toTreeWidget *view = Root->listView();
         toProjectTemplateItem *item = dynamic_cast<toProjectTemplateItem *>(view->currentItem());
         if (item)
         {
             item->setOpen(true);
-            QListViewItem *last = item->firstChild();
+            toTreeWidgetItem *last = item->firstChild();
             while (last && last->nextSibling())
                 last = last->nextSibling();
             if (item->project())
@@ -356,7 +356,7 @@ void toProjectTemplate::addFile(void)
 
 void toProjectTemplate::delFile(void)
 {
-    QListView *view = Root->listView();
+    toTreeWidget *view = Root->listView();
     toProjectTemplateItem *item = dynamic_cast<toProjectTemplateItem *>(view->currentItem());
     delete item;
     if (Details)
@@ -371,7 +371,7 @@ void toProject::update(toProjectTemplateItem *sourceparent, toResultViewItem *pa
         parent->setOpen(true);
         ItemMap[parent] = sourceparent;
     }
-    for (QListViewItem *item = sourceparent->firstChild();item;item = item->nextSibling())
+    for (toTreeWidgetItem *item = sourceparent->firstChild();item;item = item->nextSibling())
     {
         toProjectTemplateItem * projitem = dynamic_cast<toProjectTemplateItem *>(item);
         if (projitem)
@@ -393,57 +393,71 @@ void toProject::update(toProjectTemplateItem *sourceparent, toResultViewItem *pa
 }
 
 toProject::toProject(toProjectTemplateItem *top, QWidget *parent)
-        : QVBox(parent)
+        : QWidget(parent)
 {
     Root = top;
 
+    QVBoxLayout *vbox = new QVBoxLayout;
+    vbox->setSpacing(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
+
     QToolBar *toolbar = toAllocBar(this, tr("SQL project"));
-    new QToolButton(QPixmap(const_cast<const char**>(addproject_xpm)),
-                    tr("Add file to project"),
-                    tr("Add file to project"),
-                    this, SLOT(addFile()),
-                    toolbar);
-    new QToolButton(QPixmap(const_cast<const char**>(filesave_xpm)),
-                    tr("Save project"),
-                    tr("Save project"),
-                    this, SLOT(saveProject()),
-                    toolbar);
-    DelFile = new QToolButton(QPixmap(const_cast<const char**>(trash_xpm)),
-                              tr("Remove file from project"),
-                              tr("Remove file from project"),
-                              this, SLOT(delFile()),
-                              toolbar);
+    vbox->addWidget(toolbar);
+
+    toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(addproject_xpm))),
+                       tr("Add file to project"),
+                       this,
+                       SLOT(addFile()));
+
+    toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(filesave_xpm))),
+                       tr("Save project"),
+                       this,
+                       SLOT(saveProject()));
+
+    DelFile = toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(trash_xpm))),
+                                 tr("Remove file from project"),
+                                 this,
+                                 SLOT(delFile()));
+
     toolbar->addSeparator();
-    new QToolButton(QPixmap(const_cast<const char**>(new_xpm)),
-                    tr("Add new subproject"),
-                    tr("Add new subproject"),
-                    this, SLOT(newProject()),
-                    toolbar);
-    new QToolButton(QPixmap(const_cast<const char**>(sql_xpm)),
-                    tr("Generate SQL for this project"),
-                    tr("Generate SQL for this project"),
-                    this, SLOT(generateSQL()),
-                    toolbar);
+
+    toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(new_xpm))),
+                       tr("Add new subproject"),
+                       this,
+                       SLOT(newProject()));
+
+    toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(sql_xpm))),
+                       tr("Generate SQL for this project"),
+                       this,
+                       SLOT(generateSQL()));
+
     toolbar->addSeparator();
-    new QToolButton(QPixmap(const_cast<const char**>(up_xpm)),
-                    tr("Move up in project"),
-                    tr("Move up in project"),
-                    this, SLOT(moveUp()),
-                    toolbar);
-    new QToolButton(QPixmap(const_cast<const char**>(down_xpm)),
-                    tr("Move down in project"),
-                    tr("Move down in project"),
-                    this, SLOT(moveDown()),
-                    toolbar);
-    toolbar->setStretchableWidget(new QLabel(toolbar, TO_KDE_TOOLBAR_WIDGET));
+
+    toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(up_xpm))),
+                       tr("Move up in project"),
+                       this,
+                       SLOT(moveUp()));
+
+    toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(down_xpm))),
+                       tr("Move down in project"),
+                       this,
+                       SLOT(moveDown()));
+
+    toolbar->addWidget(new toSpacer());
+
     Project = new toListView(this);
     Project->addColumn(tr("File"));
     Project->addColumn(tr("Size"));
-    Project->setSelectionMode(QListView::Single);
+    Project->setSelectionMode(toTreeWidget::Single);
     Project->setRootIsDecorated(true);
     Project->setSorting(0);
-    connect(Project, SIGNAL(selectionChanged()),
-            this, SLOT(selectionChanged()));
+    connect(Project,
+            SIGNAL(selectionChanged()),
+            this,
+            SLOT(selectionChanged()));
+    vbox->addWidget(Project);
+
+    setLayout(vbox);
     update();
 }
 
@@ -456,7 +470,7 @@ void toProject::update(void)
 
 void toProject::selectionChanged(void)
 {
-    QListViewItem *item = Project->selectedItem();
+    toTreeWidgetItem *item = Project->selectedItem();
     if (item)
     {
         DelFile->setEnabled(item->parent());
@@ -482,14 +496,14 @@ void toProject::delFile(void)
 
 void toProject::moveDown(void)
 {
-    QListViewItem *item = Project->selectedItem();
+    toTreeWidgetItem *item = Project->selectedItem();
     if (item)
     {
         toProjectTemplateItem *oi = ItemMap[item];
         if (oi)
         {
-            QListViewItem *item = oi->nextSibling();
-            QListViewItem *parent = oi->parent();
+            toTreeWidgetItem *item = oi->nextSibling();
+            toTreeWidgetItem *parent = oi->parent();
             if (item && parent)
             {
                 oi->moveItem(item);
@@ -501,14 +515,14 @@ void toProject::moveDown(void)
 
 void toProject::moveUp(void)
 {
-    QListViewItem *item = Project->selectedItem();
+    toTreeWidgetItem *item = Project->selectedItem();
     if (item)
     {
         toProjectTemplateItem *oi = ItemMap[item];
         if (oi)
         {
-            QListViewItem *item = oi->previousSibling();
-            QListViewItem *parent = oi->parent();
+            toTreeWidgetItem *item = oi->previousSibling();
+            toTreeWidgetItem *parent = oi->parent();
             if (item && parent)
             {
                 item->moveItem(oi);
@@ -520,13 +534,13 @@ void toProject::moveUp(void)
 
 void toProject::newProject(void)
 {
-    QListViewItem *item = Project->selectedItem();
+    toTreeWidgetItem *item = Project->selectedItem();
     if (item)
     {
         toProjectTemplateItem *oi = ItemMap[item];
         if (oi)
         {
-            QListViewItem *last = oi;
+            toTreeWidgetItem *last = oi;
             if (!oi->project())
                 oi = dynamic_cast<toProjectTemplateItem *>(oi->parent());
             else
@@ -546,7 +560,7 @@ void toProject::newProject(void)
 
 void toProject::saveProject(void)
 {
-    QListViewItem *item = Project->selectedItem();
+    toTreeWidgetItem *item = Project->selectedItem();
     if (item)
     {
         toProjectTemplateItem *oi = ItemMap[item];
@@ -558,16 +572,16 @@ void toProject::saveProject(void)
             {
                 QFileInfo file(oi->filename());
                 QString fn = oi->filename();
-                fn = toSaveFilename(file.dirPath(), QString::fromLatin1("*.tpr"), this);
+                fn = toSaveFilename(file.dir().path(), QString::fromLatin1("*.tpr"), this);
                 if (!fn.isEmpty())
                 {
                     QString data;
-                    for (QListViewItem *item = oi->firstChild();item;item = item->nextSibling())
+                    for (toTreeWidgetItem *item = oi->firstChild();item;item = item->nextSibling())
                     {
                         toProjectTemplateItem * projitem = dynamic_cast<toProjectTemplateItem *>(item);
                         data += projitem->filename() + QString::fromLatin1("\n");
                     }
-                    if (toWriteFile(fn, data.utf8()))
+                    if (toWriteFile(fn, data.toUtf8()))
                         oi->setFilename(fn);
                 }
             }
@@ -590,7 +604,7 @@ QString toProject::generateSQL(toProjectTemplateItem *parent)
         else
         {
             data += tr("\n\n-- Start of file %1\n\n").arg(item->filename());
-            data += QString::fromLocal8Bit(toReadFile(item->filename()));
+            data += toReadFile(item->filename());
         }
     }
     return data;
@@ -598,7 +612,7 @@ QString toProject::generateSQL(toProjectTemplateItem *parent)
 
 void toProject::generateSQL(void)
 {
-    QListViewItem *item = Project->selectedItem();
+    toTreeWidgetItem *item = Project->selectedItem();
     if (item)
     {
         toProjectTemplateItem *oi = ItemMap[item];
@@ -623,7 +637,7 @@ toProject::~toProject()
 
 void toProject::selectItem(toProjectTemplateItem *item)
 {
-    for (std::map<QListViewItem *, toProjectTemplateItem *>::iterator i = ItemMap.begin();
+    for (std::map<toTreeWidgetItem *, toProjectTemplateItem *>::iterator i = ItemMap.begin();
             i != ItemMap.end();
             i++)
     {
