@@ -1,39 +1,43 @@
-/*****
-*
-* TOra - An Oracle Toolkit for DBA's and developers
-* Copyright (C) 2003-2005 Quest Software, Inc
-* Portions Copyright (C) 2005 Other Contributors
-* 
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License
-* as published by the Free Software Foundation;  only version 2 of
-* the License is valid for this program.
-* 
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-* 
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*
-*      As a special exception, you have permission to link this program
-*      with the Oracle Client libraries and distribute executables, as long
-*      as you follow the requirements of the GNU GPL in regard to all of the
-*      software in the executable aside from Oracle client libraries.
-*
-*      Specifically you are not permitted to link this program with the
-*      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
-*      And you are not permitted to distribute binaries compiled against
-*      these libraries without written consent from Quest Software, Inc.
-*      Observe that this does not disallow linking to the Qt Free Edition.
-*
-*      You may link this product with any GPL'd Qt library such as Qt/Free
-*
-* All trademarks belong to their respective owners.
-*
-*****/
+
+/* BEGIN_COMMON_COPYRIGHT_HEADER
+ *
+ * TOra - An Oracle Toolkit for DBA's and developers
+ * 
+ * Shared/mixed copyright is held throughout files in this product
+ * 
+ * Portions Copyright (C) 2000-2001 Underscore AB
+ * Portions Copyright (C) 2003-2005 Quest Software, Inc.
+ * Portions Copyright (C) 2004-2008 Numerous Other Contributors
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation;  only version 2 of
+ * the License is valid for this program.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ *      As a special exception, you have permission to link this program
+ *      with the Oracle Client libraries and distribute executables, as long
+ *      as you follow the requirements of the GNU GPL in regard to all of the
+ *      software in the executable aside from Oracle client libraries.
+ * 
+ *      Specifically you are not permitted to link this program with the
+ *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
+ *      And you are not permitted to distribute binaries compiled against
+ *      these libraries. 
+ * 
+ *      You may link this product with any GPL'd Qt library.
+ * 
+ * All trademarks belong to their respective owners.
+ *
+ * END_COMMON_COPYRIGHT_HEADER */
 
 #include "utils.h"
 
@@ -44,7 +48,7 @@
 #include "tomain.h"
 #include "tomemoeditor.h"
 #include "toresultitem.h"
-#include "toresultlong.h"
+#include "toresulttableview.h"
 #include "toresultview.h"
 #include "torollback.h"
 #include "tosgastatement.h"
@@ -52,25 +56,18 @@
 #include "tostoragedefinition.h"
 #include "totool.h"
 
-#ifdef TO_KDE
-#  include <kmenubar.h>
-#endif
-
 #include <list>
 
 #include <qcheckbox.h>
 #include <qcombobox.h>
-#include <qgroupbox.h>
-#include <qheader.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlayout.h>
 #include <qlineedit.h>
-#include <qlistview.h>
+#include <totreewidget.h>
 #include <qmenubar.h>
 #include <qmessagebox.h>
 #include <qpainter.h>
-#include <qpopupmenu.h>
 #include <qpushbutton.h>
 #include <qregexp.h>
 #include <qsplitter.h>
@@ -80,12 +77,13 @@
 #include <qtoolbutton.h>
 #include <qtooltip.h>
 #include <qvariant.h>
-#include <qwhatsthis.h>
 #include <qwidget.h>
-#include <qworkspace.h>
+#include <QMdiArea>
 
-#include "torollback.moc"
-#include "torollbackdialogui.moc"
+#include <QGroupBox>
+#include <QVBoxLayout>
+#include <QPixmap>
+#include <QMenu>
 
 #include "icons/addrollback.xpm"
 #include "icons/offline.xpm"
@@ -94,11 +92,11 @@
 #include "icons/torollback.xpm"
 #include "icons/trash.xpm"
 
-#define CONF_NO_EXEC    "NoExec"
-#define CONF_NEED_READ  "NeedRead"
-#define CONF_NEED_TWO   "NeedTwo"
-#define CONF_ALIGN_LEFT "AlignLeft"
-#define CONF_OLD_ENABLE "OldEnable"
+// #define CONF_NO_EXEC    "NoExec"
+// #define CONF_NEED_READ  "NeedRead"
+// #define CONF_NEED_TWO   "NeedTwo"
+// #define CONF_ALIGN_LEFT "AlignLeft"
+// #define CONF_OLD_ENABLE "OldEnable"
 
 class toRollbackPrefs : public QGroupBox, public toSettingTab
 {
@@ -116,62 +114,98 @@ public:
 };
 
 toRollbackPrefs::toRollbackPrefs(toTool *tool, QWidget* parent, const char* name)
-        : QGroupBox(1, Horizontal, parent, name), toSettingTab("rollback.html#options"), Tool(tool)
+        : QGroupBox(parent), toSettingTab("rollback.html#options"), Tool(tool)
 {
+    if (name)
+        setObjectName(name);
+
+    QVBoxLayout *vbox = new QVBoxLayout;
+    vbox->setSpacing(6);
+    vbox->setContentsMargins(11, 11, 11, 11);
+
+    setLayout(vbox);
+
     setTitle(qApp->translate("toRollbackPrefs", "Rollback Tool" ));
 
-    OldEnable = new QCheckBox(this, "OldEnable");
-    OldEnable->setText(qApp->translate("toRollbackPrefs", "&Enable snapshot too old detection." ));
-    QToolTip::add
-        (OldEnable, qApp->translate("toRollbackPrefs", "Enable snapshot too old detection, will put load on large databases."));
+    OldEnable = new QCheckBox(this);
+    OldEnable->setText(qApp->translate("toRollbackPrefs",
+                                       "&Enable snapshot too old detection." ));
+    OldEnable->setToolTip(qApp->translate(
+                              "toRollbackPrefs",
+                              "Enable snapshot too old detection, will put load on large databases."));
+    vbox->addWidget(OldEnable);
 
-    AlignLeft = new QCheckBox(this, "AlignLeft");
-    AlignLeft->setText(qApp->translate("toRollbackPrefs", "&Disregard start extent." ));
+    AlignLeft = new QCheckBox(this);
+    AlignLeft->setText(qApp->translate("toRollbackPrefs",
+                                       "&Disregard start extent." ));
     AlignLeft->setEnabled(false);
     connect(OldEnable, SIGNAL(toggled(bool)), AlignLeft, SLOT(setEnabled(bool)));
-    QToolTip::add
-        (AlignLeft, qApp->translate("toRollbackPrefs", "Always start from the left border when displaying extent usage."));
+    AlignLeft->setToolTip(qApp->translate(
+                              "toRollbackPrefs",
+                              "Always start from the left border when displaying extent usage."));
+    vbox->addWidget(AlignLeft);
 
-    NoExec = new QCheckBox(this, "NoCopy");
-    NoExec->setText(qApp->translate("toRollbackPrefs", "&Restart reexecuted statements" ));
+    NoExec = new QCheckBox(this);
+    NoExec->setText(qApp->translate("toRollbackPrefs",
+                                    "&Restart reexecuted statements" ));
     NoExec->setEnabled(false);
     connect(OldEnable, SIGNAL(toggled(bool)), NoExec, SLOT(setEnabled(bool)));
-    QToolTip::add
-        (NoExec, qApp->translate("toRollbackPrefs", "Start statements again that have been reexecuted."));
+    NoExec->setToolTip(qApp->translate(
+                           "toRollbackPrefs",
+                           "Start statements again that have been reexecuted."));
+    vbox->addWidget(NoExec);
 
-    NeedRead = new QCheckBox(this, "Needread");
-    NeedRead->setText(qApp->translate("toRollbackPrefs", "&Must read buffers" ));
+    NeedRead = new QCheckBox(this);
+    NeedRead->setText(qApp->translate("toRollbackPrefs",
+                                      "&Must read buffers" ));
     NeedRead->setEnabled(false);
     connect(OldEnable, SIGNAL(toggled(bool)), NeedRead, SLOT(setEnabled(bool)));
-    QToolTip::add
-        (NeedRead, qApp->translate("toRollbackPrefs", "Don't display statements that have not read buffers."));
+    NeedRead->setToolTip(qApp->translate(
+                             "toRollbackPrefs",
+                             "Don't display statements that have not read buffers."));
+    vbox->addWidget(NeedRead);
 
-    NeedTwo = new QCheckBox(this, "NeedTwo");
-    NeedTwo->setText(qApp->translate("toRollbackPrefs", "&Exclude first appearance" ));
+    NeedTwo = new QCheckBox(this);
+    NeedTwo->setText(qApp->translate("toRollbackPrefs",
+                                     "&Exclude first appearance" ));
     NeedTwo->setEnabled(false);
     connect(OldEnable, SIGNAL(toggled(bool)), NeedTwo, SLOT(setEnabled(bool)));
-    QToolTip::add
-        (NeedTwo, qApp->translate("toRollbackPrefs", "A statement must be visible at least two consecutive polls to be displayed."));
+    NeedTwo->setToolTip(qApp->translate(
+                            "toRollbackPrefs",
+                            "A statement must be visible at least two consecutive polls to be displayed."));
+    vbox->addWidget(NeedTwo);
 
-    if (!tool->config(CONF_OLD_ENABLE, "").isEmpty())
-        OldEnable->setChecked(true);
-    if (!tool->config(CONF_NO_EXEC, "Yes").isEmpty())
-        NoExec->setChecked(true);
-    if (!tool->config(CONF_NEED_READ, "Yes").isEmpty())
-        NeedRead->setChecked(true);
-    if (!tool->config(CONF_NEED_TWO, "Yes").isEmpty())
-        NeedTwo->setChecked(true);
-    if (!tool->config(CONF_ALIGN_LEFT, "Yes").isEmpty())
-        AlignLeft->setChecked(true);
+    QSpacerItem *spacer = new QSpacerItem(
+        20,
+        20,
+        QSizePolicy::Minimum,
+        QSizePolicy::Expanding);
+    vbox->addItem(spacer);
+
+//     if (!tool->config(CONF_OLD_ENABLE, "").isEmpty())
+//         OldEnable->setChecked(true);
+//     if (!tool->config(CONF_NO_EXEC, "Yes").isEmpty())
+//         NoExec->setChecked(true);
+//     if (!tool->config(CONF_NEED_READ, "Yes").isEmpty())
+//         NeedRead->setChecked(true);
+//     if (!tool->config(CONF_NEED_TWO, "Yes").isEmpty())
+//         NeedTwo->setChecked(true);
+//     if (!tool->config(CONF_ALIGN_LEFT, "Yes").isEmpty())
+//         AlignLeft->setChecked(true);
+    OldEnable->setChecked(toConfigurationSingle::Instance().oldEnable());
+    NoExec->setChecked(toConfigurationSingle::Instance().noExec());
+    NeedRead->setChecked(toConfigurationSingle::Instance().needRead());
+    NeedTwo->setChecked(toConfigurationSingle::Instance().needTwo());
+    AlignLeft->setChecked(toConfigurationSingle::Instance().alignLeft());
 }
 
 void toRollbackPrefs::saveSetting(void)
 {
-    Tool->setConfig(CONF_NO_EXEC, NoExec->isChecked() ? "Yes" : "");
-    Tool->setConfig(CONF_NEED_READ, NeedRead->isChecked() ? "Yes" : "");
-    Tool->setConfig(CONF_NEED_TWO, NeedTwo->isChecked() ? "Yes" : "");
-    Tool->setConfig(CONF_ALIGN_LEFT, AlignLeft->isChecked() ? "Yes" : "");
-    Tool->setConfig(CONF_OLD_ENABLE, OldEnable->isChecked() ? "Yes" : "");
+    toConfigurationSingle::Instance().setNoExec(NoExec->isChecked());
+    toConfigurationSingle::Instance().setNeedRead(NeedRead->isChecked());
+    toConfigurationSingle::Instance().setNeedTwo(NeedTwo->isChecked());
+    toConfigurationSingle::Instance().setAlignLeft(AlignLeft->isChecked());
+    toConfigurationSingle::Instance().setOldEnable(OldEnable->isChecked());
 }
 
 class toRollbackTool : public toTool
@@ -207,18 +241,20 @@ static toSQL SQLTablespace("toRollbackDialog:TablespaceName",
                            "Get a list of tablespace names, should only have one column and same binds");
 
 toRollbackDialog::toRollbackDialog(toConnection &Connection, QWidget* parent, const char* name)
-        : toRollbackDialogUI(parent, name, true)
+        : QDialog(parent)//, name, true)
 {
+    setupUi(this);
+
     toHelp::connectDialog(this);
 
     try
     {
         toQuery q(Connection, SQLTablespace);
         while (!q.eof())
-            Tablespace->insertItem(q.readValue());
+            Tablespace->addItem(q.readValue());
     }
     catch (...)
-    {}
+        {}
     connect(Tablespace, SIGNAL(textChanged(const QString &)),
             this, SLOT(valueChanged(const QString &)));
 
@@ -282,9 +318,10 @@ void toRollbackDialog::valueChanged(const QString &)
 
 static bool BarsAlignLeft = true;
 
-static void PaintBars(QListViewItem *item, QPainter *p, const QColorGroup & cg,
+static void PaintBars(toTreeWidgetItem *item, QPainter *p, const QColorGroup & cg,
                       int width, std::list<double> &val, std::list<double> &maxExt, std::list<double> &curExt)
 {
+#if 0                           // disabled, wrong override
     if ( val.empty() )
     {
         p->fillRect(0, 0, width, item->height(),
@@ -336,6 +373,7 @@ static void PaintBars(QListViewItem *item, QPainter *p, const QColorGroup & cg,
             lastHeight = height;
         }
     }
+#endif
 }
 
 static toSQL SQLRollback("toRollback:Information",
@@ -380,12 +418,13 @@ public:
 class rollbackItem : public toResultViewItem
     {
     public:
-        rollbackItem(QListView *parent, QListViewItem *after, const QString &buf = QString::null)
+        rollbackItem(toTreeWidget *parent, toTreeWidgetItem *after, const QString &buf = QString::null)
                 : toResultViewItem(parent, after, buf)
         { }
         virtual void paintCell (QPainter *pnt, const QColorGroup & cg,
                                 int column, int width, int alignment)
         {
+#if 0                           // disabled, wrong override
             if (column == 4)
             {
                 std::list<double> items;
@@ -401,10 +440,11 @@ class rollbackItem : public toResultViewItem
                           maxExt, curExt);
                 QPen pen(isSelected() ? cg.highlightedText() : cg.foreground());
                 pnt->setPen(pen);
-                pnt->drawText(0, 0, width, height(), AlignRight, text(column));
+                pnt->drawText(0, 0, width, height(), Qt::AlignRight, text(column));
             }
             else
                 toResultViewItem::paintCell(pnt, cg, column, width, alignment);
+#endif
         }
 
         virtual void setup(void)
@@ -418,7 +458,7 @@ class rollbackItem : public toResultViewItem
         }
     };
 
-    virtual QListViewItem *createItem(QListViewItem *last, const QString &str)
+    virtual toTreeWidgetItem *createItem(toTreeWidgetItem *last, const QString &str)
     {
         return new rollbackItem(this, last, str);
     }
@@ -430,7 +470,7 @@ class rollbackItem : public toResultViewItem
     }
     virtual void query(const QString &sql, const toQList &)
     {
-        QString unit = toConfigurationSingle::Instance().globalConfig(CONF_SIZE_UNIT, DEFAULT_SIZE_UNIT);
+        QString unit(toConfigurationSingle::Instance().sizeUnit());
 
         toQList par;
         par.insert(par.end(), QString::number(toSizeDecode(unit)));
@@ -441,14 +481,14 @@ class rollbackItem : public toResultViewItem
         res += QString::fromLatin1(")");
         for (int i = 0;i < columns();i++)
         {
-            QString str = header()->label(i);
+            QString str = headerItem()->text(i);
             str.replace(repl, res);
-            header()->setLabel(i, str);
+            headerItem()->setText(i, str);
         }
         try
         {
             toQuery trx(connection());
-            for (QListViewItem *i = firstChild();i;i = i->nextSibling())
+            for (toTreeWidgetItem *i = firstChild();i;i = i->nextSibling())
             {
                 toQList args;
                 toPush(args, toQValue(QString(i->text(TRANSCOL - 1))));
@@ -510,7 +550,7 @@ class openItem : public toResultViewItem
             return (toRollbackOpen *)listView();
         }
     public:
-        openItem(QListView *parent, QListViewItem *after, const QString &buf = QString::null)
+        openItem(toTreeWidget *parent, toTreeWidgetItem *after, const QString &buf = QString::null)
                 : toResultViewItem(parent, after, buf)
         { }
         virtual void paintCell (QPainter *pnt, const QColorGroup & cg,
@@ -526,7 +566,7 @@ class openItem : public toResultViewItem
                 toResultViewItem::paintCell(pnt, cg, column, width, alignment);
         }
 
-        virtual int width(const QFontMetrics &fm, const QListView *top, int column) const
+        virtual int width(const QFontMetrics &fm, const toTreeWidget *top, int column) const
         {
             if (column == 2)
                 return 100;
@@ -545,7 +585,7 @@ class openItem : public toResultViewItem
 
     friend class openItem;
 
-    virtual QListViewItem *createItem(QListViewItem *last, const QString &str)
+    virtual toTreeWidgetItem *createItem(toTreeWidgetItem *last, const QString &str)
     {
         return new openItem(this, last, str);
     }
@@ -569,10 +609,10 @@ class openItem : public toResultViewItem
             toConnection &conn = connection();
             toBusy busy;
             toQuery sql(conn, SQLStatementInfo);
-            QListViewItem *last = NULL;
+            toTreeWidgetItem *last = NULL;
             while (!sql.eof())
             {
-                QListViewItem *item = createItem(last, QString::null);
+                toTreeWidgetItem *item = createItem(last, QString::null);
                 last = item;
                 item->setText(0, sql.readValue());
                 item->setText(1, sql.readValue());
@@ -603,18 +643,18 @@ class openItem : public toResultViewItem
                 NumExtents = num;
             }
 
-            bool noExec = true;
-            bool needRead = true;
-            bool needTwo = true;
-            if (RollbackTool.config(CONF_NO_EXEC, "Yes").isEmpty())
-                noExec = false;
-            if (RollbackTool.config(CONF_NEED_READ, "Yes").isEmpty())
-                needRead = false;
-            if (RollbackTool.config(CONF_NEED_TWO, "Yes").isEmpty())
-                needTwo = false;
+            bool noExec = toConfigurationSingle::Instance().noExec();
+            bool needRead = toConfigurationSingle::Instance().needRead();
+            bool needTwo = toConfigurationSingle::Instance().needTwo();
+//             if (RollbackTool.config(CONF_NO_EXEC, "Yes").isEmpty())
+//                 noExec = false;
+//             if (RollbackTool.config(CONF_NEED_READ, "Yes").isEmpty())
+//                 needRead = false;
+//             if (RollbackTool.config(CONF_NEED_TWO, "Yes").isEmpty())
+//                 needTwo = false;
 
             std::map<QString, int> Exists;
-            for (QListViewItem *i = firstChild();i;)
+            for (toTreeWidgetItem *i = firstChild();i;)
             {
                 QString address = i->text(4);
                 Exists[address] = 1;
@@ -628,14 +668,15 @@ class openItem : public toResultViewItem
                     data.Executed = exec;
                     data.BufferGets = bufget;
                     Statements[address] = data;
-                    QListViewItem *next = i->nextSibling();
+                    toTreeWidgetItem *next = i->nextSibling();
                     if (needTwo)
                         delete i;
                     i = next;
                 }
                 else if ((*j).second.BufferGets == bufget && needRead)
-                { // Don't reset, just don't show
-                    QListViewItem *next = i->nextSibling();
+                {
+                    // Don't reset, just don't show
+                    toTreeWidgetItem *next = i->nextSibling();
                     delete i;
                     i = next;
                 }
@@ -675,92 +716,99 @@ toSQL SQLTransactionUsers("toRollback:TransactionUsers",
                           "Get users currently having open transactions");
 
 toRollback::toRollback(QWidget *main, toConnection &connection)
-        : toToolWidget(RollbackTool, "rollback.html", main, connection)
+        : toToolWidget(RollbackTool, "rollback.html", main, connection, "toRollback")
 {
     QToolBar *toolbar = toAllocBar(this, tr("Rollback analyzer"));
+    layout()->addWidget(toolbar);
+
+    UpdateSegmentsAct = new QAction(QPixmap(const_cast<const char**>(refresh_xpm)),
+                                    tr("Update segment list"), this);
+    UpdateSegmentsAct->setShortcut(QKeySequence::Refresh);
+    connect(UpdateSegmentsAct, SIGNAL(triggered()), this, SLOT(refresh(void)));
+    toolbar->addAction(UpdateSegmentsAct);
 
-    new QToolButton(QPixmap(const_cast<const char**>(refresh_xpm)),
-                    tr("Update segment list"),
-                    tr("Update segment list"),
-                    this, SLOT(refresh(void)),
-                    toolbar);
     toolbar->addSeparator();
 
-    QToolButton *enableOld = new QToolButton(toolbar);
-    enableOld->setToggleButton(true);
-    enableOld->setIconSet(QIconSet(QPixmap(const_cast<const char**>(torollback_xpm))));
-    connect(enableOld, SIGNAL(toggled(bool)), this, SLOT(enableOld(bool)));
-    QToolTip::add
-        (enableOld, tr("Enable snapshot too old detection."));
+    enableOldAct = new QAction(QPixmap(const_cast<const char**>(torollback_xpm)),
+                               tr("Enable snapshot too old detection."), this);
+    enableOldAct->setCheckable(true);
+    connect(enableOldAct, SIGNAL(toggled(bool)), this, SLOT(enableOld(bool)));
+    toolbar->addAction(enableOldAct);
+
     toolbar->addSeparator();
 
-    OnlineButton = new QToolButton(QPixmap(const_cast<const char**>(online_xpm)),
-                                   tr("Take segment online"),
-                                   tr("Take segment online"),
-                                   this, SLOT(online(void)),
-                                   toolbar);
-    OnlineButton->setEnabled(false);
-    OfflineButton = new QToolButton(QPixmap(const_cast<const char**>(offline_xpm)),
-                                    tr("Take segment offline"),
-                                    tr("Take segment offline"),
-                                    this, SLOT(offline(void)),
-                                    toolbar);
-    OfflineButton->setEnabled(false);
+    OnlineAct = new QAction(QPixmap(const_cast<const char**>(online_xpm)),
+                            tr("Take segment online"), this);
+    connect(OnlineAct, SIGNAL(triggered()), this, SLOT(online(void)));
+    toolbar->addAction(OnlineAct);
+    OnlineAct->setEnabled(false);
+
+    OfflineAct = new QAction(QPixmap(const_cast<const char**>(offline_xpm)),
+                             tr("Take segment offline"), this);
+    connect(OfflineAct, SIGNAL(triggered()), this, SLOT(offline(void)));
+    toolbar->addAction(OfflineAct);
+    OfflineAct->setEnabled(false);
+
     toolbar->addSeparator();
 
-    new QToolButton(QPixmap(const_cast<const char**>(addrollback_xpm)),
-                    tr("Create new rollback segment"),
-                    tr("Create new rollback segment"),
-                    this, SLOT(addSegment(void)),
-                    toolbar);
-    DropButton = new QToolButton(QPixmap(const_cast<const char**>(trash_xpm)),
-                                 tr("Drop segment"),
-                                 tr("Drop segment"),
-                                 this, SLOT(dropSegment(void)),
-                                 toolbar);
-    DropButton->setEnabled(false);
+    NewAct = new QAction(QPixmap(const_cast<const char**>(addrollback_xpm)),
+                         tr("Create new rollback segment"), this);
+    connect(NewAct, SIGNAL(triggered()), this, SLOT(addSegment(void)));
+    toolbar->addAction(NewAct);
+
+    DropAct = new QAction(QPixmap(const_cast<const char**>(trash_xpm)),
+                          tr("Drop segment"), this);
+    connect(DropAct, SIGNAL(triggered()), this, SLOT(dropSegment(void)));
+    toolbar->addAction(DropAct);
+    DropAct->setEnabled(false);
+
     toolbar->addSeparator();
 
-    new QLabel(tr("Refresh") + " ", toolbar, TO_KDE_TOOLBAR_WIDGET);
-    connect(Refresh = toRefreshCreate(toolbar, TO_KDE_TOOLBAR_WIDGET),
+    QLabel * lab1 = new QLabel(tr("Refresh") + " ", toolbar);
+    toolbar->addWidget(lab1);
+    connect(Refresh = toRefreshCreate(toolbar, TO_TOOLBAR_WIDGET_NAME),
             SIGNAL(activated(const QString &)), this, SLOT(changeRefresh(const QString &)));
+    toolbar->addWidget(Refresh);
 
-    toolbar->setStretchableWidget(new QLabel(toolbar, TO_KDE_TOOLBAR_WIDGET));
-    new toChangeConnection(toolbar, TO_KDE_TOOLBAR_WIDGET);
+    toolbar->addWidget(new toSpacer());
+
+    new toChangeConnection(toolbar, TO_TOOLBAR_WIDGET_NAME);
+
+    QSplitter *splitter = new QSplitter(Qt::Vertical, this);
+    layout()->addWidget(splitter);
 
-    QSplitter *splitter = new QSplitter(Vertical, this);
     Segments = new toRollbackView(splitter);
-    Segments->setSelectionMode(QListView::Single);
-    connect(Segments, SIGNAL(selectionChanged(QListViewItem *)),
-            this, SLOT(changeItem(QListViewItem *)));
+    Segments->setSelectionMode(toTreeWidget::Single);
+    connect(Segments, SIGNAL(selectionChanged(toTreeWidgetItem *)),
+            this, SLOT(changeItem(toTreeWidgetItem *)));
 
-    QTabWidget *tab = new QTabWidget(splitter, "TabWidget");
-    TransactionUsers = new toResultLong(false, false, toQuery::Background, tab);
+    QTabWidget *tab = new QTabWidget(splitter);
+    TransactionUsers = new toResultTableView(false, false, tab);
     tab->addTab(TransactionUsers, tr("Transaction Users"));
     TransactionUsers->setSQL(SQLTransactionUsers);
 
-    QSplitter *horsplit = new QSplitter(Horizontal, splitter);
+    QSplitter *horsplit = new QSplitter(Qt::Horizontal, splitter);
     tab->addTab(horsplit, tr("Open Cursors"));
 
     Statements = new toRollbackOpen(horsplit);
-    Statements->setSelectionMode(QListView::Single);
-    connect(Statements, SIGNAL(selectionChanged(QListViewItem *)),
-            this, SLOT(changeStatement(QListViewItem *)));
+    Statements->setSelectionMode(toTreeWidget::Single);
+    connect(Statements, SIGNAL(selectionChanged(toTreeWidgetItem *)),
+            this, SLOT(changeStatement(toTreeWidgetItem *)));
     CurrentStatement = new toSGAStatement(horsplit);
 
     try
     {
         connect(timer(), SIGNAL(timeout(void)), this, SLOT(refresh(void)));
-        toRefreshParse(timer(), toConfigurationSingle::Instance().globalConfig(CONF_REFRESH, DEFAULT_REFRESH));
+        toRefreshParse(timer(), toConfigurationSingle::Instance().refresh());
     }
     TOCATCH
 
     ToolMenu = NULL;
-    connect(toMainWidget()->workspace(), SIGNAL(windowActivated(QWidget *)),
-            this, SLOT(windowActivated(QWidget *)));
+    connect(toMainWidget()->workspace(), SIGNAL(subWindowActivated(QMdiSubWindow *)),
+            this, SLOT(windowActivated(QMdiSubWindow *)));
 
-    if (!RollbackTool.config(CONF_OLD_ENABLE, "").isEmpty())
-        enableOld->setOn(true);
+    if (toConfigurationSingle::Instance().oldEnable())
+        enableOldAct->setChecked(true);
     else
         Statements->setEnabled(false);
 
@@ -769,38 +817,31 @@ toRollback::toRollback(QWidget *main, toConnection &connection)
     setFocusProxy(Segments);
 }
 
-#define TO_ID_ONLINE  (toMain::TO_TOOL_MENU_ID+ 0)
-#define TO_ID_OFFLINE  (toMain::TO_TOOL_MENU_ID+ 1)
-#define TO_ID_CREATE  (toMain::TO_TOOL_MENU_ID+ 2)
-#define TO_ID_DROP  (toMain::TO_TOOL_MENU_ID+ 3)
-
-void toRollback::windowActivated(QWidget *widget)
+void toRollback::windowActivated(QMdiSubWindow *widget)
 {
-    if (widget == this)
+    if (!widget)
+        return;
+    if (widget->widget() == this)
     {
         if (!ToolMenu)
         {
-            ToolMenu = new QPopupMenu(this);
-            ToolMenu->insertItem(QPixmap(const_cast<const char**>(refresh_xpm)), tr("&Refresh"),
-                                 this, SLOT(refresh(void)),
-                                 toKeySequence(tr("F5", "Rollback|Refresh")));
-            ToolMenu->insertSeparator();
-            ToolMenu->insertItem(QPixmap(const_cast<const char**>(online_xpm)), tr("Online"),
-                                 this, SLOT(online(void)), 0, TO_ID_ONLINE);
-            ToolMenu->insertItem(QPixmap(const_cast<const char**>(offline_xpm)), tr("Offline"),
-                                 this, SLOT(offline(void)), 0, TO_ID_OFFLINE);
-            ToolMenu->insertSeparator();
-            ToolMenu->insertItem(QPixmap(const_cast<const char**>(addrollback_xpm)), tr("Create segment..."),
-                                 this, SLOT(addSegment(void)), 0, TO_ID_CREATE);
-            ToolMenu->insertItem(QPixmap(const_cast<const char**>(trash_xpm)), tr("Drop segment"),
-                                 this, SLOT(dropSegment(void)), 0, TO_ID_DROP);
-            ToolMenu->insertSeparator();
-            ToolMenu->insertItem(tr("&Change Refresh"), Refresh, SLOT(setFocus(void)),
-                                 toKeySequence(tr("Alt+R", "Rollback|Change refresh")));
-            toMainWidget()->menuBar()->insertItem(tr("&Rollback"), ToolMenu, -1, toToolMenuIndex());
-            ToolMenu->setItemEnabled(TO_ID_ONLINE, OnlineButton->isEnabled());
-            ToolMenu->setItemEnabled(TO_ID_OFFLINE, OfflineButton->isEnabled());
-            ToolMenu->setItemEnabled(TO_ID_DROP, DropButton->isEnabled());
+            ToolMenu = new QMenu(tr("&Rollback"), this);
+
+            ToolMenu->addAction(UpdateSegmentsAct);
+
+            ToolMenu->addSeparator();
+
+            ToolMenu->addAction(OnlineAct);
+            ToolMenu->addAction(OfflineAct);
+
+            ToolMenu->addSeparator();
+
+            ToolMenu->addAction(NewAct);
+            ToolMenu->addAction(DropAct);
+
+            ToolMenu->addSeparator();
+
+            toMainWidget()->addCustomMenu(ToolMenu);
         }
     }
     else
@@ -812,9 +853,9 @@ void toRollback::windowActivated(QWidget *widget)
 
 void toRollback::refresh(void)
 {
-    BarsAlignLeft = !RollbackTool.config(CONF_ALIGN_LEFT, "Yes").isEmpty();
+    BarsAlignLeft = toConfigurationSingle::Instance().alignLeft();
 
-    QListViewItem *item = Segments->selectedItem();
+    toTreeWidgetItem *item = Segments->selectedItem();
     QString current;
     if (item)
         current = item->text(TRANSCOL - 1);
@@ -845,34 +886,25 @@ void toRollback::refresh(void)
     TransactionUsers->refresh();
 }
 
-void toRollback::changeStatement(QListViewItem *item)
+void toRollback::changeStatement(toTreeWidgetItem *item)
 {
     if (item)
         CurrentStatement->changeAddress(item->text(4));
 }
 
-void toRollback::changeItem(QListViewItem *item)
+void toRollback::changeItem(toTreeWidgetItem *item)
 {
     if (item)
     {
-        if (item->text(3) == QString::fromLatin1("OFFLINE"))
-            OfflineButton->setEnabled(false);
-        else
-            OfflineButton->setEnabled(true);
-        if (item->text(3) == QString::fromLatin1("ONLINE"))
-            OnlineButton->setEnabled(false);
-        else
-            OnlineButton->setEnabled(true);
+        OfflineAct->setEnabled(item->text(3) != QString::fromLatin1("OFFLINE"));
+        OnlineAct->setEnabled(item->text(3) != QString::fromLatin1("ONLINE"));
     }
     else
     {
-        OnlineButton->setEnabled(false);
-        OfflineButton->setEnabled(false);
+        OnlineAct->setEnabled(false);
+        OfflineAct->setEnabled(false);
     }
-    DropButton->setEnabled(item);
-    ToolMenu->setItemEnabled(TO_ID_ONLINE, OnlineButton->isEnabled());
-    ToolMenu->setItemEnabled(TO_ID_OFFLINE, OfflineButton->isEnabled());
-    ToolMenu->setItemEnabled(TO_ID_DROP, DropButton->isEnabled());
+    DropAct->setEnabled(item);
 }
 
 void toRollback::changeRefresh(const QString &str)
@@ -886,7 +918,7 @@ void toRollback::changeRefresh(const QString &str)
 
 QString toRollback::currentSegment(void)
 {
-    QListViewItem *item = Segments->selectedItem();
+    toTreeWidgetItem *item = Segments->selectedItem();
     if (!item)
         throw tr("No segment selected");
     return item->text(0);
