@@ -1,39 +1,43 @@
-/*****
-*
-* TOra - An Oracle Toolkit for DBA's and developers
-* Copyright (C) 2003-2005 Quest Software, Inc
-* Portions Copyright (C) 2005 Other Contributors
-* 
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License
-* as published by the Free Software Foundation;  only version 2 of
-* the License is valid for this program.
-* 
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-* 
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*
-*      As a special exception, you have permission to link this program
-*      with the Oracle Client libraries and distribute executables, as long
-*      as you follow the requirements of the GNU GPL in regard to all of the
-*      software in the executable aside from Oracle client libraries.
-*
-*      Specifically you are not permitted to link this program with the
-*      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
-*      And you are not permitted to distribute binaries compiled against
-*      these libraries without written consent from Quest Software, Inc.
-*      Observe that this does not disallow linking to the Qt Free Edition.
-*
-*      You may link this product with any GPL'd Qt library such as Qt/Free
-*
-* All trademarks belong to their respective owners.
-*
-*****/
+
+/* BEGIN_COMMON_COPYRIGHT_HEADER
+ *
+ * TOra - An Oracle Toolkit for DBA's and developers
+ * 
+ * Shared/mixed copyright is held throughout files in this product
+ * 
+ * Portions Copyright (C) 2000-2001 Underscore AB
+ * Portions Copyright (C) 2003-2005 Quest Software, Inc.
+ * Portions Copyright (C) 2004-2008 Numerous Other Contributors
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation;  only version 2 of
+ * the License is valid for this program.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ *      As a special exception, you have permission to link this program
+ *      with the Oracle Client libraries and distribute executables, as long
+ *      as you follow the requirements of the GNU GPL in regard to all of the
+ *      software in the executable aside from Oracle client libraries.
+ * 
+ *      Specifically you are not permitted to link this program with the
+ *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
+ *      And you are not permitted to distribute binaries compiled against
+ *      these libraries. 
+ * 
+ *      You may link this product with any GPL'd Qt library.
+ * 
+ * All trademarks belong to their respective owners.
+ *
+ * END_COMMON_COPYRIGHT_HEADER */
 
 #include "utils.h"
 
@@ -53,25 +57,22 @@
 #include "tosql.h"
 #include "totool.h"
 #include "towaitevents.h"
-
-#ifdef TO_KDE
-#  include <kmenubar.h>
-#endif
+#include "toresulttableview.h"
 
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qmenubar.h>
 #include <qmessagebox.h>
-#include <qpopupmenu.h>
 #include <qsplitter.h>
 #include <qtimer.h>
 #include <qtoolbar.h>
 #include <qtoolbutton.h>
 #include <qtooltip.h>
-#include <qworkspace.h>
-#include <qworkspace.h>
+#include <QMdiArea>
 
-#include "tosession.moc"
+#include <QTabWidget>
+#include <QList>
+#include <QPixmap>
 
 #include "icons/add.xpm"
 #include "icons/clock.xpm"
@@ -90,8 +91,7 @@ protected:
         return const_cast<const char**>(tosession_xpm);
     }
 public:
-    toSessionTool()
-            : toTool(210, "Sessions")
+    toSessionTool() : toTool(210, "Sessions")
     { }
     virtual const char *menuItem()
     {
@@ -99,25 +99,16 @@ public:
     }
     virtual QWidget *toolWindow(QWidget *parent, toConnection &connection)
     {
-        if (toIsOracle(connection))
+        if (toIsOracle(connection) || toIsPostgreSQL(connection))
             return new toSession(parent, connection);
-#ifdef TOSESSIONMYSQL_H
-
-        else if (toIsMySQL(connection))
-            return new toSessionMySQL(*this, parent, connection);
-#endif
 
         return NULL;
     }
     virtual bool canHandle(toConnection &conn)
     {
-        return toIsOracle(conn)
-#ifdef TOSESSIONMYSQL_H
-               || toIsMySQL(conn)
-#endif
-               ;
+        return toIsOracle(conn) || toIsPostgreSQL(conn);
     }
-    virtual void closeWindow(toConnection &connection){};
+    virtual void closeWindow(toConnection &connection) {};
 };
 
 static toSessionTool SessionTool;
@@ -126,6 +117,7 @@ static toSQL SQLConnectInfo("toSession:ConnectInfo",
                             "select authentication_type,osuser,network_service_banner\n"
                             "  from v$session_connect_info where sid = :f1<char[101]>",
                             "Get connection info for a session");
+
 static toSQL SQLLockedObject("toSession:LockedObject",
                              "select b.Object_Name \"Object Name\",\n"
                              "       b.Object_Type \"Type\",\n"
@@ -136,6 +128,26 @@ static toSQL SQLLockedObject("toSession:LockedObject",
                              " where a.object_id = b.object_id\n"
                              "   and a.session_id = :f1<char[101]>",
                              "Display info about objects locked by this session");
+
+static toSQL SQLLockedObjectPg(
+    "toSession:LockedObject",
+    "SELECT c.relname AS \"Name\",\n"
+    "       l.locktype,\n"
+    "       n.nspname,\n"
+    "       l.TRANSACTION,\n"
+    "       l.MODE,\n"
+    "       l.granted,\n"
+    "       l.pid\n"
+    "  FROM pg_catalog.pg_locks l,\n"
+    "       pg_class c,\n"
+    "       pg_namespace n\n"
+    " WHERE l.relation = c.OID\n"
+    "   AND c.relnamespace = n.OID\n"
+    "   AND l.pid = :f1<int>",
+    "",
+    "",
+    "PostgreSQL");
+
 static toSQL SQLOpenCursors("toSession:OpenCursor",
                             "select SQL_Text \"SQL\", Address||':'||Hash_Value \" Address\"\n"
                             "  from v$open_cursor where sid = :f1<char[101]>",
@@ -223,76 +235,139 @@ static toSQL SQLSessions("toSession:ListSession",
                          "   AND (d.child_number = 0 OR d.child_number IS NULL)\n"
                          "   AND a.paddr = e.addr(+)\n"
                          "%1 ORDER BY a.Sid",
-                         "List sessions, must have same number of culumns and the first and last 2 must be the same");
+                         "List sessions, must have same number of columns and the first and last 2 must be the same");
+
+static toSQL SQLSessionsPg(
+    "toSession:ListSession",
+    "SELECT pg_stat_get_backend_pid ( s.backendid ) AS \"Backend ID\",\n"
+    "       ( SELECT u.usename\n"
+    "           FROM pg_user u\n"
+    "          WHERE u.usesysid = pg_stat_get_backend_userid ( s.backendid ) ) AS \"User\",\n"
+    "       pg_stat_get_backend_client_addr ( s.backendid ) AS \"From\",\n"
+    "       pg_stat_get_backend_client_port ( s.backendid ) AS \"Port\",\n"
+    "       pg_stat_get_backend_activity_start ( s.backendid ) AS \"Started\",\n"
+    "       pg_stat_get_backend_waiting ( s.backendid ) AS \"Waiting\",\n"
+    "       pg_stat_get_backend_activity ( s.backendid ) AS \"Current Query\"\n"
+    "  FROM ( SELECT pg_stat_get_backend_idset ( ) AS backendid ) AS s",
+    "",
+    "",
+    "PostgreSQL");
 
 toSession::toSession(QWidget *main, toConnection &connection)
-        : toToolWidget(SessionTool, "session.html", main, connection)
+        : toToolWidget(SessionTool, "session.html", main, connection, "toSession")
 {
     QToolBar *toolbar = toAllocBar(this, tr("Session manager"));
+    layout()->addWidget(toolbar);
 
-    new QToolButton(QPixmap(const_cast<const char**>(refresh_xpm)),
-                    tr("Update sessionlist"),
-                    tr("Update sessionlist"),
-                    this, SLOT(refresh(void)),
-                    toolbar);
-    toolbar->addSeparator();
-    Select = new toResultCombo(toolbar, TO_KDE_TOOLBAR_WIDGET);
-    Select->setSelected(tr("Only active users"));
-    Select->additionalItem(tr("Only active users"));
-    Select->additionalItem(tr("All"));
-    Select->additionalItem(tr("No background"));
-    Select->additionalItem(tr("No system"));
-    Select->query(toSQL::sql(toSQL::TOSQL_USERLIST));
+    refreshAct =
+        toolbar->addAction(
+            QIcon(QPixmap(const_cast<const char**>(refresh_xpm))),
+            tr("Update sessionlist"),
+            this,
+            SLOT(refresh(void)));
+    refreshAct->setShortcut(QKeySequence::Refresh);
 
-    connect(Select, SIGNAL(activated(int)), this, SLOT(refresh()));
+    if (toIsOracle(connection))
+    {
+        toolbar->addSeparator();
 
-    toolbar->addSeparator();
-    new QToolButton(QPixmap(const_cast<const char**>(clock_xpm)),
-                    tr("Enable timed statistics"),
-                    tr("Enable timed statistics"),
-                    this, SLOT(enableStatistics(void)),
-                    toolbar);
-    new QToolButton(QPixmap(const_cast<const char**>(noclock_xpm)),
-                    tr("Disable timed statistics"),
-                    tr("Disable timed statistics"),
-                    this, SLOT(disableStatistics(void)),
-                    toolbar);
-    toolbar->addSeparator();
-    new QToolButton(QPixmap(const_cast<const char**>(kill_xpm)),
-                    tr("Disconnect selected session"),
-                    tr("Disconnect selected session"),
-                    this, SLOT(disconnectSession(void)),
-                    toolbar);
-    toolbar->addSeparator();
-    new QLabel(tr("Refresh") + " ", toolbar, TO_KDE_TOOLBAR_WIDGET);
-    connect(Refresh = toRefreshCreate(toolbar, TO_KDE_TOOLBAR_WIDGET), SIGNAL(activated(const QString &)), this, SLOT(changeRefresh(const QString &)));
-    toolbar->addSeparator();
+        Select = new toResultCombo(toolbar, TO_TOOLBAR_WIDGET_NAME);
+        Select->setSelected(tr("Only active users"));
+        Select->additionalItem(tr("Only active users"));
+        Select->additionalItem(tr("All"));
+        Select->additionalItem(tr("No background"));
+        Select->additionalItem(tr("No system"));
+        Select->query(toSQL::sql(toSQL::TOSQL_USERLIST));
+        toolbar->addWidget(Select);
 
-    QToolButton *btn = new QToolButton(toolbar);
-    btn->setToggleButton(true);
-    btn->setIconSet(QPixmap(const_cast<const char**>(filter_xpm)));
-    connect(btn, SIGNAL(toggled(bool)), this, SLOT(excludeSelection(bool)));
-    QToolTip::add
-        (btn, tr("Exclude selected sessions"));
-    new QToolButton(QPixmap(const_cast<const char**>(add_xpm)),
-                    tr("Select all sessions"),
-                    tr("Select all sessions"),
-                    this, SLOT(selectAll(void)),
-                    toolbar);
-    new QToolButton(QPixmap(const_cast<const char**>(minus_xpm)),
-                    tr("Deselect all sessions"),
-                    tr("Deselect all sessions"),
-                    this, SLOT(selectNone(void)),
-                    toolbar);
+        connect(Select, SIGNAL(activated(int)), this, SLOT(refresh()));
 
-    toolbar->setStretchableWidget(Total = new QLabel(toolbar, TO_KDE_TOOLBAR_WIDGET));
-    Total->setAlignment(AlignRight | AlignVCenter | ExpandTabs);
-    new toChangeConnection(toolbar, TO_KDE_TOOLBAR_WIDGET);
+        toolbar->addSeparator();
+
+        enableTimedAct =
+            toolbar->addAction(
+                QIcon(QPixmap(const_cast<const char**>(clock_xpm))),
+                tr("Enable timed statistics"),
+                this,
+                SLOT(enableStatistics(void)));
+
+        disableTimedAct =
+            toolbar->addAction(
+                QIcon(QPixmap(const_cast<const char**>(noclock_xpm))),
+                tr("Disable timed statistics"),
+                this,
+                SLOT(disableStatistics(void)));
+
+        toolbar->addSeparator();
+
+        disconnectAct =
+            toolbar->addAction(
+                QIcon(QPixmap(const_cast<const char**>(kill_xpm))),
+                tr("Disconnect selected session"),
+                this,
+                SLOT(disconnectSession(void)));
+
+        toolbar->addSeparator();
+    }
+    else
+    {
+        enableTimedAct  = NULL;
+        disableTimedAct = NULL;
+
+        disconnectAct =
+            toolbar->addAction(
+                QIcon(QPixmap(const_cast<const char**>(kill_xpm))),
+                tr("Cancel selected backend"),
+                this,
+                SLOT(cancelBackend(void)));
+    }
+
+    toolbar->addWidget(
+        new QLabel(tr("Refresh") + " ", toolbar));
+
+    Refresh = toRefreshCreate(toolbar, TO_TOOLBAR_WIDGET_NAME);
+    connect(Refresh,
+            SIGNAL(activated(const QString &)),
+            this, SLOT(changeRefresh(const QString &)));
+    toolbar->addWidget(Refresh);
+
+    if (toIsOracle(connection))
+    {
+        toolbar->addSeparator();
+
+        QToolButton *btn = new QToolButton(toolbar);
+        btn->setCheckable(true);
+        btn->setIcon(QIcon(filter_xpm));
+        connect(btn, SIGNAL(toggled(bool)), this, SLOT(excludeSelection(bool)));
+        btn->setToolTip(tr("Exclude selected sessions"));
+        toolbar->addWidget(btn);
+
+        toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(add_xpm))),
+                           tr("Select all sessions"),
+                           this,
+                           SLOT(selectAll(void)));
+
+        toolbar->addAction(QIcon(QPixmap(const_cast<const char**>(minus_xpm))),
+                           tr("Deselect all sessions"),
+                           this,
+                           SLOT(selectNone(void)));
+    }
+
+    toolbar->addWidget(new toSpacer());
+
+    Total = new QLabel(toolbar);
+    Total->setAlignment(Qt::AlignRight | Qt::AlignVCenter/* | Qt::ExpandTabs*/);
+    toolbar->addWidget(Total);
+
+    new toChangeConnection(toolbar, TO_TOOLBAR_WIDGET_NAME);
+
+    QSplitter *splitter = new QSplitter(Qt::Vertical, this);
+    layout()->addWidget(splitter);
 
-    QSplitter *splitter = new QSplitter(Vertical, this);
     Sessions = new toSessionList(splitter);
+    Sessions->setAlternatingRowColors(true);
 
-    QValueList<int> list;
+    QList<int> list;
     list.append(75);
     splitter->setSizes(list);
 
@@ -304,68 +379,96 @@ toSession::toSession(QWidget *main, toConnection &connection)
     CurrentStatement = new toSGAStatement(ResultTab);
     ResultTab->addTab(CurrentStatement, tr("Current Statement"));
 
-    QString sql = toSQL::string(TOSQL_LONGOPS, connection);
-    sql += " AND b.sid = :sid<char[101]> AND b.serial# = :ser<char[101]>";
-    LongOps = new toResultLong(true, false, toQuery::Background, ResultTab);
-    LongOps->setSQL(sql);
-    ResultTab->addTab(LongOps, tr("Long ops"));
+    if (toIsOracle(connection))
+    {
+        QString sql = toSQL::string(TOSQL_LONGOPS, connection);
+        sql += " AND b.sid = :sid<char[101]> AND b.serial# = :ser<char[101]> order by b.start_time desc";
+        LongOps = new toResultLong(true, false, toQuery::Background, ResultTab);
+        LongOps->setSQL(sql);
+        ResultTab->addTab(LongOps, tr("Long ops"));
 
-    StatisticSplitter = new QSplitter(Horizontal, ResultTab);
-    SessionStatistics = new toResultStats(false, 0, StatisticSplitter);
-    WaitBar = new toResultBar(StatisticSplitter);
-    WaitBar->setSQL(SQLSessionWait);
-    WaitBar->setTitle(tr("Session wait states"));
-    WaitBar->setYPostfix(QString::fromLatin1("ms/s"));
-    IOBar = new toResultBar(StatisticSplitter);
-    IOBar->setSQL(SQLSessionIO);
-    IOBar->setTitle(tr("Session I/O"));
-    IOBar->setYPostfix(QString::fromLatin1("blocks/s"));
-    ResultTab->addTab(StatisticSplitter, tr("Statistics"));
+        StatisticSplitter = new QSplitter(Qt::Horizontal, ResultTab);
+        SessionStatistics = new toResultStats(false, 0, StatisticSplitter);
+        WaitBar = new toResultBar(StatisticSplitter);
+        WaitBar->setSQL(SQLSessionWait);
+        WaitBar->setTitle(tr("Session wait states"));
+        WaitBar->setYPostfix(QString::fromLatin1("ms/s"));
+        IOBar = new toResultBar(StatisticSplitter);
+        IOBar->setSQL(SQLSessionIO);
+        IOBar->setTitle(tr("Session I/O"));
+        IOBar->setYPostfix(QString::fromLatin1("blocks/s"));
+        ResultTab->addTab(StatisticSplitter, tr("Statistics"));
 
-    Waits = new toWaitEvents(0, ResultTab, "waits");
-    ResultTab->addTab(Waits, tr("Wait events"));
+        Waits = new toWaitEvents(0, ResultTab, "waits");
+        ResultTab->addTab(Waits, tr("Wait events"));
 
-    ConnectInfo = new toResultLong(true, false, toQuery::Background, ResultTab);
-    ConnectInfo->setSQL(SQLConnectInfo);
-    ResultTab->addTab(ConnectInfo, tr("Connect Info"));
-    PendingLocks = new toResultLock(ResultTab);
-    ResultTab->addTab(PendingLocks, tr("Pending Locks"));
-    LockedObjects = new toResultLong(false, false, toQuery::Background, ResultTab);
-    ResultTab->addTab(LockedObjects, tr("Locked Objects"));
-    LockedObjects->setSQL(SQLLockedObject);
-    AccessedObjects = new toResultLong(false, false, toQuery::Background, ResultTab);
-    AccessedObjects->setSQL(SQLAccessedObjects);
-    ResultTab->addTab(AccessedObjects, tr("Accessing"));
+        ConnectInfo = new toResultLong(true, false, toQuery::Background, ResultTab);
+        ConnectInfo->setSQL(SQLConnectInfo);
+        ResultTab->addTab(ConnectInfo, tr("Connect Info"));
 
-    PreviousStatement = new toSGAStatement(ResultTab);
-    ResultTab->addTab(PreviousStatement, tr("Previous Statement"));
+        PendingLocks = new toResultLock(ResultTab);
+        ResultTab->addTab(PendingLocks, tr("Pending Locks"));
 
-    OpenSplitter = new QSplitter(Horizontal, ResultTab);
-    ResultTab->addTab(OpenSplitter, tr("Open Cursors"));
-    OpenCursors = new toResultLong(false, true, toQuery::Background, OpenSplitter);
-    OpenCursors->setSQL(SQLOpenCursors);
-    OpenStatement = new toSGAStatement(OpenSplitter);
+        LockedObjects = new toResultTableView(false, false, ResultTab);
+        ResultTab->addTab(LockedObjects, tr("Locked Objects"));
+        LockedObjects->setSQL(SQLLockedObject);
 
-    Sessions->setSelectionMode(QListView::Single);
-    OpenCursors->setSelectionMode(QListView::Single);
-    connect(Sessions, SIGNAL(selectionChanged(QListViewItem *)),
-            this, SLOT(changeItem(QListViewItem *)));
-    connect(OpenCursors, SIGNAL(selectionChanged(QListViewItem *)),
-            this, SLOT(changeCursor(QListViewItem *)));
-    connect(ResultTab, SIGNAL(currentChanged(QWidget *)),
-            this, SLOT(changeTab(QWidget *)));
+        AccessedObjects = new toResultLong(false, false, toQuery::Background, ResultTab);
+        AccessedObjects->setSQL(SQLAccessedObjects);
+        ResultTab->addTab(AccessedObjects, tr("Accessing"));
+
+        PreviousStatement = new toSGAStatement(ResultTab);
+        ResultTab->addTab(PreviousStatement, tr("Previous Statement"));
+
+        OpenSplitter = new QSplitter(Qt::Horizontal, ResultTab);
+        ResultTab->addTab(OpenSplitter, tr("Open Cursors"));
+        OpenCursors = new toResultLong(false, true, toQuery::Background, OpenSplitter);
+        OpenCursors->setSQL(SQLOpenCursors);
+        OpenStatement = new toSGAStatement(OpenSplitter);
+
+        OpenCursors->setSelectionMode(toTreeWidget::Single);
+        connect(OpenCursors, SIGNAL(selectionChanged(toTreeWidgetItem *)),
+                this, SLOT(changeCursor(toTreeWidgetItem *)));
+    }
+    else
+    {
+        LongOps           = NULL;
+        StatisticSplitter = NULL;
+        SessionStatistics = NULL;
+        WaitBar           = NULL;
+        IOBar             = NULL;
+        Waits             = NULL;
+        ConnectInfo       = NULL;
+        PendingLocks      = NULL;
+        AccessedObjects   = NULL;
+        PreviousStatement = NULL;
+        OpenSplitter      = NULL;
+        OpenCursors       = NULL;
+        OpenStatement     = NULL;
+
+        LockedObjects = new toResultTableView(false, false, ResultTab);
+        ResultTab->addTab(LockedObjects, tr("Locked Objects"));
+        LockedObjects->setSQL(SQLLockedObject);
+    }
+
+    Sessions->setSelectionMode(toTreeWidget::Single);
+    connect(Sessions, SIGNAL(selectionChanged(toTreeWidgetItem *)),
+            this, SLOT(changeItem(toTreeWidgetItem *)));
+    connect(ResultTab, SIGNAL(currentChanged(int)),
+            this, SLOT(changeTab(int)));
 
     try
     {
         connect(timer(), SIGNAL(timeout(void)), this, SLOT(refreshTabs(void)));
         toRefreshParse(timer());
     }
-    TOCATCH
-    CurrentTab = StatisticSplitter;
+    TOCATCH;
+
+    CurrentTab = CurrentStatement;
 
     ToolMenu = NULL;
-    connect(toMainWidget()->workspace(), SIGNAL(windowActivated(QWidget *)),
-            this, SLOT(windowActivated(QWidget *)));
+    connect(toMainWidget()->workspace(), SIGNAL(subWindowActivated(QMdiSubWindow *)),
+            this, SLOT(windowActivated(QMdiSubWindow *)));
     refresh();
 
     setFocusProxy(Sessions);
@@ -373,12 +476,13 @@ toSession::toSession(QWidget *main, toConnection &connection)
 
 bool toSession::canHandle(toConnection &conn)
 {
-    return toIsOracle(conn);
+    return toIsOracle(conn) || toIsPostgreSQL(conn);
 }
 
 void toSession::excludeSelection(bool tgl)
 {
-    toSessionList::sessionFilter *filt = dynamic_cast<toSessionList::sessionFilter *>(Sessions->filter());
+    toSessionList::sessionFilter *filt =
+        dynamic_cast<toSessionList::sessionFilter *>(Sessions->filter());
     if (filt)
     {
         filt->setShow(!tgl);
@@ -388,7 +492,9 @@ void toSession::excludeSelection(bool tgl)
 
 void toSession::selectAll(void)
 {
-    for (QListViewItem *item = Sessions->firstChild();item;item = item->nextSibling())
+    for (toTreeWidgetItem *item = Sessions->firstChild();
+            item;
+            item = item->nextSibling())
     {
         toResultViewCheck * chk = dynamic_cast<toResultViewCheck *>(item);
         if (chk)
@@ -398,7 +504,7 @@ void toSession::selectAll(void)
 
 void toSession::selectNone(void)
 {
-    for (QListViewItem *item = Sessions->firstChild();item;item = item->nextSibling())
+    for (toTreeWidgetItem *item = Sessions->firstChild();item;item = item->nextSibling())
     {
         toResultViewCheck * chk = dynamic_cast<toResultViewCheck *>(item);
         if (chk)
@@ -406,11 +512,11 @@ void toSession::selectNone(void)
     }
 }
 
-QListViewItem *toSessionList::createItem(QListViewItem *last, const QString &str)
+toTreeWidgetItem *toSessionList::createItem(toTreeWidgetItem *last, const QString &str)
 {
     sessionFilter *filt = dynamic_cast<sessionFilter *>(filter());
-    if (filt && filt->show())
-        return new toResultViewCheck(this, last, str, QCheckListItem::CheckBox);
+    if (filt && filt->show() && toIsOracle(connection()))
+        return new toResultViewCheck(this, last, str, toTreeWidgetCheck::CheckBox);
     else
         return new toResultViewItem(this, last, str);
 }
@@ -422,7 +528,7 @@ void toSessionList::updateFilter()
         filt->updateList(this);
 }
 
-bool toSessionList::sessionFilter::check(const QListViewItem *item)
+bool toSessionList::sessionFilter::check(const toTreeWidgetItem *item)
 {
     if (!OnlyDatabase.isEmpty())
     {
@@ -455,7 +561,7 @@ bool toSessionList::sessionFilter::check(const QListViewItem *item)
 void toSessionList::sessionFilter::updateList(toResultLong *lst)
 {
     bool first = true;
-    for (QListViewItem *item = lst->firstChild();item;item = item->nextSibling())
+    for (toTreeWidgetItem *item = lst->firstChild();item;item = item->nextSibling())
     {
         toResultViewCheck * chk = dynamic_cast<toResultViewCheck *>(item);
         if (chk)
@@ -471,28 +577,39 @@ void toSessionList::sessionFilter::updateList(toResultLong *lst)
     }
 }
 
-void toSession::windowActivated(QWidget *widget)
+void toSession::windowActivated(QMdiSubWindow *widget)
 {
-    if (widget == this)
+    if (!widget)
+        return;
+    if (widget->widget() == this)
     {
         if (!ToolMenu)
         {
-            ToolMenu = new QPopupMenu(this);
-            ToolMenu->insertItem(QPixmap(const_cast<const char**>(refresh_xpm)), tr("&Refresh"),
-                                 this, SLOT(refresh(void)),
-                                 toKeySequence(tr("F5", "Session|Refresh")));
-            ToolMenu->insertSeparator();
-            ToolMenu->insertItem(QPixmap(const_cast<const char**>(clock_xpm)), tr("Enable timed statistics"),
-                                 this, SLOT(enableStatistics(void)));
-            ToolMenu->insertItem(QPixmap(const_cast<const char**>(noclock_xpm)), tr("Disable timed statistics"),
-                                 this, SLOT(disableStatistics(void)));
-            ToolMenu->insertSeparator();
-            ToolMenu->insertItem(QPixmap(const_cast<const char**>(kill_xpm)), tr("Disconnect session"),
-                                 this, SLOT(disconnectSession(void)));
-            ToolMenu->insertSeparator();
-            ToolMenu->insertItem(tr("&Change Refresh"), Refresh, SLOT(setFocus(void)),
-                                 toKeySequence(tr("Alt+R", "Session|Change refresh")));
-            toMainWidget()->menuBar()->insertItem(tr("&Session"), ToolMenu, -1, toToolMenuIndex());
+            ToolMenu = new QMenu(tr("&Session"), this);
+
+            // don't use toIs<connection type> here. causes crash on
+            // shutdown when windows are closed/changed.
+
+            if (refreshAct)
+                ToolMenu->addAction(refreshAct);
+
+            ToolMenu->addSeparator();
+
+            if (enableTimedAct)
+                ToolMenu->addAction(enableTimedAct);
+            if (disableTimedAct)
+                ToolMenu->addAction(disableTimedAct);
+
+            if (enableTimedAct || disableTimedAct)
+                ToolMenu->addSeparator();
+
+            if (disconnectAct)
+            {
+                ToolMenu->addAction(disconnectAct);
+                ToolMenu->addSeparator();
+            }
+
+            toMainWidget()->addCustomMenu(ToolMenu);
         }
     }
     else
@@ -506,7 +623,7 @@ void toSession::refresh(void)
 {
     try
     {
-        QListViewItem *item = Sessions->selectedItem();
+        toTreeWidgetItem *item = Sessions->selectedItem();
         if (item)
         {
             Session = item->text(0);
@@ -515,27 +632,36 @@ void toSession::refresh(void)
         else
             Session = Serial = QString::null;
         QString sql = toSQL::string(SQLSessions, connection());
-        QString extra;
-        if (Select->currentItem() == 0)
-            extra = "   AND a.Type != 'BACKGROUND' AND a.Status != 'INACTIVE'\n";
-        else if (Select->currentItem() == 1)
-            ; // Do nothing
-        else if (Select->currentItem() == 2)
-            extra = "   AND a.Type != 'BACKGROUND'\n";
-        else if (Select->currentItem() == 3)
-            extra = "   AND a.SchemaName NOT IN ('SYS','SYSTEM')\n";
-        else
-            extra = "   AND a.SchemaName = '" + Select->currentText() + "'\n";
-        Sessions->setSQL(sql.arg(extra));
+
+        if (toIsOracle(connection()))
+        {
+            QString extra;
+            if (Select->currentIndex() == 0)
+                extra = "   AND a.Type != 'BACKGROUND' AND a.Status != 'INACTIVE'\n";
+            else if (Select->currentIndex() == 1)
+                ; // Do nothing
+            else if (Select->currentIndex() == 2)
+                extra = "   AND a.Type != 'BACKGROUND'\n";
+            else if (Select->currentIndex() == 3)
+                extra = "   AND a.SchemaName NOT IN ('SYS','SYSTEM')\n";
+            else
+                extra = "   AND a.SchemaName = '" + Select->currentText() + "'\n";
+
+            sql = sql.arg(extra);
+        }
+
+        Sessions->setSQL(sql);
         Sessions->refresh();
     }
-    TOCATCH
+    TOCATCH;
 }
 
 void toSession::done(void)
 {
     int system = 0, total = 0, active = 0;
-    for (QListViewItem *item = Sessions->firstChild();item;item = item->nextSibling())
+    for (toTreeWidgetItem *item = Sessions->firstChild();
+            item;
+            item = item->nextSibling())
     {
         if (item->text(0) == Session &&
                 item->text(1) == Serial)
@@ -548,7 +674,9 @@ void toSession::done(void)
         else if (item->text(3) == "ACTIVE")
             active++;
     }
-    Total->setText(QString("Total <B>%1</B> (Active <B>%3</B>, System <B>%2</B>)").arg(total).arg(system).arg(active));
+    Total->setText(QString("Total <B>%1</B> (Active <B>%3</B>, System <B>%2</B>)")
+                   .arg(total).arg(system).arg(active));
+    Sessions->resizeColumnsToContents();
 }
 
 void toSession::enableStatistics(bool enable)
@@ -568,12 +696,14 @@ void toSession::enableStatistics(bool enable)
     }
 }
 
-void toSession::changeTab(QWidget *tab)
+void toSession::changeTab(int index)
 {
+    QWidget *tab = ResultTab->widget(index);
+
     if (tab != CurrentTab)
     {
         CurrentTab = tab;
-        QListViewItem *item = Sessions->selectedItem();
+        toTreeWidgetItem *item = Sessions->selectedItem();
         if (item)
         {
             if (CurrentTab == StatisticSplitter)
@@ -583,7 +713,7 @@ void toSession::changeTab(QWidget *tab)
                 {
                     SessionStatistics->changeSession(ses);
                 }
-                TOCATCH
+                TOCATCH;
             }
             else if (CurrentTab == ConnectInfo)
             {
@@ -602,7 +732,7 @@ void toSession::changeTab(QWidget *tab)
             }
             else if (CurrentTab == OpenSplitter)
             {
-                QListViewItem *openitem = OpenCursors->currentItem();
+                toTreeWidgetItem *openitem = OpenCursors->currentItem();
                 QString address;
                 if (openitem)
                     address = openitem->text(2);
@@ -639,15 +769,29 @@ void toSession::changeTab(QWidget *tab)
     }
 }
 
-void toSession::changeCursor(QListViewItem *item)
+void toSession::changeCursor(toTreeWidgetItem *item)
 {
     if (item)
         OpenStatement->changeAddress(item->text(2));
 }
 
-void toSession::disconnectSession(void)
+void toSession::cancelBackend()
 {
-    QListViewItem *item = Sessions->selectedItem();
+    toTreeWidgetItem *item = Sessions->selectedItem();
+    if (item)
+    {
+        try
+        {
+            connection().execute(
+                QString("SELECT pg_cancel_backend ( %1 )").arg(item->text(0)));
+        }
+        TOCATCH;
+    }
+}
+
+void toSession::disconnectSession()
+{
+    toTreeWidgetItem *item = Sessions->selectedItem();
     if (item)
     {
         QString sess = QString::fromLatin1("'");
@@ -655,9 +799,15 @@ void toSession::disconnectSession(void)
         sess.append(QString::fromLatin1(","));
         sess.append(item->text(1));
         sess.append(QString::fromLatin1("'"));
-        QString str(tr("Let current transaction finish before disconnecting session?"));
+        QString str(tr("Let current transaction finish before "
+                       "disconnecting this session?"));
         QString sql;
-        switch (TOMessageBox::warning(this, tr("Commit work?"), str, tr("&Yes"), tr("&No"), tr("Cancel")))
+        switch (TOMessageBox::warning(this,
+                                      tr("Commit work?"),
+                                      str,
+                                      tr("&Yes"),
+                                      tr("&No"),
+                                      tr("Cancel")))
         {
         case 0:
             sql = QString::fromLatin1("ALTER SYSTEM DISCONNECT SESSION ");
@@ -675,7 +825,7 @@ void toSession::disconnectSession(void)
         {
             connection().execute(sql);
         }
-        TOCATCH
+        TOCATCH;
     }
 }
 
@@ -685,29 +835,32 @@ void toSession::changeRefresh(const QString &str)
     {
         toRefreshParse(timer(), str);
     }
-    TOCATCH
+    TOCATCH;
 }
 
-void toSession::changeItem(QListViewItem *item)
+void toSession::changeItem(toTreeWidgetItem *item)
 {
     if (item && LastSession != item->text(0))
     {
         if (!item->text(0).isEmpty())
         {
-            WaitBar->changeParams(item->text(0));
-            IOBar->changeParams(item->text(0));
-            Waits->setSession(item->text(0).toInt());
+            if (WaitBar)
+                WaitBar->changeParams(item->text(0));
+            if (IOBar)
+                IOBar->changeParams(item->text(0));
+            if (Waits)
+                Waits->setSession(item->text(0).toInt());
         }
         LastSession = item->text(0);
     }
     QWidget *t = CurrentTab;
     CurrentTab = NULL;
-    changeTab(t);
+    changeTab(ResultTab->indexOf(t));
 }
 
 void toSession::refreshTabs(void)
 {
-    QListViewItem *item = Sessions->selectedItem();
+    toTreeWidgetItem *item = Sessions->selectedItem();
     if (item)
         changeItem(item);
 }
