@@ -1,39 +1,43 @@
-/*****
-*
-* TOra - An Oracle Toolkit for DBA's and developers
-* Copyright (C) 2003-2005 Quest Software, Inc
-* Portions Copyright (C) 2005 Other Contributors
-* 
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License
-* as published by the Free Software Foundation;  only version 2 of
-* the License is valid for this program.
-* 
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-* 
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*
-*      As a special exception, you have permission to link this program
-*      with the Oracle Client libraries and distribute executables, as long
-*      as you follow the requirements of the GNU GPL in regard to all of the
-*      software in the executable aside from Oracle client libraries.
-*
-*      Specifically you are not permitted to link this program with the
-*      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
-*      And you are not permitted to distribute binaries compiled against
-*      these libraries without written consent from Quest Software, Inc.
-*      Observe that this does not disallow linking to the Qt Free Edition.
-*
-*      You may link this product with any GPL'd Qt library such as Qt/Free
-*
-* All trademarks belong to their respective owners.
-*
-*****/
+
+/* BEGIN_COMMON_COPYRIGHT_HEADER
+ *
+ * TOra - An Oracle Toolkit for DBA's and developers
+ * 
+ * Shared/mixed copyright is held throughout files in this product
+ * 
+ * Portions Copyright (C) 2000-2001 Underscore AB
+ * Portions Copyright (C) 2003-2005 Quest Software, Inc.
+ * Portions Copyright (C) 2004-2008 Numerous Other Contributors
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation;  only version 2 of
+ * the License is valid for this program.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ *      As a special exception, you have permission to link this program
+ *      with the Oracle Client libraries and distribute executables, as long
+ *      as you follow the requirements of the GNU GPL in regard to all of the
+ *      software in the executable aside from Oracle client libraries.
+ * 
+ *      Specifically you are not permitted to link this program with the
+ *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
+ *      And you are not permitted to distribute binaries compiled against
+ *      these libraries. 
+ * 
+ *      You may link this product with any GPL'd Qt library.
+ * 
+ * All trademarks belong to their respective owners.
+ *
+ * END_COMMON_COPYRIGHT_HEADER */
 
 #include "utils.h"
 
@@ -47,26 +51,23 @@
 #include "totool.h"
 #include "toworksheet.h"
 
-#ifdef TO_KDE
-#include <kfiledialog.h>
-#endif
-
 #include <qcombobox.h>
-#include <qfiledialog.h>
 #include <qfileinfo.h>
 #include <qlabel.h>
 #include <qlineedit.h>
-#include <qlistview.h>
+#include <totreewidget.h>
 #include <qmenubar.h>
 #include <qmessagebox.h>
-#include <qpopupmenu.h>
 #include <qsplitter.h>
 #include <qstring.h>
-#include <qtoolbar.h>
 #include <qtoolbutton.h>
-#include <qworkspace.h>
+#include <QMdiArea>
 
-#include "tosqledit.moc"
+#include <QString>
+#include <QFrame>
+#include <QPixmap>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
 
 #include "icons/add.xpm"
 #include "icons/commit.xpm"
@@ -86,34 +87,42 @@ public:
     {
         Window = NULL;
     }
+
     virtual QWidget *toolWindow(QWidget *parent, toConnection &connection)
     {
         if (Window)
-            Window->show();
-        else
-            Window = new toSQLEdit(parent, connection);
+        {
+            Window->setFocus(Qt::OtherFocusReason);
+            // already opened, prevent creating new sub window
+            return 0;
+        }
 
-        Window->raise();
-        Window->setFocus();
-        Window->setIcon(QPixmap(const_cast<const char**>(tosqledit_xpm)));
+        Window = new toSQLEdit(parent, connection);
+        Window->setWindowIcon(QPixmap(const_cast<const char**>(tosqledit_xpm)));
         return Window;
     }
-    virtual void customSetup(int toolid)
+
+    virtual void customSetup()
     {
-        toMainWidget()->editMenu()->insertSeparator();
-        toMainWidget()->editMenu()->insertItem(QPixmap(const_cast<const char**>(tosqledit_xpm)),
-                                               qApp->translate("toSQLEditTool", "&Edit SQL..."), toolid);
-        toMainWidget()->registerSQLEditor(toolid);
+        toMainWidget()->getEditMenu()->addAction(
+            QIcon(tosqledit_xpm),
+            qApp->translate("toSQLEditTool", "&Edit SQL..."),
+            this,
+            SLOT(createWindow()));
+        toMainWidget()->registerSQLEditor(key());
     }
+
     void closeWindow(void)
     {
         Window = NULL;
     }
+
     virtual bool canHandle(toConnection &)
     {
         return true;
     }
-    virtual void closeWindow(toConnection &connection){};
+
+    virtual void closeWindow(toConnection &connection) {};
 };
 
 static toSQLEditTool SQLEditTool;
@@ -123,21 +132,21 @@ void toSQLEdit::updateStatements(const QString &sel)
     Statements->clear();
     toSQL::sqlMap sql = toSQL::definitions();
 
-    QListViewItem *head = NULL;
-    QListViewItem *item = NULL;
+    toTreeWidgetItem *head = NULL;
+    toTreeWidgetItem *item = NULL;
 
     for (toSQL::sqlMap::iterator pos = sql.begin();pos != sql.end();pos++)
     {
         QString str = (*pos).first;
-        int i = str.find(QString::fromLatin1(":"));
+        int i = str.indexOf(QString::fromLatin1(":"));
         if (i >= 0)
         {
             if (!head || head->text(0) != str.left(i))
             {
-                head = new QListViewItem(Statements, str.left(i));
+                head = new toTreeWidgetItem(Statements, str.left(i));
                 head->setSelectable(false);
             }
-            item = new QListViewItem(head, str.right(str.length() - i - 1));
+            item = new toTreeWidgetItem(head, str.right(str.length() - i - 1));
             if (sel == str)
             {
                 Statements->setSelected(item, true);
@@ -147,7 +156,7 @@ void toSQLEdit::updateStatements(const QString &sel)
         }
         else
         {
-            head = new QListViewItem(Statements, head, str);
+            head = new toTreeWidgetItem(Statements, head, str);
             if (sel == str)
             {
                 Statements->setSelected(head, true);
@@ -158,68 +167,103 @@ void toSQLEdit::updateStatements(const QString &sel)
 }
 
 toSQLEdit::toSQLEdit(QWidget *main, toConnection &connection)
-        : toToolWidget(SQLEditTool, "sqledit.html", main, connection)
+        : toToolWidget(SQLEditTool, "sqledit.html", main, connection, "toSQLEdit")
 {
-    QToolBar *toolbar = toAllocBar(this, tr("SQL editor"));
 
-    new QToolButton(QPixmap(const_cast<const char**>(fileopen_xpm)),
-                    tr("Load SQL dictionary file"),
-                    tr("Load SQL dictionary file"),
-                    this, SLOT(loadSQL()),
-                    toolbar);
-    new QToolButton(QPixmap(const_cast<const char**>(filesave_xpm)),
-                    tr("Save modified SQL to dictionary file"),
-                    tr("Save modified SQL to dictionary file"),
-                    this, SLOT(saveSQL()),
-                    toolbar);
+    QToolBar *toolbar = toAllocBar(this, tr("SQL editor"));
+    layout()->addWidget(toolbar);
+
+    toolbar->addAction(QIcon(fileopen_xpm),
+                       tr("Load SQL dictionary file"),
+                       this,
+                       SLOT(loadSQL()));
+    toolbar->addAction(QIcon(filesave_xpm),
+                       tr("Save modified SQL to dictionary file"),
+                       this,
+                       SLOT(saveSQL()));
     toolbar->addSeparator();
-    CommitButton = new QToolButton(QPixmap(const_cast<const char**>(commit_xpm)),
-                                   tr("Save this entry in the dictionary"),
-                                   tr("Save this entry in the dictionary"),
-                                   this, SLOT(commitChanges()),
-                                   toolbar);
-    TrashButton = new QToolButton(QPixmap(const_cast<const char**>(trash_xpm)),
-                                  tr("Delete this version from the SQL dictionary"),
-                                  tr("Delete this version from the SQL dictionary"),
-                                  this, SLOT(deleteVersion()),
-                                  toolbar);
-    new QToolButton(QPixmap(const_cast<const char**>(add_xpm)),
-                    tr("Start new SQL definition"),
-                    tr("Start new SQL definition"),
-                    this, SLOT(newSQL()),
-                    toolbar);
+
+    CommitButton = toolbar->addAction(
+        QIcon(commit_xpm),
+        tr("Save this entry in the dictionary"),
+        this,
+        SLOT(commitChanges()));
+
+    TrashButton = toolbar->addAction(
+        QIcon(trash_xpm),
+        tr("Delete this version from the SQL dictionary"),
+        this,
+        SLOT(deleteVersion()));
+
+    toolbar->addAction(QIcon(add_xpm),
+                       tr("Start new SQL definition"),
+                       this,
+                       SLOT(newSQL()));
+
     CommitButton->setEnabled(true);
     TrashButton->setEnabled(false);
-    toolbar->setStretchableWidget(new QLabel(toolbar, TO_KDE_TOOLBAR_WIDGET));
 
-    QSplitter *splitter = new QSplitter(Horizontal, this);
+    toolbar->addWidget(new toSpacer());
+
+    QSplitter *splitter = new QSplitter(Qt::Horizontal, this);
+    layout()->addWidget(splitter);
+
     Statements = new toListView(splitter);
     Statements->setRootIsDecorated(true);
     Statements->addColumn(tr("Text Name"));
     Statements->setSorting(0);
-    Statements->setSelectionMode(QListView::Single);
-    QVBox *vbox = new QVBox(splitter);
+    Statements->setSelectionMode(toTreeWidget::Single);
+
+    QWidget *vbox = new QWidget(splitter);
+    QVBoxLayout *vlay = new QVBoxLayout;
+
+    QWidget *hbox = new QWidget(vbox);
+    QHBoxLayout *hlay = new QHBoxLayout;
+    vlay->addWidget(hbox);
+
+    hlay->addWidget(new QLabel(tr("Name") + " ", hbox));
 
-    QHBox *hbox = new QHBox(vbox);
-    new QLabel(tr("Name") + " ", hbox);
     Name = new QLineEdit(hbox);
-    new QLabel(" " + tr("Database") + " ", hbox);
+    hlay->addWidget(Name);
+
+    hlay->addWidget(new QLabel(" " + tr("Database") + " ", hbox));
+
     Version = new QComboBox(hbox);
     Version->setEditable(true);
     Version->setDuplicatesEnabled(false);
+    hlay->addWidget(Version);
+
     LastVersion = connection.provider() + ":Any";
-    Version->insertItem(LastVersion);
+    Version->addItem(LastVersion);
 
     QFrame *line = new QFrame(vbox);
+    vlay->addWidget(line);
+
     line->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-    new QLabel(tr("Description"), vbox);
-    splitter = new QSplitter(Vertical, vbox);
+    vlay->addWidget(new QLabel(tr("Description"), vbox));
+
+    splitter = new QSplitter(Qt::Vertical, vbox);
+    vlay->addWidget(splitter);
     Description = new toMarkedText(splitter);
     Editor = new toWorksheet(splitter, connection, false);
 
+    hlay->setSpacing(0);
+    hlay->setContentsMargins(0, 0, 0, 0);
+    hbox->setLayout(hlay);
+
+    vlay->setSpacing(0);
+    vlay->setContentsMargins(0, 0, 0, 0);
+    vbox->setLayout(vlay);
+
     connectList(true);
-    connect(Version, SIGNAL(activated(const QString &)), this, SLOT(changeVersion(const QString &)));
-    connect(toMainWidget(), SIGNAL(sqlEditor(const QString &)), this, SLOT(editSQL(const QString &)));
+    connect(Version,
+            SIGNAL(activated(const QString &)),
+            this,
+            SLOT(changeVersion(const QString &)));
+    connect(toMainWidget(),
+            SIGNAL(sqlEditor(const QString &)),
+            this,
+            SLOT(editSQL(const QString &)));
 
     updateStatements();
 
@@ -237,7 +281,7 @@ void toSQLEdit::connectList(bool conn)
 toSQLEdit::~toSQLEdit()
 {
     SQLEditTool.closeWindow();
-    toSQL::saveSQL(toConfigurationSingle::Instance().globalConfig(CONF_SQL_FILE, DEFAULT_SQL_FILE));
+    toSQL::saveSQL(toConfigurationSingle::Instance().sqlFile());
 }
 
 void toSQLEdit::loadSQL(void)
@@ -251,11 +295,14 @@ void toSQLEdit::loadSQL(void)
             Filename = filename;
         }
     }
-    TOCATCH
+    TOCATCH;
 }
 
 void toSQLEdit::saveSQL(void)
 {
+    // must commit changes first for sql to be present in dictionary.
+    commitChanges();
+
     QString filename = toSaveFilename(QString::null, QString::null, this);
     if (!filename.isEmpty())
     {
@@ -266,19 +313,19 @@ void toSQLEdit::saveSQL(void)
 
 void toSQLEdit::deleteVersion(void)
 {
-    QCString provider;
-    QCString version;
+    QString provider;
+    QString version;
     if (!splitVersion(Version->currentText(), provider, version))
         return ;
 
     try
     {
-        toSQL::deleteSQL(Name->text().latin1(), version, provider);
-        Version->removeItem(Version->currentItem());
+        toSQL::deleteSQL(Name->text().toLatin1(), version, provider);
+        Version->removeItem(Version->currentIndex());
 
         if (Version->count() == 0)
         {
-            QListViewItem *item = toFindItem(Statements, Name->text());
+            toTreeWidgetItem *item = toFindItem(Statements, Name->text());
             if (item)
             {
                 connectList(false);
@@ -288,21 +335,21 @@ void toSQLEdit::deleteVersion(void)
             newSQL();
         }
         else
-            selectionChanged(QString::fromLatin1(connection().provider() + ":" + connection().version()));
+            selectionChanged(QString(connection().provider() + ":" + connection().version()));
     }
-    TOCATCH
+    TOCATCH;
 }
 
 bool toSQLEdit::close(bool del)
 {
     if (checkStore(false))
-        return QVBox::close(del);
+        return toToolWidget::close();
     return false;
 }
 
-bool toSQLEdit::splitVersion(const QString &split, QCString &provider, QCString &version)
+bool toSQLEdit::splitVersion(const QString &split, QString &provider, QString &version)
 {
-    int found = split.find(QString::fromLatin1(":"));
+    int found = split.indexOf(QString::fromLatin1(":"));
     if (found < 0)
     {
         TOMessageBox::warning(this, tr("Wrong format of version"),
@@ -310,7 +357,7 @@ bool toSQLEdit::splitVersion(const QString &split, QCString &provider, QCString
                               tr("&Ok"));
         return false;
     }
-    provider = split.mid(0, found).latin1();
+    provider = split.mid(0, found).toLatin1();
     if (provider.length() == 0)
     {
         TOMessageBox::warning(this, tr("Wrong format of version"),
@@ -318,7 +365,7 @@ bool toSQLEdit::splitVersion(const QString &split, QCString &provider, QCString
                               tr("&Ok"));
         return false;
     }
-    version = split.mid(found + 1).latin1();
+    version = split.mid(found + 1).toLatin1();
     if (version.length() == 0)
     {
         TOMessageBox::warning(this, tr("Wrong format of version"),
@@ -331,24 +378,24 @@ bool toSQLEdit::splitVersion(const QString &split, QCString &provider, QCString
 
 void toSQLEdit::commitChanges(bool changeSelected)
 {
-    QCString provider;
-    QCString version;
+    QString provider;
+    QString version;
     if (!splitVersion(Version->currentText(), provider, version))
         return ;
     QString name = Name->text();
-    QListViewItem *item = toFindItem(Statements, name);
+    toTreeWidgetItem *item = toFindItem(Statements, name);
     if (!item)
     {
-        int i = name.find(QString::fromLatin1(":"));
+        int i = name.indexOf(QString::fromLatin1(":"));
         if (i >= 0)
         {
             item = toFindItem(Statements, name.mid(0, i));
             if (!item)
-                item = new QListViewItem(Statements, name.mid(0, i));
-            item = new QListViewItem(item, name.mid(i + 1));
+                item = new toTreeWidgetItem(Statements, name.mid(0, i));
+            item = new toTreeWidgetItem(item, name.mid(i + 1));
         }
         else
-            item = new QListViewItem(Statements, name);
+            item = new toTreeWidgetItem(Statements, name);
     }
     connectList(false);
     if (changeSelected)
@@ -367,7 +414,7 @@ void toSQLEdit::commitChanges(bool changeSelected)
                               tr("&Ok"));
         Description->setText(tr("Undescribed"));
     }
-    toSQL::updateSQL(name.latin1(),
+    toSQL::updateSQL(name.toLatin1(),
                      Editor->editor()->text(),
                      Description->text(),
                      version,
@@ -378,7 +425,7 @@ void toSQLEdit::commitChanges(bool changeSelected)
     bool update = Name->isModified();
 
 
-    Name->setEdited(false);
+    Name->setModified(false);
     Description->setModified(false);
     Editor->editor()->setModified(false);
     LastVersion = Version->currentText();
@@ -395,6 +442,9 @@ bool toSQLEdit::checkStore(bool justVer)
             Description->isModified()) &&
             Version->currentText().length() > 0)
     {
+        // grab focus so user can see file and decide to save
+        setFocus(Qt::OtherFocusReason);
+
         switch (TOMessageBox::information(this, tr("Modified SQL dictionary"),
                                           tr("Save changes into the SQL dictionary"),
                                           tr("&Yes"), tr("&No"), tr("Cancel"), 0, 2))
@@ -403,7 +453,7 @@ bool toSQLEdit::checkStore(bool justVer)
             commitChanges(false);
             break;
         case 1:
-            Name->setEdited(false);
+            Name->setModified(false);
             Description->setModified(false);
             Editor->editor()->setModified(false);
             LastVersion = Version->currentText();
@@ -422,7 +472,7 @@ void toSQLEdit::changeVersion(const QString &ver)
         selectionChanged(ver);
         if (Version->currentText() != ver)
         {
-            Version->insertItem(ver);
+            Version->addItem(ver);
             Version->lineEdit()->setText(ver);
         }
     }
@@ -433,18 +483,18 @@ void toSQLEdit::selectionChanged(void)
     try
     {
         if (checkStore(false))
-            selectionChanged(QString::fromLatin1(connection().provider() + ":" + connection().version()));
+            selectionChanged(QString(connection().provider() + ":" + connection().version()));
     }
-    TOCATCH
+    TOCATCH;
 }
 
 void toSQLEdit::changeSQL(const QString &name, const QString &maxver)
 {
     toSQL::sqlMap sql = toSQL::definitions();
     Name->setText(name);
-    Name->setEdited(false);
+    Name->setModified(false);
 
-    QListViewItem *item = toFindItem(Statements, name);
+    toTreeWidgetItem *item = toFindItem(Statements, name);
     if (item)
     {
         connectList(false);
@@ -457,9 +507,9 @@ void toSQLEdit::changeSQL(const QString &name, const QString &maxver)
 
     Version->clear();
     LastVersion = "";
-    if (sql.find(name.latin1()) != sql.end())
+    if (sql.find(name.toLatin1()) != sql.end())
     {
-        toSQL::definition &def = sql[name.latin1()];
+        toSQL::definition &def = sql[name.toLatin1()];
         std::list<toSQL::version> &ver = def.Versions;
 
         Description->setText(def.Description);
@@ -472,7 +522,7 @@ void toSQLEdit::changeSQL(const QString &name, const QString &maxver)
             QString str = (*i).Provider;
             str += QString::fromLatin1(":");
             str += (*i).Version;
-            Version->insertItem(str);
+            Version->addItem(str);
             if (str <= maxver || j == ver.end())
             {
                 j = i;
@@ -485,7 +535,7 @@ void toSQLEdit::changeSQL(const QString &name, const QString &maxver)
             Editor->editor()->setText((*j).SQL);
             TrashButton->setEnabled(true);
             CommitButton->setEnabled(true);
-            Version->setCurrentItem(ind);
+            Version->setCurrentIndex(ind);
         }
     }
     else
@@ -498,7 +548,7 @@ void toSQLEdit::changeSQL(const QString &name, const QString &maxver)
     if (LastVersion.isEmpty())
     {
         LastVersion = QString::fromLatin1("Any:Any");
-        Version->insertItem(LastVersion);
+        Version->addItem(LastVersion);
     }
     Editor->editor()->setModified(false);
 }
@@ -507,7 +557,7 @@ void toSQLEdit::selectionChanged(const QString &maxver)
 {
     try
     {
-        QListViewItem *item = Statements->selectedItem();
+        toTreeWidgetItem *item = Statements->selectedItem();
         if (item)
         {
             QString name = item->text(0);
@@ -520,7 +570,7 @@ void toSQLEdit::selectionChanged(const QString &maxver)
             changeSQL(name, maxver);
         }
     }
-    TOCATCH
+    TOCATCH;
 }
 
 void toSQLEdit::editSQL(const QString &nam)
@@ -528,9 +578,9 @@ void toSQLEdit::editSQL(const QString &nam)
     try
     {
         if (checkStore(false))
-            changeSQL(nam, QString::fromLatin1(connection().provider() + ":" + connection().version()));
+            changeSQL(nam, QString(connection().provider() + ":" + connection().version()));
     }
-    TOCATCH
+    TOCATCH;
 }
 
 void toSQLEdit::newSQL(void)
@@ -538,60 +588,60 @@ void toSQLEdit::newSQL(void)
     if (checkStore(false))
     {
         QString name = Name->text();
-        int found = name.find(QString::fromLatin1(":"));
+        int found = name.indexOf(QString::fromLatin1(":"));
         if (found < 0)
             name = QString::null;
         else
             name = name.mid(0, found + 1);
         try
         {
-            changeSQL(name, QString::fromLatin1(connection().provider() + ":Any"));
+            changeSQL(name, QString(connection().provider() + ":Any"));
         }
-        TOCATCH
+        TOCATCH;
     }
 }
 
 static toSQLTemplate SQLTemplate;
 
-toSQLTemplateItem::toSQLTemplateItem(QListView *parent)
+toSQLTemplateItem::toSQLTemplateItem(toTreeWidget *parent)
         : toTemplateItem(SQLTemplate, parent, qApp->translate("toSQL", "SQL Dictionary"))
 {
     setExpandable(true);
 }
 
-static QString JustLast(const QCString &str)
+static QString JustLast(const QString &str)
 {
-    int pos = str.findRev(":");
+    int pos = str.lastIndexOf(":");
     if (pos >= 0)
-        return QString::fromLatin1(str.mid(pos + 1));
-    return QString::fromLatin1(str);
+        return QString(str.mid(pos + 1));
+    return QString(str);
 }
 
 toSQLTemplateItem::toSQLTemplateItem(toSQLTemplateItem *parent,
-                                     const QCString &name)
+                                     const QString &name)
         : toTemplateItem(parent, JustLast(name))
 {
     Name = name;
-    std::list<QCString> def = toSQL::range(Name + ":");
+    std::list<QString> def = toSQL::range(Name + ":");
     if (def.begin() != def.end())
         setExpandable(true);
 }
 
 void toSQLTemplateItem::expand(void)
 {
-    std::list<QCString> def;
+    std::list<QString> def;
     if (Name.isEmpty())
         def = toSQL::range(Name);
     else
         def = toSQL::range(Name + ":");
-    QCString last;
-    for (std::list<QCString>::iterator sql = def.begin();sql != def.end();sql++)
+    QString last;
+    for (std::list<QString>::iterator sql = def.begin();sql != def.end();sql++)
     {
-        QCString name = *sql;
+        QString name = *sql;
         if (!Name.isEmpty())
             name = name.mid(Name.length() + 1);
-        if (name.find(":") != -1)
-            name = name.mid(0, name.find(":"));
+        if (name.indexOf(":") != -1)
+            name = name.mid(0, name.indexOf(":"));
         if (name != last)
         {
             if (Name.isEmpty())
