@@ -5,14 +5,24 @@
 //
 #include "totimer.h"
 
-toTimer::toTimer(QObject *parent, const char * name): QTimer(parent, name)
-{ }
+toTimer::toTimer(QObject *parent, const char * name):
+        QTimer(parent)
+{
+
+    if (name)
+        setObjectName(name);
+}
 
 int toTimer::start(int msec, bool sshot)
 {
     LastTimer = msec;
-    return QTimer::start(msec, sshot);
+
+    if (sshot)
+        setSingleShot(msec);
+    QTimer::start(msec);
+    return timerId();
 }
+
 int toTimer::lastTimer(void)
 {
     return LastTimer;
