@@ -1,39 +1,43 @@
-/*****
-*
-* TOra - An Oracle Toolkit for DBA's and developers
-* Copyright (C) 2003-2005 Quest Software, Inc
-* Portions Copyright (C) 2005 Other Contributors
-* 
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License
-* as published by the Free Software Foundation;  only version 2 of
-* the License is valid for this program.
-* 
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-* 
-* You should have received a copy of the GNU General Public License
-* along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-*
-*      As a special exception, you have permission to link this program
-*      with the Oracle Client libraries and distribute executables, as long
-*      as you follow the requirements of the GNU GPL in regard to all of the
-*      software in the executable aside from Oracle client libraries.
-*
-*      Specifically you are not permitted to link this program with the
-*      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
-*      And you are not permitted to distribute binaries compiled against
-*      these libraries without written consent from Quest Software, Inc.
-*      Observe that this does not disallow linking to the Qt Free Edition.
-*
-*      You may link this product with any GPL'd Qt library such as Qt/Free
-*
-* All trademarks belong to their respective owners.
-*
-*****/
+
+/* BEGIN_COMMON_COPYRIGHT_HEADER
+ *
+ * TOra - An Oracle Toolkit for DBA's and developers
+ * 
+ * Shared/mixed copyright is held throughout files in this product
+ * 
+ * Portions Copyright (C) 2000-2001 Underscore AB
+ * Portions Copyright (C) 2003-2005 Quest Software, Inc.
+ * Portions Copyright (C) 2004-2008 Numerous Other Contributors
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation;  only version 2 of
+ * the License is valid for this program.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * 
+ *      As a special exception, you have permission to link this program
+ *      with the Oracle Client libraries and distribute executables, as long
+ *      as you follow the requirements of the GNU GPL in regard to all of the
+ *      software in the executable aside from Oracle client libraries.
+ * 
+ *      Specifically you are not permitted to link this program with the
+ *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
+ *      And you are not permitted to distribute binaries compiled against
+ *      these libraries. 
+ * 
+ *      You may link this product with any GPL'd Qt library.
+ * 
+ * All trademarks belong to their respective owners.
+ *
+ * END_COMMON_COPYRIGHT_HEADER */
 
 #ifndef UTILS_H
 #define UTILS_H
@@ -44,70 +48,20 @@
 #include <map>
 #include <algorithm>
 
-#include <qmainwindow.h>
-#include <qtoolbutton.h>
+#include <QToolButton>
+#include <QString>
+#include <QPixmap>
+#include <QKeyEvent>
+#include <QMainWindow>
 
-#ifdef TO_KDE
-#include <kapp.h>
-#if KDE_VERSION < 220
-#define TOPrinter QPrinter
-#else
-#define TOPrinter KPrinter
-#define TO_HAS_KPRINT
-#endif
-#define TOFileDialog KFileDialog
-#else
 #define TOPrinter QPrinter
 #define TOFileDialog QFileDialog
-#endif
 #define TOMessageBox QMessageBox
 #define TODock QWidget
 
-#ifdef TO_KDE
-#  if KDE_VERSION >= 0x30400
-#    define TO_KDE_KACCELMANAGER
-#  endif
-#endif
-
-#undef TO_DEBUG
-#ifdef TO_DEBUG
-#include <stdio.h>
-static FILE* toraLog=NULL;
-#define TO_DEBUGOUT(x) if(!toraLog) toraLog=fopen("C:\\Temp\\tora.log","a"); fprintf(toraLog,"%s\n",(const char *)x);fflush(toraLog);
-#else
-#define TO_DEBUGOUT(x)
-#endif
-
-#if 0
-/**
- * The class to use for a printer object.
- */
-class TOPrinter : public QPrinter
-    {}
-;
-/**
- * The class to use for a dock widget.
- */
-class TODock : public QWidget
-    {}
-;
-/**
- * The class to use for a file dialog.
- */
-class TOFileDialog : public QFileDialog
-    {}
-;
-/**
- * The class to use for a messagebox.
- */
-class TOMessageBox : public QMessageBox
-    {}
-;
-#endif
-
 class QComboBox;
-class QListView;
-class QListViewItem;
+class toTreeWidget;
+class toTreeWidgetItem;
 class QToolBar;
 class QWidget;
 class toConnection;
@@ -167,8 +121,8 @@ QStringList toGetSessionTypes(void);
  * @param def Default value of the combobox.
  * @param item Combo box to fill. If not specified a new combobox is created.
  */
-QComboBox *toRefreshCreate(QWidget *parent, const char *name = NULL, const QString &def = QString::null,
-                           QComboBox *item = NULL);
+QComboBox *toRefreshCreate(QWidget *parent, const char *name = NULL, const QString & def = QString::null,
+                           QComboBox * item = NULL);
 /** Set a timer with the value from a refresh combobox (See @ref toRefreshCreate).
  * @param timer Timer to set timeout in.
  * @param str String from currentText of combobox. If empty, set to default.
@@ -205,7 +159,7 @@ TODock *toAllocDock(const QString &name,
  * @param container Whatever container is supposed to be in the dock window.
  * @param place Where to place the dock.
  */
-void toAttachDock(TODock *dock, QWidget *container, QMainWindow::ToolBarDock place);
+void toAttachDock(TODock *, QWidget *, Qt::DockWidgetArea);
 /** Decode a size string this basically converts "KB" to 1024, "MB" to 1024KB and
  * everything else to 1.
  * @return Multiplier specified by string.
@@ -291,18 +245,18 @@ QString toFontToString(const QFont &fnt);
 /** Get the path to the help directory.
  * @return Path to the help directory.
  */
-QString toHelpPath(void);
+// QString toHelpPath(void);
 /** Read file from filename.
  * @param filename Filename to read file from.
  * @return Contents of file.
  * @exception QString describing I/O problem.
  */
-QCString toReadFile(const QString &filename);
+QString toReadFile(const QString &filename);
 /** Write file to filename.
  * @param filename Filename to write file to.
  * @param data Data to write to file.
  */
-bool toWriteFile(const QString &filename, const QCString &data);
+bool toWriteFile(const QString &filename, const QByteArray &data);
 /** Write file to filename.
  * @param filename Filename to write file to.
  * @param data Data to write to file.
@@ -314,16 +268,16 @@ bool toWriteFile(const QString &filename, const QString &data);
  * @param len Length of lists to compare.
  * @return True if all first len elements match.
  */
-bool toCompareLists(QStringList &l1, QStringList &l2, unsigned int len);
+bool toCompareLists(QStringList &l1, QStringList &l2, int len);
 /** Set environment variable.
  * @param var Variable name to set.
  * @param val Value to set variable to.
  */
-void toSetEnv(const QCString &var, const QCString &val);
+void toSetEnv(const QString &var, const QString &val);
 /** Delete an environment variable.
  * @param var Environment variable to delete.
  */
-void toUnSetEnv(const QCString &var);
+void toUnSetEnv(const QString &var);
 /** Pop up a dialog and choose a file to open.
  * @param filename Default filename to open.
  * @param filter Filter of filenames (See @ref QFileDialog)
@@ -339,10 +293,6 @@ QString toOpenFilename(const QString &filename, const QString &filter, QWidget *
  */
 QString toSaveFilename(const QString &filename, const QString &filter, QWidget *parent);
 
-/** Get index of menu to insert tool specific menu at.
- * @return Index of the tool menu entry.
- */
-int toToolMenuIndex(void);
 /** Check if a character is valid for an identifier in Oracle.
  * @param c Character to check
  * @return True if it is a valid Oracle identifier.
@@ -355,10 +305,7 @@ inline bool toIsIdent(QChar c)
  * target on windows).
  * @return String containing directory
  */
-QString toPluginPath(void);
-/** Get a list of the latest status messages that have been shown.
- */
-std::list<QString> toStatusMessages(void);
+// QString toPluginPath(void);
 /** Get a brush for a chart item.
  * @param index Indicating which chart item to get color for.
  */
@@ -426,30 +373,28 @@ bool toCheckModal(QWidget *widget);
  * @param prefix Prefix to save map using.
  * @param src The map to save.
  */
-void toMapExport(std::map<QCString, QString> &data, const QCString &prefix,
-                 std::map<QCString, QString> &src);
+void toMapExport(std::map<QString, QString> &data, const QString &prefix,
+                 std::map<QString, QString> &src);
 /** Import the contents of a map from another map.
  * @param data The source map.
  * @param prefix Prefix to use for restoring from map.
  * @param dst The map to save into.
  */
-void toMapImport(std::map<QCString, QString> &data, const QCString &prefix,
-                 std::map<QCString, QString> &dst);
+void toMapImport(std::map<QString, QString> &data, const QString &prefix,
+                 std::map<QString, QString> &dst);
 
 /** Find an item in a listview.
  * @param list The list to search for the item.
  * @param str The string to search for. You can specify parent/child with : in the string.
  */
-QListViewItem *toFindItem(QListView *list, const QString &str);
+toTreeWidgetItem *toFindItem(toTreeWidget *list, const QString &str);
 /** Whenever this class is instantiated the window will display a busy cursor. You
  * can instantiate this function as many time as you want, only when all of them are
  * destructed the curser will revert back to normal.
  */
 class toBusy
 {
-    static unsigned int Count;
 public:
-    static void clear(void);
     toBusy();
     ~toBusy();
 };
@@ -486,13 +431,11 @@ class toPopupButton : public QToolButton
 public:
     /** Create button, same constructor as toolbutton except no slots
      */
-    toPopupButton(const QIconSet &iconSet, const QString &textLabel,
+    toPopupButton(const QIcon &iconSet, const QString &textLabel,
                   const QString &grouptext, QToolBar *parent, const char *name = 0);
     /** Create button somewhere else than in a toolbar.
      */
     toPopupButton(QWidget *parent, const char *name = 0);
-private slots:
-    void click(void);
 };
 
 /**
@@ -513,7 +456,7 @@ struct DeleteObject
 #define TOCATCH                                 \
     catch (const QString &str) {                \
       toStatusMessage(str);                     \
-    } 
+    }
 /* This can't be documented in KDoc, anyway it is an easy way to catch any exception that
  * might be sent by TOra or OTL and display the message in the statusbar of the main window.
  */
@@ -525,6 +468,26 @@ struct DeleteObject
       } catch(...) { }                          \
     }
 
+/**
+ * std::min name collisions on windows/cygwin
+ *
+ */
+#define TO_MIN qMin
+
 #define QTRANS(x,y) (qApp?qApp->translate(x,y):QString::fromLatin1(y))
 
+/**
+ * simple class to provide an empty widget that will resize horizontally
+ */
+class toSpacer : public QWidget
+{
+    Q_OBJECT;
+
+public:
+    toSpacer(QWidget *parent = NULL);
+    ~toSpacer(void)
+    {
+    }
+};
+
 #endif
